SystemOrganization addCategory: #'OnlineHelp-Tests'!
SystemOrganization addCategory: #'OnlineHelp-Core'!
SystemOrganization addCategory: #'OnlineHelp-Handlers'!

TestCase subclass: #HelpServerTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OnlineHelp-Tests'!

!HelpServerTests methodsFor: 'testing' stamp: 'tbn 10/22/2012 20:22'!
testPortAvailable

	self assert: HelpServer onlineHelpPort isInteger 
	
! !

!HelpServerTests methodsFor: 'testing' stamp: 'tbn 10/22/2012 20:24'!
testServerAccessibility

	|server|	
	server := HelpServer server.
	self 
		assert: server notNil;
		assert: server port = HelpServer onlineHelpPort;
		assert: server isRunning = HelpServer isRunning 
		
	
	! !

Object subclass: #HelpRequestDispatcher
	instanceVariableNames: 'dispatchMap'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OnlineHelp-Core'!

!HelpRequestDispatcher methodsFor: 'building' stamp: 'tbn 10/29/2012 21:25'!
buildDispatchMap
 
	| handler |
	self				
		map: 'help' to: #help:;				
		map: '/' to: 'welcome';				
		map: 'favicon.ico' to: #favicon:.
		
	OHHelpRequestHandler allSubclassesDo: [:each |
		handler := each new.
		self map: handler prefix  to: handler
	]! !

!HelpRequestDispatcher methodsFor: 'accessing' stamp: 'tbn 10/23/2012 20:16'!
dispatchMap
	^ dispatchMap ifNil: [ dispatchMap := Dictionary new ]! !

!HelpRequestDispatcher methodsFor: 'standard responses' stamp: 'tbn 10/23/2012 21:52'!
favicon: request
	"Answer a nice favicon for browsers to display"

	| entity |
	entity := ZnEntity with: HelpResourceLibrary faviconBytes type: 'image/vnd.microsoft.icon'. 
	^ ZnResponse ok: entity! !

!HelpRequestDispatcher methodsFor: 'private' stamp: 'tbn 10/23/2012 21:51'!
generateHelp

	^ String streamContents: [ :stream |
		stream << ZnConstants standardHtmlDocType.
		stream << '<html><head><title>Pharo Help</title><link rel="shortcut icon" href="/favicon.ico"/>'.
		stream << '<style type="text/css"> '.
		stream << HelpResourceLibrary helpCss.
		stream << '</style>'.		
		stream << '</head>'.
		stream << '<body><h1>Pharo Help</h1><h3>Online Help</h3><ul>'.
		dispatchMap keys do: [ :each | 
			stream << '<li><a href="'; << each; << '">'; << each; << '</a></li>' ].
		stream << '<ul></body></html>' ]! !

!HelpRequestDispatcher methodsFor: 'dispatching' stamp: 'tbn 10/29/2012 21:27'!
handleRequest: aRequest
	| prefix prefixHandler |
	prefix := aRequest uri isSlash
		ifTrue: [ dispatchMap  at: '/' ifAbsent: [ nil ] ]
		ifFalse: [ aRequest uri firstPathSegment ].
	prefixHandler := dispatchMap at: prefix ifAbsent: [ nil ].
	prefixHandler isNil
		ifFalse: [ 
			^ prefixHandler isSymbol
				ifTrue: [ self perform: prefixHandler with: aRequest ]
				ifFalse: [ prefixHandler handleRequest: aRequest ] ].
	^ ZnResponse notFound: aRequest uri
! !

!HelpRequestDispatcher methodsFor: 'responses' stamp: 'tbn 10/23/2012 20:22'!
help: request
	"Reply with a dynamic HTML page containing links to all pages I support"

	^ ZnResponse ok: (ZnEntity html: self generateHelp)
	! !

!HelpRequestDispatcher methodsFor: 'initialize-release' stamp: 'tbn 10/23/2012 20:08'!
initialize 
	super initialize.
	self buildDispatchMap! !

!HelpRequestDispatcher methodsFor: 'accessing' stamp: 'tbn 10/23/2012 20:23'!
map: prefix to: handler
	"Arrange for the receiver to dispatch requests matching prefix to handler.
	Handler can be a symbol naming a method in the receiver, 
	or a block accepting the request and producing the response"
	
	self dispatchMap  
		at: prefix
		put: handler
		! !

Object subclass: #HelpResourceLibrary
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OnlineHelp-Core'!

!HelpResourceLibrary class methodsFor: 'icons' stamp: 'tbn 10/23/2012 21:52'!
faviconBytes
	^#[0 0 1 0 1 0 16 16 0 0 1 0 32 0 104 4 0 0 22 0 0 0 40 0 0 0 16 0 0 0 32 0 0 0 1 0 32 0 0 0 0 0 0 0 0 0 19 11 0 0 19 11 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 208 173 126 255 237 173 23 255 229 165 24 255 208 157 69 255 206 177 144 255 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 208 178 142 255 213 156 53 255 231 164 23 255 228 160 23 255 205 151 69 255 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 203 172 138 255 200 141 57 255 212 139 27 255 212 188 163 255 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 222 205 191 255 202 171 141 255 0 0 0 0 0 0 0 0 0 0 0 0 194 150 106 255 219 201 184 255 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 169 107 44 255 172 125 82 255 210 189 171 255 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 196 167 143 255 137 86 46 255 126 78 44 255 161 123 92 255 222 207 197 255 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 216 198 184 255 161 125 99 255 100 65 52 255 144 108 84 255 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 186 155 129 255 212 193 179 255 238 230 226 255 203 182 166 255 180 148 119 255 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 176 149 133 255 91 71 85 255 170 144 129 255 226 212 203 255 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 209 188 173 255 70 60 104 255 34 34 103 255 95 76 96 255 204 183 169 255 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 213 196 184 255 77 64 104 255 34 40 129 255 42 46 127 255 13 22 118 255 67 59 113 255 211 194 183 255 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 220 205 194 255 152 129 128 255 47 51 136 255 39 49 152 255 25 33 133 255 137 118 132 255 211 195 185 255 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 204 184 171 255 41 49 152 255 39 50 162 255 37 49 162 255 179 156 150 255 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 222 206 196 255 119 115 166 255 87 109 209 255 92 102 188 255 191 169 159 255 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 154 154 164 255 162 221 255 255 137 172 217 255 223 207 194 255 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 193 168 139 255 149 138 108 255 176 154 122 255 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 254 15 0 0 255 7 240 191 255 195 0 0 254 115 0 0 255 31 53 194 255 7 0 0 255 135 0 0 255 7 0 0 255 15 0 0 255 7 56 20 254 3 0 0 254 3 0 0 255 7 255 255 255 7 255 255 255 135 58 116 255 143 0 0]! !

!HelpResourceLibrary class methodsFor: 'styles' stamp: 'tbn 10/29/2012 21:35'!
helpCss
	^'
	body {
	 
}
'! !

Object subclass: #HelpServer
	instanceVariableNames: 'prefixMap'
	classVariableNames: 'OnlineHelpPort'
	poolDictionaries: ''
	category: 'OnlineHelp-Core'!

!HelpServer class methodsFor: 'private' stamp: 'tbn 10/23/2012 19:58'!
dispatcherClass
	"Returns the default dispatcher class."
	
	^HelpRequestDispatcher ! !

!HelpServer class methodsFor: 'testing' stamp: 'tbn 10/22/2012 21:05'!
isRunning
	"Return true if the server is running"
	 
	^self server isRunning! !

!HelpServer class methodsFor: 'settings' stamp: 'tbn 10/22/2012 20:11'!
onlineHelpPort
	"Return the port to use for the online help, an Integer"
	
	^OnlineHelpPort ifNil: [ OnlineHelpPort := 8080 ]! !

!HelpServer class methodsFor: 'settings' stamp: 'tbn 10/22/2012 20:18'!
onlineHelpPort: aPort
	"Sets the port to use for the online help. If the server is already running on
	  a different port then it is restarted."
	
	|requiresRestart|
	requiresRestart := OnlineHelpPort = aPort and: [ self isRunning ].
	requiresRestart ifTrue: [self stop].
	OnlineHelpPort := aPort.
	requiresRestart ifTrue: [self start].
	! !

!HelpServer class methodsFor: 'settings' stamp: 'tbn 10/22/2012 21:09'!
onlineHelpSettingsOn: aBuilder 
	"Build the possible settings"	
	<systemsettings>
	
	(aBuilder group: #help) 
		label: 'Online Help' translated;
		description: 'All online help related settings' translated;
		noOrdering;
		with: [ 			 
			(aBuilder setting: #onlineHelpPort)
					label: 'HTTP Port' translated;
					description: 'The HTTP port for the online help' translated.
	]! !

!HelpServer class methodsFor: 'accessing' stamp: 'tbn 10/22/2012 20:17'!
server
	"Return the server instance"
	
	^(ZnServer defaultOn: 8080) ! !

!HelpServer class methodsFor: 'running' stamp: 'tbn 10/23/2012 19:59'!
start
	"Start the online help server.
	
		HelpServer start
	"
	self isRunning ifTrue: [^self server].
	^self server
		delegate: self dispatcherClass new;
		start
       ! !

!HelpServer class methodsFor: 'running' stamp: 'tbn 10/22/2012 20:52'!
stop
	"Stop the online help server.
	
		HelpServer stop
	"
	
	self isRunning ifFalse: [^self server].	
	^self server
		stop
       ! !

Object subclass: #OHHelpRequestHandler
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OnlineHelp-Core'!

OHHelpRequestHandler subclass: #OHAPIHelpRequestHandler
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OnlineHelp-Core'!

!OHAPIHelpRequestHandler commentStamp: '<historical>' prior: 0!
This is an example of a request handler (here for the API help).

!

!OHAPIHelpRequestHandler methodsFor: 'request handling' stamp: 'tbn 10/29/2012 21:50'!
handleRequest: aRequest
 	
	| requestedClass |
	requestedClass := (aRequest uri queryAt: 'class' ifAbsent: 'Object').
 	^self htmlResponse: (self pageForClass: requestedClass).				
	 ! !

!OHAPIHelpRequestHandler methodsFor: 'request handling' stamp: 'tbn 10/23/2012 22:04'!
pageForClass: aClass
	| realClass |
	realClass := Smalltalk at: aClass asSymbol.
	
	^self helpPageWithContent: [:stream |
		stream << '<h1>' << realClass name << '</h1>'.
		realClass subclasses do: [:each |
			stream << '<li><a href="reference?class='.
			stream << each name.
			stream <<  '">'.
			stream << each name.
			stream << '</a>'
		]	
	]! !

!OHAPIHelpRequestHandler methodsFor: 'defaults' stamp: 'tbn 10/29/2012 21:38'!
prefix
	^'api'! !

OHHelpRequestHandler subclass: #OHFileRequestHandler
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OnlineHelp-Core'!

!OHFileRequestHandler methodsFor: 'private' stamp: 'tbn 10/29/2012 21:06'!
cssResponseFor: aContentSelector

	^self respondWith: (self perform: aContentSelector) usingMIMEType: 'text/css'
	! !

!OHFileRequestHandler methodsFor: 'uploads' stamp: 'tbn 10/29/2012 20:41'!
cssbootstrapminCssContent
	^ '/*!!
 * Bootstrap v2.1.1
 *
 * Copyright 2012 Twitter, Inc
 * Licensed under the Apache License v2.0
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Designed and built with all the love in the world @twitter by @mdo and @fat.
 */article,aside,details,figcaption,figure,footer,header,hgroup,nav,section{display:block}audio,canvas,video{display:inline-block;*display:inline;*zoom:1}audio:not([controls]){display:none}html{font-size:100%;-webkit-text-size-adjust:100%;-ms-text-size-adjust:100%}a:focus{outline:thin dotted #333;outline:5px auto -webkit-focus-ring-color;outline-offset:-2px}a:hover,a:active{outline:0}sub,sup{position:relative;font-size:75%;line-height:0;vertical-align:baseline}sup{top:-0.5em}sub{bottom:-0.25em}img{width:auto\9;height:auto;max-width:100%;vertical-align:middle;border:0;-ms-interpolation-mode:bicubic}#map_canvas img{max-width:none}button,input,select,textarea{margin:0;font-size:100%;vertical-align:middle}button,input{*overflow:visible;line-height:normal}button::-moz-focus-inner,input::-moz-focus-inner{padding:0;border:0}button,input[type="button"],input[type="reset"],input[type="submit"]{cursor:pointer;-webkit-appearance:button}input[type="search"]{-webkit-box-sizing:content-box;-moz-box-sizing:content-box;box-sizing:content-box;-webkit-appearance:textfield}input[type="search"]::-webkit-search-decoration,input[type="search"]::-webkit-search-cancel-button{-webkit-appearance:none}textarea{overflow:auto;vertical-align:top}.clearfix{*zoom:1}.clearfix:before,.clearfix:after{display:table;line-height:0;content:""}.clearfix:after{clear:both}.hide-text{font:0/0 a;color:transparent;text-shadow:none;background-color:transparent;border:0}.input-block-level{display:block;width:100%;min-height:30px;-webkit-box-sizing:border-box;-moz-box-sizing:border-box;box-sizing:border-box}body{margin:0;font-family:"Helvetica Neue",Helvetica,Arial,sans-serif;font-size:14px;line-height:20px;color:#333;background-color:#fff}a{color:#08c;text-decoration:none}a:hover{color:#005580;text-decoration:underline}.img-rounded{-webkit-border-radius:6px;-moz-border-radius:6px;border-radius:6px}.img-polaroid{padding:4px;background-color:#fff;border:1px solid #ccc;border:1px solid rgba(0,0,0,0.2);-webkit-box-shadow:0 1px 3px rgba(0,0,0,0.1);-moz-box-shadow:0 1px 3px rgba(0,0,0,0.1);box-shadow:0 1px 3px rgba(0,0,0,0.1)}.img-circle{-webkit-border-radius:500px;-moz-border-radius:500px;border-radius:500px}.row{margin-left:-20px;*zoom:1}.row:before,.row:after{display:table;line-height:0;content:""}.row:after{clear:both}[class*="span"]{float:left;min-height:1px;margin-left:20px}.container,.navbar-static-top .container,.navbar-fixed-top .container,.navbar-fixed-bottom .container{width:940px}.span12{width:940px}.span11{width:860px}.span10{width:780px}.span9{width:700px}.span8{width:620px}.span7{width:540px}.span6{width:460px}.span5{width:380px}.span4{width:300px}.span3{width:220px}.span2{width:140px}.span1{width:60px}.offset12{margin-left:980px}.offset11{margin-left:900px}.offset10{margin-left:820px}.offset9{margin-left:740px}.offset8{margin-left:660px}.offset7{margin-left:580px}.offset6{margin-left:500px}.offset5{margin-left:420px}.offset4{margin-left:340px}.offset3{margin-left:260px}.offset2{margin-left:180px}.offset1{margin-left:100px}.row-fluid{width:100%;*zoom:1}.row-fluid:before,.row-fluid:after{display:table;line-height:0;content:""}.row-fluid:after{clear:both}.row-fluid [class*="span"]{display:block;float:left;width:100%;min-height:30px;margin-left:2.127659574468085%;*margin-left:2.074468085106383%;-webkit-box-sizing:border-box;-moz-box-sizing:border-box;box-sizing:border-box}.row-fluid [class*="span"]:first-child{margin-left:0}.row-fluid .span12{width:100%;*width:99.94680851063829%}.row-fluid .span11{width:91.48936170212765%;*width:91.43617021276594%}.row-fluid .span10{width:82.97872340425532%;*width:82.92553191489361%}.row-fluid .span9{width:74.46808510638297%;*width:74.41489361702126%}.row-fluid .span8{width:65.95744680851064%;*width:65.90425531914893%}.row-fluid .span7{width:57.44680851063829%;*width:57.39361702127659%}.row-fluid .span6{width:48.93617021276595%;*width:48.88297872340425%}.row-fluid .span5{width:40.42553191489362%;*width:40.37234042553192%}.row-fluid .span4{width:31.914893617021278%;*width:31.861702127659576%}.row-fluid .span3{width:23.404255319148934%;*width:23.351063829787233%}.row-fluid .span2{width:14.893617021276595%;*width:14.840425531914894%}.row-fluid .span1{width:6.382978723404255%;*width:6.329787234042553%}.row-fluid .offset12{margin-left:104.25531914893617%;*margin-left:104.14893617021275%}.row-fluid .offset12:first-child{margin-left:102.12765957446808%;*margin-left:102.02127659574467%}.row-fluid .offset11{margin-left:95.74468085106382%;*margin-left:95.6382978723404%}.row-fluid .offset11:first-child{margin-left:93.61702127659574%;*margin-left:93.51063829787232%}.row-fluid .offset10{margin-left:87.23404255319149%;*margin-left:87.12765957446807%}.row-fluid .offset10:first-child{margin-left:85.1063829787234%;*margin-left:84.99999999999999%}.row-fluid .offset9{margin-left:78.72340425531914%;*margin-left:78.61702127659572%}.row-fluid .offset9:first-child{margin-left:76.59574468085106%;*margin-left:76.48936170212764%}.row-fluid .offset8{margin-left:70.2127659574468%;*margin-left:70.10638297872339%}.row-fluid .offset8:first-child{margin-left:68.08510638297872%;*margin-left:67.9787234042553%}.row-fluid .offset7{margin-left:61.70212765957446%;*margin-left:61.59574468085106%}.row-fluid .offset7:first-child{margin-left:59.574468085106375%;*margin-left:59.46808510638297%}.row-fluid .offset6{margin-left:53.191489361702125%;*margin-left:53.085106382978715%}.row-fluid .offset6:first-child{margin-left:51.063829787234035%;*margin-left:50.95744680851063%}.row-fluid .offset5{margin-left:44.68085106382979%;*margin-left:44.57446808510638%}.row-fluid .offset5:first-child{margin-left:42.5531914893617%;*margin-left:42.4468085106383%}.row-fluid .offset4{margin-left:36.170212765957444%;*margin-left:36.06382978723405%}.row-fluid .offset4:first-child{margin-left:34.04255319148936%;*margin-left:33.93617021276596%}.row-fluid .offset3{margin-left:27.659574468085104%;*margin-left:27.5531914893617%}.row-fluid .offset3:first-child{margin-left:25.53191489361702%;*margin-left:25.425531914893618%}.row-fluid .offset2{margin-left:19.148936170212764%;*margin-left:19.04255319148936%}.row-fluid .offset2:first-child{margin-left:17.02127659574468%;*margin-left:16.914893617021278%}.row-fluid .offset1{margin-left:10.638297872340425%;*margin-left:10.53191489361702%}.row-fluid .offset1:first-child{margin-left:8.51063829787234%;*margin-left:8.404255319148938%}[class*="span"].hide,.row-fluid [class*="span"].hide{display:none}[class*="span"].pull-right,.row-fluid [class*="span"].pull-right{float:right}.container{margin-right:auto;margin-left:auto;*zoom:1}.container:before,.container:after{display:table;line-height:0;content:""}.container:after{clear:both}.container-fluid{padding-right:20px;padding-left:20px;*zoom:1}.container-fluid:before,.container-fluid:after{display:table;line-height:0;content:""}.container-fluid:after{clear:both}p{margin:0 0 10px}.lead{margin-bottom:20px;font-size:21px;font-weight:200;line-height:30px}small{font-size:85%}strong{font-weight:bold}em{font-style:italic}cite{font-style:normal}.muted{color:#999}.text-warning{color:#c09853}.text-error{color:#b94a48}.text-info{color:#3a87ad}.text-success{color:#468847}h1,h2,h3,h4,h5,h6{margin:10px 0;font-family:inherit;font-weight:bold;line-height:1;color:inherit;text-rendering:optimizelegibility}h1 small,h2 small,h3 small,h4 small,h5 small,h6 small{font-weight:normal;line-height:1;color:#999}h1{font-size:36px;line-height:40px}h2{font-size:30px;line-height:40px}h3{font-size:24px;line-height:40px}h4{font-size:18px;line-height:20px}h5{font-size:14px;line-height:20px}h6{font-size:12px;line-height:20px}h1 small{font-size:24px}h2 small{font-size:18px}h3 small{font-size:14px}h4 small{font-size:14px}.page-header{padding-bottom:9px;margin:20px 0 30px;border-bottom:1px solid #eee}ul,ol{padding:0;margin:0 0 10px 25px}ul ul,ul ol,ol ol,ol ul{margin-bottom:0}li{line-height:20px}ul.unstyled,ol.unstyled{margin-left:0;list-style:none}dl{margin-bottom:20px}dt,dd{line-height:20px}dt{font-weight:bold}dd{margin-left:10px}.dl-horizontal{*zoom:1}.dl-horizontal:before,.dl-horizontal:after{display:table;line-height:0;content:""}.dl-horizontal:after{clear:both}.dl-horizontal dt{float:left;width:160px;overflow:hidden;clear:left;text-align:right;text-overflow:ellipsis;white-space:nowrap}.dl-horizontal dd{margin-left:180px}hr{margin:20px 0;border:0;border-top:1px solid #eee;border-bottom:1px solid #fff}abbr[title]{cursor:help;border-bottom:1px dotted #999}abbr.initialism{font-size:90%;text-transform:uppercase}blockquote{padding:0 0 0 15px;margin:0 0 20px;border-left:5px solid #eee}blockquote p{margin-bottom:0;font-size:16px;font-weight:300;line-height:25px}blockquote small{display:block;line-height:20px;color:#999}blockquote small:before{content:''\2014 \00A0''}blockquote.pull-right{float:right;padding-right:15px;padding-left:0;border-right:5px solid #eee;border-left:0}blockquote.pull-right p,blockquote.pull-right small{text-align:right}blockquote.pull-right small:before{content:''''}blockquote.pull-right small:after{content:''\00A0 \2014''}q:before,q:after,blockquote:before,blockquote:after{content:""}address{display:block;margin-bottom:20px;font-style:normal;line-height:20px}code,pre{padding:0 3px 2px;font-family:Monaco,Menlo,Consolas,"Courier New",monospace;font-size:12px;color:#333;-webkit-border-radius:3px;-moz-border-radius:3px;border-radius:3px}code{padding:2px 4px;color:#d14;background-color:#f7f7f9;border:1px solid #e1e1e8}pre{display:block;padding:9.5px;margin:0 0 10px;font-size:13px;line-height:20px;word-break:break-all;word-wrap:break-word;white-space:pre;white-space:pre-wrap;background-color:#f5f5f5;border:1px solid #ccc;border:1px solid rgba(0,0,0,0.15);-webkit-border-radius:4px;-moz-border-radius:4px;border-radius:4px}pre.prettyprint{margin-bottom:20px}pre code{padding:0;color:inherit;background-color:transparent;border:0}.pre-scrollable{max-height:340px;overflow-y:scroll}form{margin:0 0 20px}fieldset{padding:0;margin:0;border:0}legend{display:block;width:100%;padding:0;margin-bottom:20px;font-size:21px;line-height:40px;color:#333;border:0;border-bottom:1px solid #e5e5e5}legend small{font-size:15px;color:#999}label,input,button,select,textarea{font-size:14px;font-weight:normal;line-height:20px}input,button,select,textarea{font-family:"Helvetica Neue",Helvetica,Arial,sans-serif}label{display:block;margin-bottom:5px}select,textarea,input[type="text"],input[type="password"],input[type="datetime"],input[type="datetime-local"],input[type="date"],input[type="month"],input[type="time"],input[type="week"],input[type="number"],input[type="email"],input[type="url"],input[type="search"],input[type="tel"],input[type="color"],.uneditable-input{display:inline-block;height:20px;padding:4px 6px;margin-bottom:9px;font-size:14px;line-height:20px;color:#555;-webkit-border-radius:3px;-moz-border-radius:3px;border-radius:3px}input,textarea,.uneditable-input{width:206px}textarea{height:auto}textarea,input[type="text"],input[type="password"],input[type="datetime"],input[type="datetime-local"],input[type="date"],input[type="month"],input[type="time"],input[type="week"],input[type="number"],input[type="email"],input[type="url"],input[type="search"],input[type="tel"],input[type="color"],.uneditable-input{background-color:#fff;border:1px solid #ccc;-webkit-box-shadow:inset 0 1px 1px rgba(0,0,0,0.075);-moz-box-shadow:inset 0 1px 1px rgba(0,0,0,0.075);box-shadow:inset 0 1px 1px rgba(0,0,0,0.075);-webkit-transition:border linear .2s,box-shadow linear .2s;-moz-transition:border linear .2s,box-shadow linear .2s;-o-transition:border linear .2s,box-shadow linear .2s;transition:border linear .2s,box-shadow linear .2s}textarea:focus,input[type="text"]:focus,input[type="password"]:focus,input[type="datetime"]:focus,input[type="datetime-local"]:focus,input[type="date"]:focus,input[type="month"]:focus,input[type="time"]:focus,input[type="week"]:focus,input[type="number"]:focus,input[type="email"]:focus,input[type="url"]:focus,input[type="search"]:focus,input[type="tel"]:focus,input[type="color"]:focus,.uneditable-input:focus{border-color:rgba(82,168,236,0.8);outline:0;outline:thin dotted \9;-webkit-box-shadow:inset 0 1px 1px rgba(0,0,0,0.075),0 0 8px rgba(82,168,236,0.6);-moz-box-shadow:inset 0 1px 1px rgba(0,0,0,0.075),0 0 8px rgba(82,168,236,0.6);box-shadow:inset 0 1px 1px rgba(0,0,0,0.075),0 0 8px rgba(82,168,236,0.6)}input[type="radio"],input[type="checkbox"]{margin:4px 0 0;margin-top:1px \9;*margin-top:0;line-height:normal;cursor:pointer}input[type="file"],input[type="image"],input[type="submit"],input[type="reset"],input[type="button"],input[type="radio"],input[type="checkbox"]{width:auto}select,input[type="file"]{height:30px;*margin-top:4px;line-height:30px}select{width:220px;background-color:#fff;border:1px solid #ccc}select[multiple],select[size]{height:auto}select:focus,input[type="file"]:focus,input[type="radio"]:focus,input[type="checkbox"]:focus{outline:thin dotted #333;outline:5px auto -webkit-focus-ring-color;outline-offset:-2px}.uneditable-input,.uneditable-textarea{color:#999;cursor:not-allowed;background-color:#fcfcfc;border-color:#ccc;-webkit-box-shadow:inset 0 1px 2px rgba(0,0,0,0.025);-moz-box-shadow:inset 0 1px 2px rgba(0,0,0,0.025);box-shadow:inset 0 1px 2px rgba(0,0,0,0.025)}.uneditable-input{overflow:hidden;white-space:nowrap}.uneditable-textarea{width:auto;height:auto}input:-moz-placeholder,textarea:-moz-placeholder{color:#999}input:-ms-input-placeholder,textarea:-ms-input-placeholder{color:#999}input::-webkit-input-placeholder,textarea::-webkit-input-placeholder{color:#999}.radio,.checkbox{min-height:18px;padding-left:18px}.radio input[type="radio"],.checkbox input[type="checkbox"]{float:left;margin-left:-18px}.controls>.radio:first-child,.controls>.checkbox:first-child{padding-top:5px}.radio.inline,.checkbox.inline{display:inline-block;padding-top:5px;margin-bottom:0;vertical-align:middle}.radio.inline+.radio.inline,.checkbox.inline+.checkbox.inline{margin-left:10px}.input-mini{width:60px}.input-small{width:90px}.input-medium{width:150px}.input-large{width:210px}.input-xlarge{width:270px}.input-xxlarge{width:530px}input[class*="span"],select[class*="span"],textarea[class*="span"],.uneditable-input[class*="span"],.row-fluid input[class*="span"],.row-fluid select[class*="span"],.row-fluid textarea[class*="span"],.row-fluid .uneditable-input[class*="span"]{float:none;margin-left:0}.input-append input[class*="span"],.input-append .uneditable-input[class*="span"],.input-prepend input[class*="span"],.input-prepend .uneditable-input[class*="span"],.row-fluid input[class*="span"],.row-fluid select[class*="span"],.row-fluid textarea[class*="span"],.row-fluid .uneditable-input[class*="span"],.row-fluid .input-prepend [class*="span"],.row-fluid .input-append [class*="span"]{display:inline-block}input,textarea,.uneditable-input{margin-left:0}.controls-row [class*="span"]+[class*="span"]{margin-left:20px}input.span12,textarea.span12,.uneditable-input.span12{width:926px}input.span11,textarea.span11,.uneditable-input.span11{width:846px}input.span10,textarea.span10,.uneditable-input.span10{width:766px}input.span9,textarea.span9,.uneditable-input.span9{width:686px}input.span8,textarea.span8,.uneditable-input.span8{width:606px}input.span7,textarea.span7,.uneditable-input.span7{width:526px}input.span6,textarea.span6,.uneditable-input.span6{width:446px}input.span5,textarea.span5,.uneditable-input.span5{width:366px}input.span4,textarea.span4,.uneditable-input.span4{width:286px}input.span3,textarea.span3,.uneditable-input.span3{width:206px}input.span2,textarea.span2,.uneditable-input.span2{width:126px}input.span1,textarea.span1,.uneditable-input.span1{width:46px}.controls-row{*zoom:1}.controls-row:before,.controls-row:after{display:table;line-height:0;content:""}.controls-row:after{clear:both}.controls-row [class*="span"]{float:left}input[disabled],select[disabled],textarea[disabled],input[readonly],select[readonly],textarea[readonly]{cursor:not-allowed;background-color:#eee}input[type="radio"][disabled],input[type="checkbox"][disabled],input[type="radio"][readonly],input[type="checkbox"][readonly]{background-color:transparent}.control-group.warning>label,.control-group.warning .help-block,.control-group.warning .help-inline{color:#c09853}.control-group.warning .checkbox,.control-group.warning .radio,.control-group.warning input,.control-group.warning select,.control-group.warning textarea{color:#c09853}.control-group.warning input,.control-group.warning select,.control-group.warning textarea{border-color:#c09853;-webkit-box-shadow:inset 0 1px 1px rgba(0,0,0,0.075);-moz-box-shadow:inset 0 1px 1px rgba(0,0,0,0.075);box-shadow:inset 0 1px 1px rgba(0,0,0,0.075)}.control-group.warning input:focus,.control-group.warning select:focus,.control-group.warning textarea:focus{border-color:#a47e3c;-webkit-box-shadow:inset 0 1px 1px rgba(0,0,0,0.075),0 0 6px #dbc59e;-moz-box-shadow:inset 0 1px 1px rgba(0,0,0,0.075),0 0 6px #dbc59e;box-shadow:inset 0 1px 1px rgba(0,0,0,0.075),0 0 6px #dbc59e}.control-group.warning .input-prepend .add-on,.control-group.warning .input-append .add-on{color:#c09853;background-color:#fcf8e3;border-color:#c09853}.control-group.error>label,.control-group.error .help-block,.control-group.error .help-inline{color:#b94a48}.control-group.error .checkbox,.control-group.error .radio,.control-group.error input,.control-group.error select,.control-group.error textarea{color:#b94a48}.control-group.error input,.control-group.error select,.control-group.error textarea{border-color:#b94a48;-webkit-box-shadow:inset 0 1px 1px rgba(0,0,0,0.075);-moz-box-shadow:inset 0 1px 1px rgba(0,0,0,0.075);box-shadow:inset 0 1px 1px rgba(0,0,0,0.075)}.control-group.error input:focus,.control-group.error select:focus,.control-group.error textarea:focus{border-color:#953b39;-webkit-box-shadow:inset 0 1px 1px rgba(0,0,0,0.075),0 0 6px #d59392;-moz-box-shadow:inset 0 1px 1px rgba(0,0,0,0.075),0 0 6px #d59392;box-shadow:inset 0 1px 1px rgba(0,0,0,0.075),0 0 6px #d59392}.control-group.error .input-prepend .add-on,.control-group.error .input-append .add-on{color:#b94a48;background-color:#f2dede;border-color:#b94a48}.control-group.success>label,.control-group.success .help-block,.control-group.success .help-inline{color:#468847}.control-group.success .checkbox,.control-group.success .radio,.control-group.success input,.control-group.success select,.control-group.success textarea{color:#468847}.control-group.success input,.control-group.success select,.control-group.success textarea{border-color:#468847;-webkit-box-shadow:inset 0 1px 1px rgba(0,0,0,0.075);-moz-box-shadow:inset 0 1px 1px rgba(0,0,0,0.075);box-shadow:inset 0 1px 1px rgba(0,0,0,0.075)}.control-group.success input:focus,.control-group.success select:focus,.control-group.success textarea:focus{border-color:#356635;-webkit-box-shadow:inset 0 1px 1px rgba(0,0,0,0.075),0 0 6px #7aba7b;-moz-box-shadow:inset 0 1px 1px rgba(0,0,0,0.075),0 0 6px #7aba7b;box-shadow:inset 0 1px 1px rgba(0,0,0,0.075),0 0 6px #7aba7b}.control-group.success .input-prepend .add-on,.control-group.success .input-append .add-on{color:#468847;background-color:#dff0d8;border-color:#468847}.control-group.info>label,.control-group.info .help-block,.control-group.info .help-inline{color:#3a87ad}.control-group.info .checkbox,.control-group.info .radio,.control-group.info input,.control-group.info select,.control-group.info textarea{color:#3a87ad}.control-group.info input,.control-group.info select,.control-group.info textarea{border-color:#3a87ad;-webkit-box-shadow:inset 0 1px 1px rgba(0,0,0,0.075);-moz-box-shadow:inset 0 1px 1px rgba(0,0,0,0.075);box-shadow:inset 0 1px 1px rgba(0,0,0,0.075)}.control-group.info input:focus,.control-group.info select:focus,.control-group.info textarea:focus{border-color:#2d6987;-webkit-box-shadow:inset 0 1px 1px rgba(0,0,0,0.075),0 0 6px #7ab5d3;-moz-box-shadow:inset 0 1px 1px rgba(0,0,0,0.075),0 0 6px #7ab5d3;box-shadow:inset 0 1px 1px rgba(0,0,0,0.075),0 0 6px #7ab5d3}.control-group.info .input-prepend .add-on,.control-group.info .input-append .add-on{color:#3a87ad;background-color:#d9edf7;border-color:#3a87ad}input:focus:required:invalid,textarea:focus:required:invalid,select:focus:required:invalid{color:#b94a48;border-color:#ee5f5b}input:focus:required:invalid:focus,textarea:focus:required:invalid:focus,select:focus:required:invalid:focus{border-color:#e9322d;-webkit-box-shadow:0 0 6px #f8b9b7;-moz-box-shadow:0 0 6px #f8b9b7;box-shadow:0 0 6px #f8b9b7}.form-actions{padding:19px 20px 20px;margin-top:20px;margin-bottom:20px;background-color:#f5f5f5;border-top:1px solid #e5e5e5;*zoom:1}.form-actions:before,.form-actions:after{display:table;line-height:0;content:""}.form-actions:after{clear:both}.help-block,.help-inline{color:#595959}.help-block{display:block;margin-bottom:10px}.help-inline{display:inline-block;*display:inline;padding-left:5px;vertical-align:middle;*zoom:1}.input-append,.input-prepend{margin-bottom:5px;font-size:0;white-space:nowrap}.input-append input,.input-prepend input,.input-append select,.input-prepend select,.input-append .uneditable-input,.input-prepend .uneditable-input{position:relative;margin-bottom:0;*margin-left:0;font-size:14px;vertical-align:top;-webkit-border-radius:0 3px 3px 0;-moz-border-radius:0 3px 3px 0;border-radius:0 3px 3px 0}.input-append input:focus,.input-prepend input:focus,.input-append select:focus,.input-prepend select:focus,.input-append .uneditable-input:focus,.input-prepend .uneditable-input:focus{z-index:2}.input-append .add-on,.input-prepend .add-on{display:inline-block;width:auto;height:20px;min-width:16px;padding:4px 5px;font-size:14px;font-weight:normal;line-height:20px;text-align:center;text-shadow:0 1px 0 #fff;background-color:#eee;border:1px solid #ccc}.input-append .add-on,.input-prepend .add-on,.input-append .btn,.input-prepend .btn{vertical-align:top;-webkit-border-radius:0;-moz-border-radius:0;border-radius:0}.input-append .active,.input-prepend .active{background-color:#a9dba9;border-color:#46a546}.input-prepend .add-on,.input-prepend .btn{margin-right:-1px}.input-prepend .add-on:first-child,.input-prepend .btn:first-child{-webkit-border-radius:3px 0 0 3px;-moz-border-radius:3px 0 0 3px;border-radius:3px 0 0 3px}.input-append input,.input-append select,.input-append .uneditable-input{-webkit-border-radius:3px 0 0 3px;-moz-border-radius:3px 0 0 3px;border-radius:3px 0 0 3px}.input-append .add-on,.input-append .btn{margin-left:-1px}.input-append .add-on:last-child,.input-append .btn:last-child{-webkit-border-radius:0 3px 3px 0;-moz-border-radius:0 3px 3px 0;border-radius:0 3px 3px 0}.input-prepend.input-append input,.input-prepend.input-append select,.input-prepend.input-append .uneditable-input{-webkit-border-radius:0;-moz-border-radius:0;border-radius:0}.input-prepend.input-append .add-on:first-child,.input-prepend.input-append .btn:first-child{margin-right:-1px;-webkit-border-radius:3px 0 0 3px;-moz-border-radius:3px 0 0 3px;border-radius:3px 0 0 3px}.input-prepend.input-append .add-on:last-child,.input-prepend.input-append .btn:last-child{margin-left:-1px;-webkit-border-radius:0 3px 3px 0;-moz-border-radius:0 3px 3px 0;border-radius:0 3px 3px 0}input.search-query{padding-right:14px;padding-right:4px \9;padding-left:14px;padding-left:4px \9;margin-bottom:0;-webkit-border-radius:15px;-moz-border-radius:15px;border-radius:15px}.form-search .input-append .search-query,.form-search .input-prepend .search-query{-webkit-border-radius:0;-moz-border-radius:0;border-radius:0}.form-search .input-append .search-query{-webkit-border-radius:14px 0 0 14px;-moz-border-radius:14px 0 0 14px;border-radius:14px 0 0 14px}.form-search .input-append .btn{-webkit-border-radius:0 14px 14px 0;-moz-border-radius:0 14px 14px 0;border-radius:0 14px 14px 0}.form-search .input-prepend .search-query{-webkit-border-radius:0 14px 14px 0;-moz-border-radius:0 14px 14px 0;border-radius:0 14px 14px 0}.form-search .input-prepend .btn{-webkit-border-radius:14px 0 0 14px;-moz-border-radius:14px 0 0 14px;border-radius:14px 0 0 14px}.form-search input,.form-inline input,.form-horizontal input,.form-search textarea,.form-inline textarea,.form-horizontal textarea,.form-search select,.form-inline select,.form-horizontal select,.form-search .help-inline,.form-inline .help-inline,.form-horizontal .help-inline,.form-search .uneditable-input,.form-inline .uneditable-input,.form-horizontal .uneditable-input,.form-search .input-prepend,.form-inline .input-prepend,.form-horizontal .input-prepend,.form-search .input-append,.form-inline .input-append,.form-horizontal .input-append{display:inline-block;*display:inline;margin-bottom:0;vertical-align:middle;*zoom:1}.form-search .hide,.form-inline .hide,.form-horizontal .hide{display:none}.form-search label,.form-inline label,.form-search .btn-group,.form-inline .btn-group{display:inline-block}.form-search .input-append,.form-inline .input-append,.form-search .input-prepend,.form-inline .input-prepend{margin-bottom:0}.form-search .radio,.form-search .checkbox,.form-inline .radio,.form-inline .checkbox{padding-left:0;margin-bottom:0;vertical-align:middle}.form-search .radio input[type="radio"],.form-search .checkbox input[type="checkbox"],.form-inline .radio input[type="radio"],.form-inline .checkbox input[type="checkbox"]{float:left;margin-right:3px;margin-left:0}.control-group{margin-bottom:10px}legend+.control-group{margin-top:20px;-webkit-margin-top-collapse:separate}.form-horizontal .control-group{margin-bottom:20px;*zoom:1}.form-horizontal .control-group:before,.form-horizontal .control-group:after{display:table;line-height:0;content:""}.form-horizontal .control-group:after{clear:both}.form-horizontal .control-label{float:left;width:160px;padding-top:5px;text-align:right}.form-horizontal .controls{*display:inline-block;*padding-left:20px;margin-left:180px;*margin-left:0}.form-horizontal .controls:first-child{*padding-left:180px}.form-horizontal .help-block{margin-bottom:0}.form-horizontal input+.help-block,.form-horizontal select+.help-block,.form-horizontal textarea+.help-block{margin-top:10px}.form-horizontal .form-actions{padding-left:180px}table{max-width:100%;background-color:transparent;border-collapse:collapse;border-spacing:0}.table{width:100%;margin-bottom:20px}.table th,.table td{padding:8px;line-height:20px;text-align:left;vertical-align:top;border-top:1px solid #ddd}.table th{font-weight:bold}.table thead th{vertical-align:bottom}.table caption+thead tr:first-child th,.table caption+thead tr:first-child td,.table colgroup+thead tr:first-child th,.table colgroup+thead tr:first-child td,.table thead:first-child tr:first-child th,.table thead:first-child tr:first-child td{border-top:0}.table tbody+tbody{border-top:2px solid #ddd}.table-condensed th,.table-condensed td{padding:4px 5px}.table-bordered{border:1px solid #ddd;border-collapse:separate;*border-collapse:collapse;border-left:0;-webkit-border-radius:4px;-moz-border-radius:4px;border-radius:4px}.table-bordered th,.table-bordered td{border-left:1px solid #ddd}.table-bordered caption+thead tr:first-child th,.table-bordered caption+tbody tr:first-child th,.table-bordered caption+tbody tr:first-child td,.table-bordered colgroup+thead tr:first-child th,.table-bordered colgroup+tbody tr:first-child th,.table-bordered colgroup+tbody tr:first-child td,.table-bordered thead:first-child tr:first-child th,.table-bordered tbody:first-child tr:first-child th,.table-bordered tbody:first-child tr:first-child td{border-top:0}.table-bordered thead:first-child tr:first-child th:first-child,.table-bordered tbody:first-child tr:first-child td:first-child{-webkit-border-top-left-radius:4px;border-top-left-radius:4px;-moz-border-radius-topleft:4px}.table-bordered thead:first-child tr:first-child th:last-child,.table-bordered tbody:first-child tr:first-child td:last-child{-webkit-border-top-right-radius:4px;border-top-right-radius:4px;-moz-border-radius-topright:4px}.table-bordered thead:last-child tr:last-child th:first-child,.table-bordered tbody:last-child tr:last-child td:first-child,.table-bordered tfoot:last-child tr:last-child td:first-child{-webkit-border-radius:0 0 0 4px;-moz-border-radius:0 0 0 4px;border-radius:0 0 0 4px;-webkit-border-bottom-left-radius:4px;border-bottom-left-radius:4px;-moz-border-radius-bottomleft:4px}.table-bordered thead:last-child tr:last-child th:last-child,.table-bordered tbody:last-child tr:last-child td:last-child,.table-bordered tfoot:last-child tr:last-child td:last-child{-webkit-border-bottom-right-radius:4px;border-bottom-right-radius:4px;-moz-border-radius-bottomright:4px}.table-bordered caption+thead tr:first-child th:first-child,.table-bordered caption+tbody tr:first-child td:first-child,.table-bordered colgroup+thead tr:first-child th:first-child,.table-bordered colgroup+tbody tr:first-child td:first-child{-webkit-border-top-left-radius:4px;border-top-left-radius:4px;-moz-border-radius-topleft:4px}.table-bordered caption+thead tr:first-child th:last-child,.table-bordered caption+tbody tr:first-child td:last-child,.table-bordered colgroup+thead tr:first-child th:last-child,.table-bordered colgroup+tbody tr:first-child td:last-child{-webkit-border-top-right-radius:4px;border-top-right-radius:4px;-moz-border-radius-topleft:4px}.table-striped tbody tr:nth-child(odd) td,.table-striped tbody tr:nth-child(odd) th{background-color:#f9f9f9}.table-hover tbody tr:hover td,.table-hover tbody tr:hover th{background-color:#f5f5f5}table [class*=span],.row-fluid table [class*=span]{display:table-cell;float:none;margin-left:0}.table .span1{float:none;width:44px;margin-left:0}.table .span2{float:none;width:124px;margin-left:0}.table .span3{float:none;width:204px;margin-left:0}.table .span4{float:none;width:284px;margin-left:0}.table .span5{float:none;width:364px;margin-left:0}.table .span6{float:none;width:444px;margin-left:0}.table .span7{float:none;width:524px;margin-left:0}.table .span8{float:none;width:604px;margin-left:0}.table .span9{float:none;width:684px;margin-left:0}.table .span10{float:none;width:764px;margin-left:0}.table .span11{float:none;width:844px;margin-left:0}.table .span12{float:none;width:924px;margin-left:0}.table .span13{float:none;width:1004px;margin-left:0}.table .span14{float:none;width:1084px;margin-left:0}.table .span15{float:none;width:1164px;margin-left:0}.table .span16{float:none;width:1244px;margin-left:0}.table .span17{float:none;width:1324px;margin-left:0}.table .span18{float:none;width:1404px;margin-left:0}.table .span19{float:none;width:1484px;margin-left:0}.table .span20{float:none;width:1564px;margin-left:0}.table .span21{float:none;width:1644px;margin-left:0}.table .span22{float:none;width:1724px;margin-left:0}.table .span23{float:none;width:1804px;margin-left:0}.table .span24{float:none;width:1884px;margin-left:0}.table tbody tr.success td{background-color:#dff0d8}.table tbody tr.error td{background-color:#f2dede}.table tbody tr.warning td{background-color:#fcf8e3}.table tbody tr.info td{background-color:#d9edf7}.table-hover tbody tr.success:hover td{background-color:#d0e9c6}.table-hover tbody tr.error:hover td{background-color:#ebcccc}.table-hover tbody tr.warning:hover td{background-color:#faf2cc}.table-hover tbody tr.info:hover td{background-color:#c4e3f3}[class^="icon-"],[class*=" icon-"]{display:inline-block;width:14px;height:14px;margin-top:1px;*margin-right:.3em;line-height:14px;vertical-align:text-top;background-image:url("../img/glyphicons-halflings.png");background-position:14px 14px;background-repeat:no-repeat}.icon-white,.nav-tabs>.active>a>[class^="icon-"],.nav-tabs>.active>a>[class*=" icon-"],.nav-pills>.active>a>[class^="icon-"],.nav-pills>.active>a>[class*=" icon-"],.nav-list>.active>a>[class^="icon-"],.nav-list>.active>a>[class*=" icon-"],.navbar-inverse .nav>.active>a>[class^="icon-"],.navbar-inverse .nav>.active>a>[class*=" icon-"],.dropdown-menu>li>a:hover>[class^="icon-"],.dropdown-menu>li>a:hover>[class*=" icon-"],.dropdown-menu>.active>a>[class^="icon-"],.dropdown-menu>.active>a>[class*=" icon-"]{background-image:url("../img/glyphicons-halflings-white.png")}.icon-glass{background-position:0 0}.icon-music{background-position:-24px 0}.icon-search{background-position:-48px 0}.icon-envelope{background-position:-72px 0}.icon-heart{background-position:-96px 0}.icon-star{background-position:-120px 0}.icon-star-empty{background-position:-144px 0}.icon-user{background-position:-168px 0}.icon-film{background-position:-192px 0}.icon-th-large{background-position:-216px 0}.icon-th{background-position:-240px 0}.icon-th-list{background-position:-264px 0}.icon-ok{background-position:-288px 0}.icon-remove{background-position:-312px 0}.icon-zoom-in{background-position:-336px 0}.icon-zoom-out{background-position:-360px 0}.icon-off{background-position:-384px 0}.icon-signal{background-position:-408px 0}.icon-cog{background-position:-432px 0}.icon-trash{background-position:-456px 0}.icon-home{background-position:0 -24px}.icon-file{background-position:-24px -24px}.icon-time{background-position:-48px -24px}.icon-road{background-position:-72px -24px}.icon-download-alt{background-position:-96px -24px}.icon-download{background-position:-120px -24px}.icon-upload{background-position:-144px -24px}.icon-inbox{background-position:-168px -24px}.icon-play-circle{background-position:-192px -24px}.icon-repeat{background-position:-216px -24px}.icon-refresh{background-position:-240px -24px}.icon-list-alt{background-position:-264px -24px}.icon-lock{background-position:-287px -24px}.icon-flag{background-position:-312px -24px}.icon-headphones{background-position:-336px -24px}.icon-volume-off{background-position:-360px -24px}.icon-volume-down{background-position:-384px -24px}.icon-volume-up{background-position:-408px -24px}.icon-qrcode{background-position:-432px -24px}.icon-barcode{background-position:-456px -24px}.icon-tag{background-position:0 -48px}.icon-tags{background-position:-25px -48px}.icon-book{background-position:-48px -48px}.icon-bookmark{background-position:-72px -48px}.icon-print{background-position:-96px -48px}.icon-camera{background-position:-120px -48px}.icon-font{background-position:-144px -48px}.icon-bold{background-position:-167px -48px}.icon-italic{background-position:-192px -48px}.icon-text-height{background-position:-216px -48px}.icon-text-width{background-position:-240px -48px}.icon-align-left{background-position:-264px -48px}.icon-align-center{background-position:-288px -48px}.icon-align-right{background-position:-312px -48px}.icon-align-justify{background-position:-336px -48px}.icon-list{background-position:-360px -48px}.icon-indent-left{background-position:-384px -48px}.icon-indent-right{background-position:-408px -48px}.icon-facetime-video{background-position:-432px -48px}.icon-picture{background-position:-456px -48px}.icon-pencil{background-position:0 -72px}.icon-map-marker{background-position:-24px -72px}.icon-adjust{background-position:-48px -72px}.icon-tint{background-position:-72px -72px}.icon-edit{background-position:-96px -72px}.icon-share{background-position:-120px -72px}.icon-check{background-position:-144px -72px}.icon-move{background-position:-168px -72px}.icon-step-backward{background-position:-192px -72px}.icon-fast-backward{background-position:-216px -72px}.icon-backward{background-position:-240px -72px}.icon-play{background-position:-264px -72px}.icon-pause{background-position:-288px -72px}.icon-stop{background-position:-312px -72px}.icon-forward{background-position:-336px -72px}.icon-fast-forward{background-position:-360px -72px}.icon-step-forward{background-position:-384px -72px}.icon-eject{background-position:-408px -72px}.icon-chevron-left{background-position:-432px -72px}.icon-chevron-right{background-position:-456px -72px}.icon-plus-sign{background-position:0 -96px}.icon-minus-sign{background-position:-24px -96px}.icon-remove-sign{background-position:-48px -96px}.icon-ok-sign{background-position:-72px -96px}.icon-question-sign{background-position:-96px -96px}.icon-info-sign{background-position:-120px -96px}.icon-screenshot{background-position:-144px -96px}.icon-remove-circle{background-position:-168px -96px}.icon-ok-circle{background-position:-192px -96px}.icon-ban-circle{background-position:-216px -96px}.icon-arrow-left{background-position:-240px -96px}.icon-arrow-right{background-position:-264px -96px}.icon-arrow-up{background-position:-289px -96px}.icon-arrow-down{background-position:-312px -96px}.icon-share-alt{background-position:-336px -96px}.icon-resize-full{background-position:-360px -96px}.icon-resize-small{background-position:-384px -96px}.icon-plus{background-position:-408px -96px}.icon-minus{background-position:-433px -96px}.icon-asterisk{background-position:-456px -96px}.icon-exclamation-sign{background-position:0 -120px}.icon-gift{background-position:-24px -120px}.icon-leaf{background-position:-48px -120px}.icon-fire{background-position:-72px -120px}.icon-eye-open{background-position:-96px -120px}.icon-eye-close{background-position:-120px -120px}.icon-warning-sign{background-position:-144px -120px}.icon-plane{background-position:-168px -120px}.icon-calendar{background-position:-192px -120px}.icon-random{width:16px;background-position:-216px -120px}.icon-comment{background-position:-240px -120px}.icon-magnet{background-position:-264px -120px}.icon-chevron-up{background-position:-288px -120px}.icon-chevron-down{background-position:-313px -119px}.icon-retweet{background-position:-336px -120px}.icon-shopping-cart{background-position:-360px -120px}.icon-folder-close{background-position:-384px -120px}.icon-folder-open{width:16px;background-position:-408px -120px}.icon-resize-vertical{background-position:-432px -119px}.icon-resize-horizontal{background-position:-456px -118px}.icon-hdd{background-position:0 -144px}.icon-bullhorn{background-position:-24px -144px}.icon-bell{background-position:-48px -144px}.icon-certificate{background-position:-72px -144px}.icon-thumbs-up{background-position:-96px -144px}.icon-thumbs-down{background-position:-120px -144px}.icon-hand-right{background-position:-144px -144px}.icon-hand-left{background-position:-168px -144px}.icon-hand-up{background-position:-192px -144px}.icon-hand-down{background-position:-216px -144px}.icon-circle-arrow-right{background-position:-240px -144px}.icon-circle-arrow-left{background-position:-264px -144px}.icon-circle-arrow-up{background-position:-288px -144px}.icon-circle-arrow-down{background-position:-312px -144px}.icon-globe{background-position:-336px -144px}.icon-wrench{background-position:-360px -144px}.icon-tasks{background-position:-384px -144px}.icon-filter{background-position:-408px -144px}.icon-briefcase{background-position:-432px -144px}.icon-fullscreen{background-position:-456px -144px}.dropup,.dropdown{position:relative}.dropdown-toggle{*margin-bottom:-3px}.dropdown-toggle:active,.open .dropdown-toggle{outline:0}.caret{display:inline-block;width:0;height:0;vertical-align:top;border-top:4px solid #000;border-right:4px solid transparent;border-left:4px solid transparent;content:""}.dropdown .caret{margin-top:8px;margin-left:2px}.dropdown-menu{position:absolute;top:100%;left:0;z-index:1000;display:none;float:left;min-width:160px;padding:5px 0;margin:2px 0 0;list-style:none;background-color:#fff;border:1px solid #ccc;border:1px solid rgba(0,0,0,0.2);*border-right-width:2px;*border-bottom-width:2px;-webkit-border-radius:6px;-moz-border-radius:6px;border-radius:6px;-webkit-box-shadow:0 5px 10px rgba(0,0,0,0.2);-moz-box-shadow:0 5px 10px rgba(0,0,0,0.2);box-shadow:0 5px 10px rgba(0,0,0,0.2);-webkit-background-clip:padding-box;-moz-background-clip:padding;background-clip:padding-box}.dropdown-menu.pull-right{right:0;left:auto}.dropdown-menu .divider{*width:100%;height:1px;margin:9px 1px;*margin:-5px 0 5px;overflow:hidden;background-color:#e5e5e5;border-bottom:1px solid #fff}.dropdown-menu a{display:block;padding:3px 20px;clear:both;font-weight:normal;line-height:20px;color:#333;white-space:nowrap}.dropdown-menu li>a:hover,.dropdown-menu li>a:focus,.dropdown-submenu:hover>a{color:#fff;text-decoration:none;background-color:#08c;background-color:#0081c2;background-image:-moz-linear-gradient(top,#08c,#0077b3);background-image:-webkit-gradient(linear,0 0,0 100%,from(#08c),to(#0077b3));background-image:-webkit-linear-gradient(top,#08c,#0077b3);background-image:-o-linear-gradient(top,#08c,#0077b3);background-image:linear-gradient(to bottom,#08c,#0077b3);background-repeat:repeat-x;filter:progid:dximagetransform.microsoft.gradient(startColorstr=''#ff0088cc'',endColorstr=''#ff0077b3'',GradientType=0)}.dropdown-menu .active>a,.dropdown-menu .active>a:hover{color:#fff;text-decoration:none;background-color:#08c;background-color:#0081c2;background-image:linear-gradient(to bottom,#08c,#0077b3);background-image:-moz-linear-gradient(top,#08c,#0077b3);background-image:-webkit-gradient(linear,0 0,0 100%,from(#08c),to(#0077b3));background-image:-webkit-linear-gradient(top,#08c,#0077b3);background-image:-o-linear-gradient(top,#08c,#0077b3);background-repeat:repeat-x;outline:0;filter:progid:dximagetransform.microsoft.gradient(startColorstr=''#ff0088cc'',endColorstr=''#ff0077b3'',GradientType=0)}.dropdown-menu .disabled>a,.dropdown-menu .disabled>a:hover{color:#999}.dropdown-menu .disabled>a:hover{text-decoration:none;cursor:default;background-color:transparent}.open{*z-index:1000}.open>.dropdown-menu{display:block}.pull-right>.dropdown-menu{right:0;left:auto}.dropup .caret,.navbar-fixed-bottom .dropdown .caret{border-top:0;border-bottom:4px solid #000;content:""}.dropup .dropdown-menu,.navbar-fixed-bottom .dropdown .dropdown-menu{top:auto;bottom:100%;margin-bottom:1px}.dropdown-submenu{position:relative}.dropdown-submenu>.dropdown-menu{top:0;left:100%;margin-top:-6px;margin-left:-1px;-webkit-border-radius:0 6px 6px 6px;-moz-border-radius:0 6px 6px 6px;border-radius:0 6px 6px 6px}.dropdown-submenu:hover>.dropdown-menu{display:block}.dropdown-submenu>a:after{display:block;float:right;width:0;height:0;margin-top:5px;margin-right:-10px;border-color:transparent;border-left-color:#ccc;border-style:solid;border-width:5px 0 5px 5px;content:" "}.dropdown-submenu:hover>a:after{border-left-color:#fff}.dropdown .dropdown-menu .nav-header{padding-right:20px;padding-left:20px}.typeahead{margin-top:2px;-webkit-border-radius:4px;-moz-border-radius:4px;border-radius:4px}.well{min-height:20px;padding:19px;margin-bottom:20px;background-color:#f5f5f5;border:1px solid #e3e3e3;-webkit-border-radius:4px;-moz-border-radius:4px;border-radius:4px;-webkit-box-shadow:inset 0 1px 1px rgba(0,0,0,0.05);-moz-box-shadow:inset 0 1px 1px rgba(0,0,0,0.05);box-shadow:inset 0 1px 1px rgba(0,0,0,0.05)}.well blockquote{border-color:#ddd;border-color:rgba(0,0,0,0.15)}.well-large{padding:24px;-webkit-border-radius:6px;-moz-border-radius:6px;border-radius:6px}.well-small{padding:9px;-webkit-border-radius:3px;-moz-border-radius:3px;border-radius:3px}.fade{opacity:0;-webkit-transition:opacity .15s linear;-moz-transition:opacity .15s linear;-o-transition:opacity .15s linear;transition:opacity .15s linear}.fade.in{opacity:1}.collapse{position:relative;height:0;overflow:hidden;-webkit-transition:height .35s ease;-moz-transition:height .35s ease;-o-transition:height .35s ease;transition:height .35s ease}.collapse.in{height:auto}.close{float:right;font-size:20px;font-weight:bold;line-height:20px;color:#000;text-shadow:0 1px 0 #fff;opacity:.2;filter:alpha(opacity=20)}.close:hover{color:#000;text-decoration:none;cursor:pointer;opacity:.4;filter:alpha(opacity=40)}button.close{padding:0;cursor:pointer;background:transparent;border:0;-webkit-appearance:none}.btn{display:inline-block;*display:inline;padding:4px 14px;margin-bottom:0;*margin-left:.3em;font-size:14px;line-height:20px;*line-height:20px;color:#333;text-align:center;text-shadow:0 1px 1px rgba(255,255,255,0.75);vertical-align:middle;cursor:pointer;background-color:#f5f5f5;*background-color:#e6e6e6;background-image:-webkit-gradient(linear,0 0,0 100%,from(#fff),to(#e6e6e6));background-image:-webkit-linear-gradient(top,#fff,#e6e6e6);background-image:-o-linear-gradient(top,#fff,#e6e6e6);background-image:linear-gradient(to bottom,#fff,#e6e6e6);background-image:-moz-linear-gradient(top,#fff,#e6e6e6);background-repeat:repeat-x;border:1px solid #bbb;*border:0;border-color:rgba(0,0,0,0.1) rgba(0,0,0,0.1) rgba(0,0,0,0.25);border-color:#e6e6e6 #e6e6e6 #bfbfbf;border-bottom-color:#a2a2a2;-webkit-border-radius:4px;-moz-border-radius:4px;border-radius:4px;filter:progid:dximagetransform.microsoft.gradient(startColorstr=''#ffffffff'',endColorstr=''#ffe6e6e6'',GradientType=0);filter:progid:dximagetransform.microsoft.gradient(enabled=false);*zoom:1;-webkit-box-shadow:inset 0 1px 0 rgba(255,255,255,0.2),0 1px 2px rgba(0,0,0,0.05);-moz-box-shadow:inset 0 1px 0 rgba(255,255,255,0.2),0 1px 2px rgba(0,0,0,0.05);box-shadow:inset 0 1px 0 rgba(255,255,255,0.2),0 1px 2px rgba(0,0,0,0.05)}.btn:hover,.btn:active,.btn.active,.btn.disabled,.btn[disabled]{color:#333;background-color:#e6e6e6;*background-color:#d9d9d9}.btn:active,.btn.active{background-color:#ccc \9}.btn:first-child{*margin-left:0}.btn:hover{color:#333;text-decoration:none;background-color:#e6e6e6;*background-color:#d9d9d9;background-position:0 -15px;-webkit-transition:background-position .1s linear;-moz-transition:background-position .1s linear;-o-transition:background-position .1s linear;transition:background-position .1s linear}.btn:focus{outline:thin dotted #333;outline:5px auto -webkit-focus-ring-color;outline-offset:-2px}.btn.active,.btn:active{background-color:#e6e6e6;background-color:#d9d9d9 \9;background-image:none;outline:0;-webkit-box-shadow:inset 0 2px 4px rgba(0,0,0,0.15),0 1px 2px rgba(0,0,0,0.05);-moz-box-shadow:inset 0 2px 4px rgba(0,0,0,0.15),0 1px 2px rgba(0,0,0,0.05);box-shadow:inset 0 2px 4px rgba(0,0,0,0.15),0 1px 2px rgba(0,0,0,0.05)}.btn.disabled,.btn[disabled]{cursor:default;background-color:#e6e6e6;background-image:none;opacity:.65;filter:alpha(opacity=65);-webkit-box-shadow:none;-moz-box-shadow:none;box-shadow:none}.btn-large{padding:9px 14px;font-size:16px;line-height:normal;-webkit-border-radius:5px;-moz-border-radius:5px;border-radius:5px}.btn-large [class^="icon-"]{margin-top:2px}.btn-small{padding:3px 9px;font-size:12px;line-height:18px}.btn-small [class^="icon-"]{margin-top:0}.btn-mini{padding:2px 6px;font-size:11px;line-height:17px}.btn-block{display:block;width:100%;padding-right:0;padding-left:0;-webkit-box-sizing:border-box;-moz-box-sizing:border-box;box-sizing:border-box}.btn-block+.btn-block{margin-top:5px}input[type="submit"].btn-block,input[type="reset"].btn-block,input[type="button"].btn-block{width:100%}.btn-primary.active,.btn-warning.active,.btn-danger.active,.btn-success.active,.btn-info.active,.btn-inverse.active{color:rgba(255,255,255,0.75)}.btn{border-color:#c5c5c5;border-color:rgba(0,0,0,0.15) rgba(0,0,0,0.15) rgba(0,0,0,0.25)}.btn-primary{color:#fff;text-shadow:0 -1px 0 rgba(0,0,0,0.25);background-color:#006dcc;*background-color:#04c;background-image:-webkit-gradient(linear,0 0,0 100%,from(#08c),to(#04c));background-image:-webkit-linear-gradient(top,#08c,#04c);background-image:-o-linear-gradient(top,#08c,#04c);background-image:linear-gradient(to bottom,#08c,#04c);background-image:-moz-linear-gradient(top,#08c,#04c);background-repeat:repeat-x;border-color:#04c #04c #002a80;border-color:rgba(0,0,0,0.1) rgba(0,0,0,0.1) rgba(0,0,0,0.25);filter:progid:dximagetransform.microsoft.gradient(startColorstr=''#ff0088cc'',endColorstr=''#ff0044cc'',GradientType=0);filter:progid:dximagetransform.microsoft.gradient(enabled=false)}.btn-primary:hover,.btn-primary:active,.btn-primary.active,.btn-primary.disabled,.btn-primary[disabled]{color:#fff;background-color:#04c;*background-color:#003bb3}.btn-primary:active,.btn-primary.active{background-color:#039 \9}.btn-warning{color:#fff;text-shadow:0 -1px 0 rgba(0,0,0,0.25);background-color:#faa732;*background-color:#f89406;background-image:-webkit-gradient(linear,0 0,0 100%,from(#fbb450),to(#f89406));background-image:-webkit-linear-gradient(top,#fbb450,#f89406);background-image:-o-linear-gradient(top,#fbb450,#f89406);background-image:linear-gradient(to bottom,#fbb450,#f89406);background-image:-moz-linear-gradient(top,#fbb450,#f89406);background-repeat:repeat-x;border-color:#f89406 #f89406 #ad6704;border-color:rgba(0,0,0,0.1) rgba(0,0,0,0.1) rgba(0,0,0,0.25);filter:progid:dximagetransform.microsoft.gradient(startColorstr=''#fffbb450'',endColorstr=''#fff89406'',GradientType=0);filter:progid:dximagetransform.microsoft.gradient(enabled=false)}.btn-warning:hover,.btn-warning:active,.btn-warning.active,.btn-warning.disabled,.btn-warning[disabled]{color:#fff;background-color:#f89406;*background-color:#df8505}.btn-warning:active,.btn-warning.active{background-color:#c67605 \9}.btn-danger{color:#fff;text-shadow:0 -1px 0 rgba(0,0,0,0.25);background-color:#da4f49;*background-color:#bd362f;background-image:-webkit-gradient(linear,0 0,0 100%,from(#ee5f5b),to(#bd362f));background-image:-webkit-linear-gradient(top,#ee5f5b,#bd362f);background-image:-o-linear-gradient(top,#ee5f5b,#bd362f);background-image:linear-gradient(to bottom,#ee5f5b,#bd362f);background-image:-moz-linear-gradient(top,#ee5f5b,#bd362f);background-repeat:repeat-x;border-color:#bd362f #bd362f #802420;border-color:rgba(0,0,0,0.1) rgba(0,0,0,0.1) rgba(0,0,0,0.25);filter:progid:dximagetransform.microsoft.gradient(startColorstr=''#ffee5f5b'',endColorstr=''#ffbd362f'',GradientType=0);filter:progid:dximagetransform.microsoft.gradient(enabled=false)}.btn-danger:hover,.btn-danger:active,.btn-danger.active,.btn-danger.disabled,.btn-danger[disabled]{color:#fff;background-color:#bd362f;*background-color:#a9302a}.btn-danger:active,.btn-danger.active{background-color:#942a25 \9}.btn-success{color:#fff;text-shadow:0 -1px 0 rgba(0,0,0,0.25);background-color:#5bb75b;*background-color:#51a351;background-image:-webkit-gradient(linear,0 0,0 100%,from(#62c462),to(#51a351));background-image:-webkit-linear-gradient(top,#62c462,#51a351);background-image:-o-linear-gradient(top,#62c462,#51a351);background-image:linear-gradient(to bottom,#62c462,#51a351);background-image:-moz-linear-gradient(top,#62c462,#51a351);background-repeat:repeat-x;border-color:#51a351 #51a351 #387038;border-color:rgba(0,0,0,0.1) rgba(0,0,0,0.1) rgba(0,0,0,0.25);filter:progid:dximagetransform.microsoft.gradient(startColorstr=''#ff62c462'',endColorstr=''#ff51a351'',GradientType=0);filter:progid:dximagetransform.microsoft.gradient(enabled=false)}.btn-success:hover,.btn-success:active,.btn-success.active,.btn-success.disabled,.btn-success[disabled]{color:#fff;background-color:#51a351;*background-color:#499249}.btn-success:active,.btn-success.active{background-color:#408140 \9}.btn-info{color:#fff;text-shadow:0 -1px 0 rgba(0,0,0,0.25);background-color:#49afcd;*background-color:#2f96b4;background-image:-webkit-gradient(linear,0 0,0 100%,from(#5bc0de),to(#2f96b4));background-image:-webkit-linear-gradient(top,#5bc0de,#2f96b4);background-image:-o-linear-gradient(top,#5bc0de,#2f96b4);background-image:linear-gradient(to bottom,#5bc0de,#2f96b4);background-image:-moz-linear-gradient(top,#5bc0de,#2f96b4);background-repeat:repeat-x;border-color:#2f96b4 #2f96b4 #1f6377;border-color:rgba(0,0,0,0.1) rgba(0,0,0,0.1) rgba(0,0,0,0.25);filter:progid:dximagetransform.microsoft.gradient(startColorstr=''#ff5bc0de'',endColorstr=''#ff2f96b4'',GradientType=0);filter:progid:dximagetransform.microsoft.gradient(enabled=false)}.btn-info:hover,.btn-info:active,.btn-info.active,.btn-info.disabled,.btn-info[disabled]{color:#fff;background-color:#2f96b4;*background-color:#2a85a0}.btn-info:active,.btn-info.active{background-color:#24748c \9}.btn-inverse{color:#fff;text-shadow:0 -1px 0 rgba(0,0,0,0.25);background-color:#363636;*background-color:#222;background-image:-webkit-gradient(linear,0 0,0 100%,from(#444),to(#222));background-image:-webkit-linear-gradient(top,#444,#222);background-image:-o-linear-gradient(top,#444,#222);background-image:linear-gradient(to bottom,#444,#222);background-image:-moz-linear-gradient(top,#444,#222);background-repeat:repeat-x;border-color:#222 #222 #000;border-color:rgba(0,0,0,0.1) rgba(0,0,0,0.1) rgba(0,0,0,0.25);filter:progid:dximagetransform.microsoft.gradient(startColorstr=''#ff444444'',endColorstr=''#ff222222'',GradientType=0);filter:progid:dximagetransform.microsoft.gradient(enabled=false)}.btn-inverse:hover,.btn-inverse:active,.btn-inverse.active,.btn-inverse.disabled,.btn-inverse[disabled]{color:#fff;background-color:#222;*background-color:#151515}.btn-inverse:active,.btn-inverse.active{background-color:#080808 \9}button.btn,input[type="submit"].btn{*padding-top:3px;*padding-bottom:3px}button.btn::-moz-focus-inner,input[type="submit"].btn::-moz-focus-inner{padding:0;border:0}button.btn.btn-large,input[type="submit"].btn.btn-large{*padding-top:7px;*padding-bottom:7px}button.btn.btn-small,input[type="submit"].btn.btn-small{*padding-top:3px;*padding-bottom:3px}button.btn.btn-mini,input[type="submit"].btn.btn-mini{*padding-top:1px;*padding-bottom:1px}.btn-link,.btn-link:active,.btn-link[disabled]{background-color:transparent;background-image:none;-webkit-box-shadow:none;-moz-box-shadow:none;box-shadow:none}.btn-link{color:#08c;cursor:pointer;border-color:transparent;-webkit-border-radius:0;-moz-border-radius:0;border-radius:0}.btn-link:hover{color:#005580;text-decoration:underline;background-color:transparent}.btn-link[disabled]:hover{color:#333;text-decoration:none}.btn-group{position:relative;*margin-left:.3em;font-size:0;white-space:nowrap;vertical-align:middle}.btn-group:first-child{*margin-left:0}.btn-group+.btn-group{margin-left:5px}.btn-toolbar{margin-top:10px;margin-bottom:10px;font-size:0}.btn-toolbar .btn-group{display:inline-block;*display:inline;*zoom:1}.btn-toolbar .btn+.btn,.btn-toolbar .btn-group+.btn,.btn-toolbar .btn+.btn-group{margin-left:5px}.btn-group>.btn{position:relative;-webkit-border-radius:0;-moz-border-radius:0;border-radius:0}.btn-group>.btn+.btn{margin-left:-1px}.btn-group>.btn,.btn-group>.dropdown-menu{font-size:14px}.btn-group>.btn-mini{font-size:11px}.btn-group>.btn-small{font-size:12px}.btn-group>.btn-large{font-size:16px}.btn-group>.btn:first-child{margin-left:0;-webkit-border-bottom-left-radius:4px;border-bottom-left-radius:4px;-webkit-border-top-left-radius:4px;border-top-left-radius:4px;-moz-border-radius-bottomleft:4px;-moz-border-radius-topleft:4px}.btn-group>.btn:last-child,.btn-group>.dropdown-toggle{-webkit-border-top-right-radius:4px;border-top-right-radius:4px;-webkit-border-bottom-right-radius:4px;border-bottom-right-radius:4px;-moz-border-radius-topright:4px;-moz-border-radius-bottomright:4px}.btn-group>.btn.large:first-child{margin-left:0;-webkit-border-bottom-left-radius:6px;border-bottom-left-radius:6px;-webkit-border-top-left-radius:6px;border-top-left-radius:6px;-moz-border-radius-bottomleft:6px;-moz-border-radius-topleft:6px}.btn-group>.btn.large:last-child,.btn-group>.large.dropdown-toggle{-webkit-border-top-right-radius:6px;border-top-right-radius:6px;-webkit-border-bottom-right-radius:6px;border-bottom-right-radius:6px;-moz-border-radius-topright:6px;-moz-border-radius-bottomright:6px}.btn-group>.btn:hover,.btn-group>.btn:focus,.btn-group>.btn:active,.btn-group>.btn.active{z-index:2}.btn-group .dropdown-toggle:active,.btn-group.open .dropdown-toggle{outline:0}.btn-group>.btn+.dropdown-toggle{*padding-top:5px;padding-right:8px;*padding-bottom:5px;padding-left:8px;-webkit-box-shadow:inset 1px 0 0 rgba(255,255,255,0.125),inset 0 1px 0 rgba(255,255,255,0.2),0 1px 2px rgba(0,0,0,0.05);-moz-box-shadow:inset 1px 0 0 rgba(255,255,255,0.125),inset 0 1px 0 rgba(255,255,255,0.2),0 1px 2px rgba(0,0,0,0.05);box-shadow:inset 1px 0 0 rgba(255,255,255,0.125),inset 0 1px 0 rgba(255,255,255,0.2),0 1px 2px rgba(0,0,0,0.05)}.btn-group>.btn-mini+.dropdown-toggle{*padding-top:2px;padding-right:5px;*padding-bottom:2px;padding-left:5px}.btn-group>.btn-small+.dropdown-toggle{*padding-top:5px;*padding-bottom:4px}.btn-group>.btn-large+.dropdown-toggle{*padding-top:7px;padding-right:12px;*padding-bottom:7px;padding-left:12px}.btn-group.open .dropdown-toggle{background-image:none;-webkit-box-shadow:inset 0 2px 4px rgba(0,0,0,0.15),0 1px 2px rgba(0,0,0,0.05);-moz-box-shadow:inset 0 2px 4px rgba(0,0,0,0.15),0 1px 2px rgba(0,0,0,0.05);box-shadow:inset 0 2px 4px rgba(0,0,0,0.15),0 1px 2px rgba(0,0,0,0.05)}.btn-group.open .btn.dropdown-toggle{background-color:#e6e6e6}.btn-group.open .btn-primary.dropdown-toggle{background-color:#04c}.btn-group.open .btn-warning.dropdown-toggle{background-color:#f89406}.btn-group.open .btn-danger.dropdown-toggle{background-color:#bd362f}.btn-group.open .btn-success.dropdown-toggle{background-color:#51a351}.btn-group.open .btn-info.dropdown-toggle{background-color:#2f96b4}.btn-group.open .btn-inverse.dropdown-toggle{background-color:#222}.btn .caret{margin-top:8px;margin-left:0}.btn-mini .caret,.btn-small .caret,.btn-large .caret{margin-top:6px}.btn-large .caret{border-top-width:5px;border-right-width:5px;border-left-width:5px}.dropup .btn-large .caret{border-top:0;border-bottom:5px solid #000}.btn-primary .caret,.btn-warning .caret,.btn-danger .caret,.btn-info .caret,.btn-success .caret,.btn-inverse .caret{border-top-color:#fff;border-bottom-color:#fff}.btn-group-vertical{display:inline-block;*display:inline;*zoom:1}.btn-group-vertical .btn{display:block;float:none;width:100%;-webkit-border-radius:0;-moz-border-radius:0;border-radius:0}.btn-group-vertical .btn+.btn{margin-top:-1px;margin-left:0}.btn-group-vertical .btn:first-child{-webkit-border-radius:4px 4px 0 0;-moz-border-radius:4px 4px 0 0;border-radius:4px 4px 0 0}.btn-group-vertical .btn:last-child{-webkit-border-radius:0 0 4px 4px;-moz-border-radius:0 0 4px 4px;border-radius:0 0 4px 4px}.btn-group-vertical .btn-large:first-child{-webkit-border-radius:6px 6px 0 0;-moz-border-radius:6px 6px 0 0;border-radius:6px 6px 0 0}.btn-group-vertical .btn-large:last-child{-webkit-border-radius:0 0 6px 6px;-moz-border-radius:0 0 6px 6px;border-radius:0 0 6px 6px}.alert{padding:8px 35px 8px 14px;margin-bottom:20px;color:#c09853;text-shadow:0 1px 0 rgba(255,255,255,0.5);background-color:#fcf8e3;border:1px solid #fbeed5;-webkit-border-radius:4px;-moz-border-radius:4px;border-radius:4px}.alert h4{margin:0}.alert .close{position:relative;top:-2px;right:-21px;line-height:20px}.alert-success{color:#468847;background-color:#dff0d8;border-color:#d6e9c6}.alert-danger,.alert-error{color:#b94a48;background-color:#f2dede;border-color:#eed3d7}.alert-info{color:#3a87ad;background-color:#d9edf7;border-color:#bce8f1}.alert-block{padding-top:14px;padding-bottom:14px}.alert-block>p,.alert-block>ul{margin-bottom:0}.alert-block p+p{margin-top:5px}.nav{margin-bottom:20px;margin-left:0;list-style:none}.nav>li>a{display:block}.nav>li>a:hover{text-decoration:none;background-color:#eee}.nav>.pull-right{float:right}.nav-header{display:block;padding:3px 15px;font-size:11px;font-weight:bold;line-height:20px;color:#999;text-shadow:0 1px 0 rgba(255,255,255,0.5);text-transform:uppercase}.nav li+.nav-header{margin-top:9px}.nav-list{padding-right:15px;padding-left:15px;margin-bottom:0}.nav-list>li>a,.nav-list .nav-header{margin-right:-15px;margin-left:-15px;text-shadow:0 1px 0 rgba(255,255,255,0.5)}.nav-list>li>a{padding:3px 15px}.nav-list>.active>a,.nav-list>.active>a:hover{color:#fff;text-shadow:0 -1px 0 rgba(0,0,0,0.2);background-color:#08c}.nav-list [class^="icon-"]{margin-right:2px}.nav-list .divider{*width:100%;height:1px;margin:9px 1px;*margin:-5px 0 5px;overflow:hidden;background-color:#e5e5e5;border-bottom:1px solid #fff}.nav-tabs,.nav-pills{*zoom:1}.nav-tabs:before,.nav-pills:before,.nav-tabs:after,.nav-pills:after{display:table;line-height:0;content:""}.nav-tabs:after,.nav-pills:after{clear:both}.nav-tabs>li,.nav-pills>li{float:left}.nav-tabs>li>a,.nav-pills>li>a{padding-right:12px;padding-left:12px;margin-right:2px;line-height:14px}.nav-tabs{border-bottom:1px solid #ddd}.nav-tabs>li{margin-bottom:-1px}.nav-tabs>li>a{padding-top:8px;padding-bottom:8px;line-height:20px;border:1px solid transparent;-webkit-border-radius:4px 4px 0 0;-moz-border-radius:4px 4px 0 0;border-radius:4px 4px 0 0}.nav-tabs>li>a:hover{border-color:#eee #eee #ddd}.nav-tabs>.active>a,.nav-tabs>.active>a:hover{color:#555;cursor:default;background-color:#fff;border:1px solid #ddd;border-bottom-color:transparent}.nav-pills>li>a{padding-top:8px;padding-bottom:8px;margin-top:2px;margin-bottom:2px;-webkit-border-radius:5px;-moz-border-radius:5px;border-radius:5px}.nav-pills>.active>a,.nav-pills>.active>a:hover{color:#fff;background-color:#08c}.nav-stacked>li{float:none}.nav-stacked>li>a{margin-right:0}.nav-tabs.nav-stacked{border-bottom:0}.nav-tabs.nav-stacked>li>a{border:1px solid #ddd;-webkit-border-radius:0;-moz-border-radius:0;border-radius:0}.nav-tabs.nav-stacked>li:first-child>a{-webkit-border-top-right-radius:4px;border-top-right-radius:4px;-webkit-border-top-left-radius:4px;border-top-left-radius:4px;-moz-border-radius-topright:4px;-moz-border-radius-topleft:4px}.nav-tabs.nav-stacked>li:last-child>a{-webkit-border-bottom-right-radius:4px;border-bottom-right-radius:4px;-webkit-border-bottom-left-radius:4px;border-bottom-left-radius:4px;-moz-border-radius-bottomright:4px;-moz-border-radius-bottomleft:4px}.nav-tabs.nav-stacked>li>a:hover{z-index:2;border-color:#ddd}.nav-pills.nav-stacked>li>a{margin-bottom:3px}.nav-pills.nav-stacked>li:last-child>a{margin-bottom:1px}.nav-tabs .dropdown-menu{-webkit-border-radius:0 0 6px 6px;-moz-border-radius:0 0 6px 6px;border-radius:0 0 6px 6px}.nav-pills .dropdown-menu{-webkit-border-radius:6px;-moz-border-radius:6px;border-radius:6px}.nav .dropdown-toggle .caret{margin-top:6px;border-top-color:#08c;border-bottom-color:#08c}.nav .dropdown-toggle:hover .caret{border-top-color:#005580;border-bottom-color:#005580}.nav-tabs .dropdown-toggle .caret{margin-top:8px}.nav .active .dropdown-toggle .caret{border-top-color:#fff;border-bottom-color:#fff}.nav-tabs .active .dropdown-toggle .caret{border-top-color:#555;border-bottom-color:#555}.nav>.dropdown.active>a:hover{cursor:pointer}.nav-tabs .open .dropdown-toggle,.nav-pills .open .dropdown-toggle,.nav>li.dropdown.open.active>a:hover{color:#fff;background-color:#999;border-color:#999}.nav li.dropdown.open .caret,.nav li.dropdown.open.active .caret,.nav li.dropdown.open a:hover .caret{border-top-color:#fff;border-bottom-color:#fff;opacity:1;filter:alpha(opacity=100)}.tabs-stacked .open>a:hover{border-color:#999}.tabbable{*zoom:1}.tabbable:before,.tabbable:after{display:table;line-height:0;content:""}.tabbable:after{clear:both}.tab-content{overflow:auto}.tabs-below>.nav-tabs,.tabs-right>.nav-tabs,.tabs-left>.nav-tabs{border-bottom:0}.tab-content>.tab-pane,.pill-content>.pill-pane{display:none}.tab-content>.active,.pill-content>.active{display:block}.tabs-below>.nav-tabs{border-top:1px solid #ddd}.tabs-below>.nav-tabs>li{margin-top:-1px;margin-bottom:0}.tabs-below>.nav-tabs>li>a{-webkit-border-radius:0 0 4px 4px;-moz-border-radius:0 0 4px 4px;border-radius:0 0 4px 4px}.tabs-below>.nav-tabs>li>a:hover{border-top-color:#ddd;border-bottom-color:transparent}.tabs-below>.nav-tabs>.active>a,.tabs-below>.nav-tabs>.active>a:hover{border-color:transparent #ddd #ddd #ddd}.tabs-left>.nav-tabs>li,.tabs-right>.nav-tabs>li{float:none}.tabs-left>.nav-tabs>li>a,.tabs-right>.nav-tabs>li>a{min-width:74px;margin-right:0;margin-bottom:3px}.tabs-left>.nav-tabs{float:left;margin-right:19px;border-right:1px solid #ddd}.tabs-left>.nav-tabs>li>a{margin-right:-1px;-webkit-border-radius:4px 0 0 4px;-moz-border-radius:4px 0 0 4px;border-radius:4px 0 0 4px}.tabs-left>.nav-tabs>li>a:hover{border-color:#eee #ddd #eee #eee}.tabs-left>.nav-tabs .active>a,.tabs-left>.nav-tabs .active>a:hover{border-color:#ddd transparent #ddd #ddd;*border-right-color:#fff}.tabs-right>.nav-tabs{float:right;margin-left:19px;border-left:1px solid #ddd}.tabs-right>.nav-tabs>li>a{margin-left:-1px;-webkit-border-radius:0 4px 4px 0;-moz-border-radius:0 4px 4px 0;border-radius:0 4px 4px 0}.tabs-right>.nav-tabs>li>a:hover{border-color:#eee #eee #eee #ddd}.tabs-right>.nav-tabs .active>a,.tabs-right>.nav-tabs .active>a:hover{border-color:#ddd #ddd #ddd transparent;*border-left-color:#fff}.nav>.disabled>a{color:#999}.nav>.disabled>a:hover{text-decoration:none;cursor:default;background-color:transparent}.navbar{*position:relative;*z-index:2;margin-bottom:20px;overflow:visible;color:#777}.navbar-inner{min-height:40px;padding-right:20px;padding-left:20px;background-color:#fafafa;background-image:-moz-linear-gradient(top,#fff,#f2f2f2);background-image:-webkit-gradient(linear,0 0,0 100%,from(#fff),to(#f2f2f2));background-image:-webkit-linear-gradient(top,#fff,#f2f2f2);background-image:-o-linear-gradient(top,#fff,#f2f2f2);background-image:linear-gradient(to bottom,#fff,#f2f2f2);background-repeat:repeat-x;border:1px solid #d4d4d4;-webkit-border-radius:4px;-moz-border-radius:4px;border-radius:4px;filter:progid:dximagetransform.microsoft.gradient(startColorstr=''#ffffffff'',endColorstr=''#fff2f2f2'',GradientType=0);*zoom:1;-webkit-box-shadow:0 1px 4px rgba(0,0,0,0.065);-moz-box-shadow:0 1px 4px rgba(0,0,0,0.065);box-shadow:0 1px 4px rgba(0,0,0,0.065)}.navbar-inner:before,.navbar-inner:after{display:table;line-height:0;content:""}.navbar-inner:after{clear:both}.navbar .container{width:auto}.nav-collapse.collapse{height:auto}.navbar .brand{display:block;float:left;padding:10px 20px 10px;margin-left:-20px;font-size:20px;font-weight:200;color:#777;text-shadow:0 1px 0 #fff}.navbar .brand:hover{text-decoration:none}.navbar-text{margin-bottom:0;line-height:40px}.navbar-link{color:#777}.navbar-link:hover{color:#333}.navbar .divider-vertical{height:40px;margin:0 9px;border-right:1px solid #fff;border-left:1px solid #f2f2f2}.navbar .btn,.navbar .btn-group{margin-top:5px}.navbar .btn-group .btn,.navbar .input-prepend .btn,.navbar .input-append .btn{margin-top:0}.navbar-form{margin-bottom:0;*zoom:1}.navbar-form:before,.navbar-form:after{display:table;line-height:0;content:""}.navbar-form:after{clear:both}.navbar-form input,.navbar-form select,.navbar-form .radio,.navbar-form .checkbox{margin-top:5px}.navbar-form input,.navbar-form select,.navbar-form .btn{display:inline-block;margin-bottom:0}.navbar-form input[type="image"],.navbar-form input[type="checkbox"],.navbar-form input[type="radio"]{margin-top:3px}.navbar-form .input-append,.navbar-form .input-prepend{margin-top:6px;white-space:nowrap}.navbar-form .input-append input,.navbar-form .input-prepend input{margin-top:0}.navbar-search{position:relative;float:left;margin-top:5px;margin-bottom:0}.navbar-search .search-query{padding:4px 14px;margin-bottom:0;font-family:"Helvetica Neue",Helvetica,Arial,sans-serif;font-size:13px;font-weight:normal;line-height:1;-webkit-border-radius:15px;-moz-border-radius:15px;border-radius:15px}.navbar-static-top{position:static;width:100%;margin-bottom:0}.navbar-static-top .navbar-inner{-webkit-border-radius:0;-moz-border-radius:0;border-radius:0}.navbar-fixed-top,.navbar-fixed-bottom{position:fixed;right:0;left:0;z-index:1030;margin-bottom:0}.navbar-fixed-top .navbar-inner,.navbar-static-top .navbar-inner{border-width:0 0 1px}.navbar-fixed-bottom .navbar-inner{border-width:1px 0 0}.navbar-fixed-top .navbar-inner,.navbar-fixed-bottom .navbar-inner{padding-right:0;padding-left:0;-webkit-border-radius:0;-moz-border-radius:0;border-radius:0}.navbar-static-top .container,.navbar-fixed-top .container,.navbar-fixed-bottom .container{width:940px}.navbar-fixed-top{top:0}.navbar-fixed-top .navbar-inner,.navbar-static-top .navbar-inner{-webkit-box-shadow:inset 0 -1px 0 rgba(0,0,0,0.1),0 1px 10px rgba(0,0,0,0.1);-moz-box-shadow:inset 0 -1px 0 rgba(0,0,0,0.1),0 1px 10px rgba(0,0,0,0.1);box-shadow:inset 0 -1px 0 rgba(0,0,0,0.1),0 1px 10px rgba(0,0,0,0.1)}.navbar-fixed-bottom{bottom:0}.navbar-fixed-bottom .navbar-inner{-webkit-box-shadow:inset 0 1px 0 rgba(0,0,0,0.1),0 -1px 10px rgba(0,0,0,0.1);-moz-box-shadow:inset 0 1px 0 rgba(0,0,0,0.1),0 -1px 10px rgba(0,0,0,0.1);box-shadow:inset 0 1px 0 rgba(0,0,0,0.1),0 -1px 10px rgba(0,0,0,0.1)}.navbar .nav{position:relative;left:0;display:block;float:left;margin:0 10px 0 0}.navbar .nav.pull-right{float:right;margin-right:0}.navbar .nav>li{float:left}.navbar .nav>li>a{float:none;padding:10px 15px 10px;color:#777;text-decoration:none;text-shadow:0 1px 0 #fff}.navbar .nav .dropdown-toggle .caret{margin-top:8px}.navbar .nav>li>a:focus,.navbar .nav>li>a:hover{color:#333;text-decoration:none;background-color:transparent}.navbar .nav>.active>a,.navbar .nav>.active>a:hover,.navbar .nav>.active>a:focus{color:#555;text-decoration:none;background-color:#e5e5e5;-webkit-box-shadow:inset 0 3px 8px rgba(0,0,0,0.125);-moz-box-shadow:inset 0 3px 8px rgba(0,0,0,0.125);box-shadow:inset 0 3px 8px rgba(0,0,0,0.125)}.navbar .btn-navbar{display:none;float:right;padding:7px 10px;margin-right:5px;margin-left:5px;color:#fff;text-shadow:0 -1px 0 rgba(0,0,0,0.25);background-color:#ededed;*background-color:#e5e5e5;background-image:-webkit-gradient(linear,0 0,0 100%,from(#f2f2f2),to(#e5e5e5));background-image:-webkit-linear-gradient(top,#f2f2f2,#e5e5e5);background-image:-o-linear-gradient(top,#f2f2f2,#e5e5e5);background-image:linear-gradient(to bottom,#f2f2f2,#e5e5e5);background-image:-moz-linear-gradient(top,#f2f2f2,#e5e5e5);background-repeat:repeat-x;border-color:#e5e5e5 #e5e5e5 #bfbfbf;border-color:rgba(0,0,0,0.1) rgba(0,0,0,0.1) rgba(0,0,0,0.25);filter:progid:dximagetransform.microsoft.gradient(startColorstr=''#fff2f2f2'',endColorstr=''#ffe5e5e5'',GradientType=0);filter:progid:dximagetransform.microsoft.gradient(enabled=false);-webkit-box-shadow:inset 0 1px 0 rgba(255,255,255,0.1),0 1px 0 rgba(255,255,255,0.075);-moz-box-shadow:inset 0 1px 0 rgba(255,255,255,0.1),0 1px 0 rgba(255,255,255,0.075);box-shadow:inset 0 1px 0 rgba(255,255,255,0.1),0 1px 0 rgba(255,255,255,0.075)}.navbar .btn-navbar:hover,.navbar .btn-navbar:active,.navbar .btn-navbar.active,.navbar .btn-navbar.disabled,.navbar .btn-navbar[disabled]{color:#fff;background-color:#e5e5e5;*background-color:#d9d9d9}.navbar .btn-navbar:active,.navbar .btn-navbar.active{background-color:#ccc \9}.navbar .btn-navbar .icon-bar{display:block;width:18px;height:2px;background-color:#f5f5f5;-webkit-border-radius:1px;-moz-border-radius:1px;border-radius:1px;-webkit-box-shadow:0 1px 0 rgba(0,0,0,0.25);-moz-box-shadow:0 1px 0 rgba(0,0,0,0.25);box-shadow:0 1px 0 rgba(0,0,0,0.25)}.btn-navbar .icon-bar+.icon-bar{margin-top:3px}.navbar .nav>li>.dropdown-menu:before{position:absolute;top:-7px;left:9px;display:inline-block;border-right:7px solid transparent;border-bottom:7px solid #ccc;border-left:7px solid transparent;border-bottom-color:rgba(0,0,0,0.2);content:''''}.navbar .nav>li>.dropdown-menu:after{position:absolute;top:-6px;left:10px;display:inline-block;border-right:6px solid transparent;border-bottom:6px solid #fff;border-left:6px solid transparent;content:''''}.navbar-fixed-bottom .nav>li>.dropdown-menu:before{top:auto;bottom:-7px;border-top:7px solid #ccc;border-bottom:0;border-top-color:rgba(0,0,0,0.2)}.navbar-fixed-bottom .nav>li>.dropdown-menu:after{top:auto;bottom:-6px;border-top:6px solid #fff;border-bottom:0}.navbar .nav li.dropdown.open>.dropdown-toggle,.navbar .nav li.dropdown.active>.dropdown-toggle,.navbar .nav li.dropdown.open.active>.dropdown-toggle{color:#555;background-color:#e5e5e5}.navbar .nav li.dropdown>.dropdown-toggle .caret{border-top-color:#777;border-bottom-color:#777}.navbar .nav li.dropdown.open>.dropdown-toggle .caret,.navbar .nav li.dropdown.active>.dropdown-toggle .caret,.navbar .nav li.dropdown.open.active>.dropdown-toggle .caret{border-top-color:#555;border-bottom-color:#555}.navbar .pull-right>li>.dropdown-menu,.navbar .nav>li>.dropdown-menu.pull-right{right:0;left:auto}.navbar .pull-right>li>.dropdown-menu:before,.navbar .nav>li>.dropdown-menu.pull-right:before{right:12px;left:auto}.navbar .pull-right>li>.dropdown-menu:after,.navbar .nav>li>.dropdown-menu.pull-right:after{right:13px;left:auto}.navbar .pull-right>li>.dropdown-menu .dropdown-menu,.navbar .nav>li>.dropdown-menu.pull-right .dropdown-menu{right:100%;left:auto;margin-right:-1px;margin-left:0;-webkit-border-radius:6px 0 6px 6px;-moz-border-radius:6px 0 6px 6px;border-radius:6px 0 6px 6px}.navbar-inverse{color:#999}.navbar-inverse .navbar-inner{background-color:#1b1b1b;background-image:-moz-linear-gradient(top,#222,#111);background-image:-webkit-gradient(linear,0 0,0 100%,from(#222),to(#111));background-image:-webkit-linear-gradient(top,#222,#111);background-image:-o-linear-gradient(top,#222,#111);background-image:linear-gradient(to bottom,#222,#111);background-repeat:repeat-x;border-color:#252525;filter:progid:dximagetransform.microsoft.gradient(startColorstr=''#ff222222'',endColorstr=''#ff111111'',GradientType=0)}.navbar-inverse .brand,.navbar-inverse .nav>li>a{color:#999;text-shadow:0 -1px 0 rgba(0,0,0,0.25)}.navbar-inverse .brand:hover,.navbar-inverse .nav>li>a:hover{color:#fff}.navbar-inverse .nav>li>a:focus,.navbar-inverse .nav>li>a:hover{color:#fff;background-color:transparent}.navbar-inverse .nav .active>a,.navbar-inverse .nav .active>a:hover,.navbar-inverse .nav .active>a:focus{color:#fff;background-color:#111}.navbar-inverse .navbar-link{color:#999}.navbar-inverse .navbar-link:hover{color:#fff}.navbar-inverse .divider-vertical{border-right-color:#222;border-left-color:#111}.navbar-inverse .nav li.dropdown.open>.dropdown-toggle,.navbar-inverse .nav li.dropdown.active>.dropdown-toggle,.navbar-inverse .nav li.dropdown.open.active>.dropdown-toggle{color:#fff;background-color:#111}.navbar-inverse .nav li.dropdown>.dropdown-toggle .caret{border-top-color:#999;border-bottom-color:#999}.navbar-inverse .nav li.dropdown.open>.dropdown-toggle .caret,.navbar-inverse .nav li.dropdown.active>.dropdown-toggle .caret,.navbar-inverse .nav li.dropdown.open.active>.dropdown-toggle .caret{border-top-color:#fff;border-bottom-color:#fff}.navbar-inverse .navbar-search .search-query{color:#fff;background-color:#515151;border-color:#111;-webkit-box-shadow:inset 0 1px 2px rgba(0,0,0,0.1),0 1px 0 rgba(255,255,255,0.15);-moz-box-shadow:inset 0 1px 2px rgba(0,0,0,0.1),0 1px 0 rgba(255,255,255,0.15);box-shadow:inset 0 1px 2px rgba(0,0,0,0.1),0 1px 0 rgba(255,255,255,0.15);-webkit-transition:none;-moz-transition:none;-o-transition:none;transition:none}.navbar-inverse .navbar-search .search-query:-moz-placeholder{color:#ccc}.navbar-inverse .navbar-search .search-query:-ms-input-placeholder{color:#ccc}.navbar-inverse .navbar-search .search-query::-webkit-input-placeholder{color:#ccc}.navbar-inverse .navbar-search .search-query:focus,.navbar-inverse .navbar-search .search-query.focused{padding:5px 15px;color:#333;text-shadow:0 1px 0 #fff;background-color:#fff;border:0;outline:0;-webkit-box-shadow:0 0 3px rgba(0,0,0,0.15);-moz-box-shadow:0 0 3px rgba(0,0,0,0.15);box-shadow:0 0 3px rgba(0,0,0,0.15)}.navbar-inverse .btn-navbar{color:#fff;text-shadow:0 -1px 0 rgba(0,0,0,0.25);background-color:#0e0e0e;*background-color:#040404;background-image:-webkit-gradient(linear,0 0,0 100%,from(#151515),to(#040404));background-image:-webkit-linear-gradient(top,#151515,#040404);background-image:-o-linear-gradient(top,#151515,#040404);background-image:linear-gradient(to bottom,#151515,#040404);background-image:-moz-linear-gradient(top,#151515,#040404);background-repeat:repeat-x;border-color:#040404 #040404 #000;border-color:rgba(0,0,0,0.1) rgba(0,0,0,0.1) rgba(0,0,0,0.25);filter:progid:dximagetransform.microsoft.gradient(startColorstr=''#ff151515'',endColorstr=''#ff040404'',GradientType=0);filter:progid:dximagetransform.microsoft.gradient(enabled=false)}.navbar-inverse .btn-navbar:hover,.navbar-inverse .btn-navbar:active,.navbar-inverse .btn-navbar.active,.navbar-inverse .btn-navbar.disabled,.navbar-inverse .btn-navbar[disabled]{color:#fff;background-color:#040404;*background-color:#000}.navbar-inverse .btn-navbar:active,.navbar-inverse .btn-navbar.active{background-color:#000 \9}.breadcrumb{padding:8px 15px;margin:0 0 20px;list-style:none;background-color:#f5f5f5;-webkit-border-radius:4px;-moz-border-radius:4px;border-radius:4px}.breadcrumb li{display:inline-block;*display:inline;text-shadow:0 1px 0 #fff;*zoom:1}.breadcrumb .divider{padding:0 5px;color:#ccc}.breadcrumb .active{color:#999}.pagination{height:40px;margin:20px 0}.pagination ul{display:inline-block;*display:inline;margin-bottom:0;margin-left:0;-webkit-border-radius:3px;-moz-border-radius:3px;border-radius:3px;*zoom:1;-webkit-box-shadow:0 1px 2px rgba(0,0,0,0.05);-moz-box-shadow:0 1px 2px rgba(0,0,0,0.05);box-shadow:0 1px 2px rgba(0,0,0,0.05)}.pagination ul>li{display:inline}.pagination ul>li>a,.pagination ul>li>span{float:left;padding:0 14px;line-height:38px;text-decoration:none;background-color:#fff;border:1px solid #ddd;border-left-width:0}.pagination ul>li>a:hover,.pagination ul>.active>a,.pagination ul>.active>span{background-color:#f5f5f5}.pagination ul>.active>a,.pagination ul>.active>span{color:#999;cursor:default}.pagination ul>.disabled>span,.pagination ul>.disabled>a,.pagination ul>.disabled>a:hover{color:#999;cursor:default;background-color:transparent}.pagination ul>li:first-child>a,.pagination ul>li:first-child>span{border-left-width:1px;-webkit-border-radius:3px 0 0 3px;-moz-border-radius:3px 0 0 3px;border-radius:3px 0 0 3px}.pagination ul>li:last-child>a,.pagination ul>li:last-child>span{-webkit-border-radius:0 3px 3px 0;-moz-border-radius:0 3px 3px 0;border-radius:0 3px 3px 0}.pagination-centered{text-align:center}.pagination-right{text-align:right}.pager{margin:20px 0;text-align:center;list-style:none;*zoom:1}.pager:before,.pager:after{display:table;line-height:0;content:""}.pager:after{clear:both}.pager li{display:inline}.pager a,.pager span{display:inline-block;padding:5px 14px;background-color:#fff;border:1px solid #ddd;-webkit-border-radius:15px;-moz-border-radius:15px;border-radius:15px}.pager a:hover{text-decoration:none;background-color:#f5f5f5}.pager .next a,.pager .next span{float:right}.pager .previous a{float:left}.pager .disabled a,.pager .disabled a:hover,.pager .disabled span{color:#999;cursor:default;background-color:#fff}.modal-open .modal .dropdown-menu{z-index:2050}.modal-open .modal .dropdown.open{*z-index:2050}.modal-open .modal .popover{z-index:2060}.modal-open .modal .tooltip{z-index:2080}.modal-backdrop{position:fixed;top:0;right:0;bottom:0;left:0;z-index:1040;background-color:#000}.modal-backdrop.fade{opacity:0}.modal-backdrop,.modal-backdrop.fade.in{opacity:.8;filter:alpha(opacity=80)}.modal{position:fixed;top:50%;left:50%;z-index:1050;width:560px;margin:-250px 0 0 -280px;overflow:auto;background-color:#fff;border:1px solid #999;border:1px solid rgba(0,0,0,0.3);*border:1px solid #999;-webkit-border-radius:6px;-moz-border-radius:6px;border-radius:6px;-webkit-box-shadow:0 3px 7px rgba(0,0,0,0.3);-moz-box-shadow:0 3px 7px rgba(0,0,0,0.3);box-shadow:0 3px 7px rgba(0,0,0,0.3);-webkit-background-clip:padding-box;-moz-background-clip:padding-box;background-clip:padding-box}.modal.fade{top:-25%;-webkit-transition:opacity .3s linear,top .3s ease-out;-moz-transition:opacity .3s linear,top .3s ease-out;-o-transition:opacity .3s linear,top .3s ease-out;transition:opacity .3s linear,top .3s ease-out}.modal.fade.in{top:50%}.modal-header{padding:9px 15px;border-bottom:1px solid #eee}.modal-header .close{margin-top:2px}.modal-header h3{margin:0;line-height:30px}.modal-body{max-height:400px;padding:15px;overflow-y:auto}.modal-form{margin-bottom:0}.modal-footer{padding:14px 15px 15px;margin-bottom:0;text-align:right;background-color:#f5f5f5;border-top:1px solid #ddd;-webkit-border-radius:0 0 6px 6px;-moz-border-radius:0 0 6px 6px;border-radius:0 0 6px 6px;*zoom:1;-webkit-box-shadow:inset 0 1px 0 #fff;-moz-box-shadow:inset 0 1px 0 #fff;box-shadow:inset 0 1px 0 #fff}.modal-footer:before,.modal-footer:after{display:table;line-height:0;content:""}.modal-footer:after{clear:both}.modal-footer .btn+.btn{margin-bottom:0;margin-left:5px}.modal-footer .btn-group .btn+.btn{margin-left:-1px}.tooltip{position:absolute;z-index:1030;display:block;padding:5px;font-size:11px;opacity:0;filter:alpha(opacity=0);visibility:visible}.tooltip.in{opacity:.8;filter:alpha(opacity=80)}.tooltip.top{margin-top:-3px}.tooltip.right{margin-left:3px}.tooltip.bottom{margin-top:3px}.tooltip.left{margin-left:-3px}.tooltip-inner{max-width:200px;padding:3px 8px;color:#fff;text-align:center;text-decoration:none;background-color:#000;-webkit-border-radius:4px;-moz-border-radius:4px;border-radius:4px}.tooltip-arrow{position:absolute;width:0;height:0;border-color:transparent;border-style:solid}.tooltip.top .tooltip-arrow{bottom:0;left:50%;margin-left:-5px;border-top-color:#000;border-width:5px 5px 0}.tooltip.right .tooltip-arrow{top:50%;left:0;margin-top:-5px;border-right-color:#000;border-width:5px 5px 5px 0}.tooltip.left .tooltip-arrow{top:50%;right:0;margin-top:-5px;border-left-color:#000;border-width:5px 0 5px 5px}.tooltip.bottom .tooltip-arrow{top:0;left:50%;margin-left:-5px;border-bottom-color:#000;border-width:0 5px 5px}.popover{position:absolute;top:0;left:0;z-index:1010;display:none;width:236px;padding:1px;background-color:#fff;border:1px solid #ccc;border:1px solid rgba(0,0,0,0.2);-webkit-border-radius:6px;-moz-border-radius:6px;border-radius:6px;-webkit-box-shadow:0 5px 10px rgba(0,0,0,0.2);-moz-box-shadow:0 5px 10px rgba(0,0,0,0.2);box-shadow:0 5px 10px rgba(0,0,0,0.2);-webkit-background-clip:padding-box;-moz-background-clip:padding;background-clip:padding-box}.popover.top{margin-bottom:10px}.popover.right{margin-left:10px}.popover.bottom{margin-top:10px}.popover.left{margin-right:10px}.popover-title{padding:8px 14px;margin:0;font-size:14px;font-weight:normal;line-height:18px;background-color:#f7f7f7;border-bottom:1px solid #ebebeb;-webkit-border-radius:5px 5px 0 0;-moz-border-radius:5px 5px 0 0;border-radius:5px 5px 0 0}.popover-content{padding:9px 14px}.popover-content p,.popover-content ul,.popover-content ol{margin-bottom:0}.popover .arrow,.popover .arrow:after{position:absolute;display:inline-block;width:0;height:0;border-color:transparent;border-style:solid}.popover .arrow:after{z-index:-1;content:""}.popover.top .arrow{bottom:-10px;left:50%;margin-left:-10px;border-top-color:#fff;border-width:10px 10px 0}.popover.top .arrow:after{bottom:-1px;left:-11px;border-top-color:rgba(0,0,0,0.25);border-width:11px 11px 0}.popover.right .arrow{top:50%;left:-10px;margin-top:-10px;border-right-color:#fff;border-width:10px 10px 10px 0}.popover.right .arrow:after{bottom:-11px;left:-1px;border-right-color:rgba(0,0,0,0.25);border-width:11px 11px 11px 0}.popover.bottom .arrow{top:-10px;left:50%;margin-left:-10px;border-bottom-color:#fff;border-width:0 10px 10px}.popover.bottom .arrow:after{top:-1px;left:-11px;border-bottom-color:rgba(0,0,0,0.25);border-width:0 11px 11px}.popover.left .arrow{top:50%;right:-10px;margin-top:-10px;border-left-color:#fff;border-width:10px 0 10px 10px}.popover.left .arrow:after{right:-1px;bottom:-11px;border-left-color:rgba(0,0,0,0.25);border-width:11px 0 11px 11px}.thumbnails{margin-left:-20px;list-style:none;*zoom:1}.thumbnails:before,.thumbnails:after{display:table;line-height:0;content:""}.thumbnails:after{clear:both}.row-fluid .thumbnails{margin-left:0}.thumbnails>li{float:left;margin-bottom:20px;margin-left:20px}.thumbnail{display:block;padding:4px;line-height:20px;border:1px solid #ddd;-webkit-border-radius:4px;-moz-border-radius:4px;border-radius:4px;-webkit-box-shadow:0 1px 3px rgba(0,0,0,0.055);-moz-box-shadow:0 1px 3px rgba(0,0,0,0.055);box-shadow:0 1px 3px rgba(0,0,0,0.055);-webkit-transition:all .2s ease-in-out;-moz-transition:all .2s ease-in-out;-o-transition:all .2s ease-in-out;transition:all .2s ease-in-out}a.thumbnail:hover{border-color:#08c;-webkit-box-shadow:0 1px 4px rgba(0,105,214,0.25);-moz-box-shadow:0 1px 4px rgba(0,105,214,0.25);box-shadow:0 1px 4px rgba(0,105,214,0.25)}.thumbnail>img{display:block;max-width:100%;margin-right:auto;margin-left:auto}.thumbnail .caption{padding:9px;color:#555}.label,.badge{font-size:11.844px;font-weight:bold;line-height:14px;color:#fff;text-shadow:0 -1px 0 rgba(0,0,0,0.25);white-space:nowrap;vertical-align:baseline;background-color:#999}.label{padding:1px 4px 2px;-webkit-border-radius:3px;-moz-border-radius:3px;border-radius:3px}.badge{padding:1px 9px 2px;-webkit-border-radius:9px;-moz-border-radius:9px;border-radius:9px}a.label:hover,a.badge:hover{color:#fff;text-decoration:none;cursor:pointer}.label-important,.badge-important{background-color:#b94a48}.label-important[href],.badge-important[href]{background-color:#953b39}.label-warning,.badge-warning{background-color:#f89406}.label-warning[href],.badge-warning[href]{background-color:#c67605}.label-success,.badge-success{background-color:#468847}.label-success[href],.badge-success[href]{background-color:#356635}.label-info,.badge-info{background-color:#3a87ad}.label-info[href],.badge-info[href]{background-color:#2d6987}.label-inverse,.badge-inverse{background-color:#333}.label-inverse[href],.badge-inverse[href]{background-color:#1a1a1a}.btn .label,.btn .badge{position:relative;top:-1px}.btn-mini .label,.btn-mini .badge{top:0}@-webkit-keyframes progress-bar-stripes{from{background-position:40px 0}to{background-position:0 0}}@-moz-keyframes progress-bar-stripes{from{background-position:40px 0}to{background-position:0 0}}@-ms-keyframes progress-bar-stripes{from{background-position:40px 0}to{background-position:0 0}}@-o-keyframes progress-bar-stripes{from{background-position:0 0}to{background-position:40px 0}}@keyframes progress-bar-stripes{from{background-position:40px 0}to{background-position:0 0}}.progress{height:20px;margin-bottom:20px;overflow:hidden;background-color:#f7f7f7;background-image:-moz-linear-gradient(top,#f5f5f5,#f9f9f9);background-image:-webkit-gradient(linear,0 0,0 100%,from(#f5f5f5),to(#f9f9f9));background-image:-webkit-linear-gradient(top,#f5f5f5,#f9f9f9);background-image:-o-linear-gradient(top,#f5f5f5,#f9f9f9);background-image:linear-gradient(to bottom,#f5f5f5,#f9f9f9);background-repeat:repeat-x;-webkit-border-radius:4px;-moz-border-radius:4px;border-radius:4px;filter:progid:dximagetransform.microsoft.gradient(startColorstr=''#fff5f5f5'',endColorstr=''#fff9f9f9'',GradientType=0);-webkit-box-shadow:inset 0 1px 2px rgba(0,0,0,0.1);-moz-box-shadow:inset 0 1px 2px rgba(0,0,0,0.1);box-shadow:inset 0 1px 2px rgba(0,0,0,0.1)}.progress .bar{float:left;width:0;height:100%;font-size:12px;color:#fff;text-align:center;text-shadow:0 -1px 0 rgba(0,0,0,0.25);background-color:#0e90d2;background-image:-moz-linear-gradient(top,#149bdf,#0480be);background-image:-webkit-gradient(linear,0 0,0 100%,from(#149bdf),to(#0480be));background-image:-webkit-linear-gradient(top,#149bdf,#0480be);background-image:-o-linear-gradient(top,#149bdf,#0480be);background-image:linear-gradient(to bottom,#149bdf,#0480be);background-repeat:repeat-x;filter:progid:dximagetransform.microsoft.gradient(startColorstr=''#ff149bdf'',endColorstr=''#ff0480be'',GradientType=0);-webkit-box-shadow:inset 0 -1px 0 rgba(0,0,0,0.15);-moz-box-shadow:inset 0 -1px 0 rgba(0,0,0,0.15);box-shadow:inset 0 -1px 0 rgba(0,0,0,0.15);-webkit-box-sizing:border-box;-moz-box-sizing:border-box;box-sizing:border-box;-webkit-transition:width .6s ease;-moz-transition:width .6s ease;-o-transition:width .6s ease;transition:width .6s ease}.progress .bar+.bar{-webkit-box-shadow:inset 1px 0 0 rgba(0,0,0,0.15),inset 0 -1px 0 rgba(0,0,0,0.15);-moz-box-shadow:inset 1px 0 0 rgba(0,0,0,0.15),inset 0 -1px 0 rgba(0,0,0,0.15);box-shadow:inset 1px 0 0 rgba(0,0,0,0.15),inset 0 -1px 0 rgba(0,0,0,0.15)}.progress-striped .bar{background-color:#149bdf;background-image:-webkit-gradient(linear,0 100%,100% 0,color-stop(0.25,rgba(255,255,255,0.15)),color-stop(0.25,transparent),color-stop(0.5,transparent),color-stop(0.5,rgba(255,255,255,0.15)),color-stop(0.75,rgba(255,255,255,0.15)),color-stop(0.75,transparent),to(transparent));background-image:-webkit-linear-gradient(45deg,rgba(255,255,255,0.15) 25%,transparent 25%,transparent 50%,rgba(255,255,255,0.15) 50%,rgba(255,255,255,0.15) 75%,transparent 75%,transparent);background-image:-moz-linear-gradient(45deg,rgba(255,255,255,0.15) 25%,transparent 25%,transparent 50%,rgba(255,255,255,0.15) 50%,rgba(255,255,255,0.15) 75%,transparent 75%,transparent);background-image:-o-linear-gradient(45deg,rgba(255,255,255,0.15) 25%,transparent 25%,transparent 50%,rgba(255,255,255,0.15) 50%,rgba(255,255,255,0.15) 75%,transparent 75%,transparent);background-image:linear-gradient(45deg,rgba(255,255,255,0.15) 25%,transparent 25%,transparent 50%,rgba(255,255,255,0.15) 50%,rgba(255,255,255,0.15) 75%,transparent 75%,transparent);-webkit-background-size:40px 40px;-moz-background-size:40px 40px;-o-background-size:40px 40px;background-size:40px 40px}.progress.active .bar{-webkit-animation:progress-bar-stripes 2s linear infinite;-moz-animation:progress-bar-stripes 2s linear infinite;-ms-animation:progress-bar-stripes 2s linear infinite;-o-animation:progress-bar-stripes 2s linear infinite;animation:progress-bar-stripes 2s linear infinite}.progress-danger .bar,.progress .bar-danger{background-color:#dd514c;background-image:-moz-linear-gradient(top,#ee5f5b,#c43c35);background-image:-webkit-gradient(linear,0 0,0 100%,from(#ee5f5b),to(#c43c35));background-image:-webkit-linear-gradient(top,#ee5f5b,#c43c35);background-image:-o-linear-gradient(top,#ee5f5b,#c43c35);background-image:linear-gradient(to bottom,#ee5f5b,#c43c35);background-repeat:repeat-x;filter:progid:dximagetransform.microsoft.gradient(startColorstr=''#ffee5f5b'',endColorstr=''#ffc43c35'',GradientType=0)}.progress-danger.progress-striped .bar,.progress-striped .bar-danger{background-color:#ee5f5b;background-image:-webkit-gradient(linear,0 100%,100% 0,color-stop(0.25,rgba(255,255,255,0.15)),color-stop(0.25,transparent),color-stop(0.5,transparent),color-stop(0.5,rgba(255,255,255,0.15)),color-stop(0.75,rgba(255,255,255,0.15)),color-stop(0.75,transparent),to(transparent));background-image:-webkit-linear-gradient(45deg,rgba(255,255,255,0.15) 25%,transparent 25%,transparent 50%,rgba(255,255,255,0.15) 50%,rgba(255,255,255,0.15) 75%,transparent 75%,transparent);background-image:-moz-linear-gradient(45deg,rgba(255,255,255,0.15) 25%,transparent 25%,transparent 50%,rgba(255,255,255,0.15) 50%,rgba(255,255,255,0.15) 75%,transparent 75%,transparent);background-image:-o-linear-gradient(45deg,rgba(255,255,255,0.15) 25%,transparent 25%,transparent 50%,rgba(255,255,255,0.15) 50%,rgba(255,255,255,0.15) 75%,transparent 75%,transparent);background-image:linear-gradient(45deg,rgba(255,255,255,0.15) 25%,transparent 25%,transparent 50%,rgba(255,255,255,0.15) 50%,rgba(255,255,255,0.15) 75%,transparent 75%,transparent)}.progress-success .bar,.progress .bar-success{background-color:#5eb95e;background-image:-moz-linear-gradient(top,#62c462,#57a957);background-image:-webkit-gradient(linear,0 0,0 100%,from(#62c462),to(#57a957));background-image:-webkit-linear-gradient(top,#62c462,#57a957);background-image:-o-linear-gradient(top,#62c462,#57a957);background-image:linear-gradient(to bottom,#62c462,#57a957);background-repeat:repeat-x;filter:progid:dximagetransform.microsoft.gradient(startColorstr=''#ff62c462'',endColorstr=''#ff57a957'',GradientType=0)}.progress-success.progress-striped .bar,.progress-striped .bar-success{background-color:#62c462;background-image:-webkit-gradient(linear,0 100%,100% 0,color-stop(0.25,rgba(255,255,255,0.15)),color-stop(0.25,transparent),color-stop(0.5,transparent),color-stop(0.5,rgba(255,255,255,0.15)),color-stop(0.75,rgba(255,255,255,0.15)),color-stop(0.75,transparent),to(transparent));background-image:-webkit-linear-gradient(45deg,rgba(255,255,255,0.15) 25%,transparent 25%,transparent 50%,rgba(255,255,255,0.15) 50%,rgba(255,255,255,0.15) 75%,transparent 75%,transparent);background-image:-moz-linear-gradient(45deg,rgba(255,255,255,0.15) 25%,transparent 25%,transparent 50%,rgba(255,255,255,0.15) 50%,rgba(255,255,255,0.15) 75%,transparent 75%,transparent);background-image:-o-linear-gradient(45deg,rgba(255,255,255,0.15) 25%,transparent 25%,transparent 50%,rgba(255,255,255,0.15) 50%,rgba(255,255,255,0.15) 75%,transparent 75%,transparent);background-image:linear-gradient(45deg,rgba(255,255,255,0.15) 25%,transparent 25%,transparent 50%,rgba(255,255,255,0.15) 50%,rgba(255,255,255,0.15) 75%,transparent 75%,transparent)}.progress-info .bar,.progress .bar-info{background-color:#4bb1cf;background-image:-moz-linear-gradient(top,#5bc0de,#339bb9);background-image:-webkit-gradient(linear,0 0,0 100%,from(#5bc0de),to(#339bb9));background-image:-webkit-linear-gradient(top,#5bc0de,#339bb9);background-image:-o-linear-gradient(top,#5bc0de,#339bb9);background-image:linear-gradient(to bottom,#5bc0de,#339bb9);background-repeat:repeat-x;filter:progid:dximagetransform.microsoft.gradient(startColorstr=''#ff5bc0de'',endColorstr=''#ff339bb9'',GradientType=0)}.progress-info.progress-striped .bar,.progress-striped .bar-info{background-color:#5bc0de;background-image:-webkit-gradient(linear,0 100%,100% 0,color-stop(0.25,rgba(255,255,255,0.15)),color-stop(0.25,transparent),color-stop(0.5,transparent),color-stop(0.5,rgba(255,255,255,0.15)),color-stop(0.75,rgba(255,255,255,0.15)),color-stop(0.75,transparent),to(transparent));background-image:-webkit-linear-gradient(45deg,rgba(255,255,255,0.15) 25%,transparent 25%,transparent 50%,rgba(255,255,255,0.15) 50%,rgba(255,255,255,0.15) 75%,transparent 75%,transparent);background-image:-moz-linear-gradient(45deg,rgba(255,255,255,0.15) 25%,transparent 25%,transparent 50%,rgba(255,255,255,0.15) 50%,rgba(255,255,255,0.15) 75%,transparent 75%,transparent);background-image:-o-linear-gradient(45deg,rgba(255,255,255,0.15) 25%,transparent 25%,transparent 50%,rgba(255,255,255,0.15) 50%,rgba(255,255,255,0.15) 75%,transparent 75%,transparent);background-image:linear-gradient(45deg,rgba(255,255,255,0.15) 25%,transparent 25%,transparent 50%,rgba(255,255,255,0.15) 50%,rgba(255,255,255,0.15) 75%,transparent 75%,transparent)}.progress-warning .bar,.progress .bar-warning{background-color:#faa732;background-image:-moz-linear-gradient(top,#fbb450,#f89406);background-image:-webkit-gradient(linear,0 0,0 100%,from(#fbb450),to(#f89406));background-image:-webkit-linear-gradient(top,#fbb450,#f89406);background-image:-o-linear-gradient(top,#fbb450,#f89406);background-image:linear-gradient(to bottom,#fbb450,#f89406);background-repeat:repeat-x;filter:progid:dximagetransform.microsoft.gradient(startColorstr=''#fffbb450'',endColorstr=''#fff89406'',GradientType=0)}.progress-warning.progress-striped .bar,.progress-striped .bar-warning{background-color:#fbb450;background-image:-webkit-gradient(linear,0 100%,100% 0,color-stop(0.25,rgba(255,255,255,0.15)),color-stop(0.25,transparent),color-stop(0.5,transparent),color-stop(0.5,rgba(255,255,255,0.15)),color-stop(0.75,rgba(255,255,255,0.15)),color-stop(0.75,transparent),to(transparent));background-image:-webkit-linear-gradient(45deg,rgba(255,255,255,0.15) 25%,transparent 25%,transparent 50%,rgba(255,255,255,0.15) 50%,rgba(255,255,255,0.15) 75%,transparent 75%,transparent);background-image:-moz-linear-gradient(45deg,rgba(255,255,255,0.15) 25%,transparent 25%,transparent 50%,rgba(255,255,255,0.15) 50%,rgba(255,255,255,0.15) 75%,transparent 75%,transparent);background-image:-o-linear-gradient(45deg,rgba(255,255,255,0.15) 25%,transparent 25%,transparent 50%,rgba(255,255,255,0.15) 50%,rgba(255,255,255,0.15) 75%,transparent 75%,transparent);background-image:linear-gradient(45deg,rgba(255,255,255,0.15) 25%,transparent 25%,transparent 50%,rgba(255,255,255,0.15) 50%,rgba(255,255,255,0.15) 75%,transparent 75%,transparent)}.accordion{margin-bottom:20px}.accordion-group{margin-bottom:2px;border:1px solid #e5e5e5;-webkit-border-radius:4px;-moz-border-radius:4px;border-radius:4px}.accordion-heading{border-bottom:0}.accordion-heading .accordion-toggle{display:block;padding:8px 15px}.accordion-toggle{cursor:pointer}.accordion-inner{padding:9px 15px;border-top:1px solid #e5e5e5}.carousel{position:relative;margin-bottom:20px;line-height:1}.carousel-inner{position:relative;width:100%;overflow:hidden}.carousel .item{position:relative;display:none;-webkit-transition:.6s ease-in-out left;-moz-transition:.6s ease-in-out left;-o-transition:.6s ease-in-out left;transition:.6s ease-in-out left}.carousel .item>img{display:block;line-height:1}.carousel .active,.carousel .next,.carousel .prev{display:block}.carousel .active{left:0}.carousel .next,.carousel .prev{position:absolute;top:0;width:100%}.carousel .next{left:100%}.carousel .prev{left:-100%}.carousel .next.left,.carousel .prev.right{left:0}.carousel .active.left{left:-100%}.carousel .active.right{left:100%}.carousel-control{position:absolute;top:40%;left:15px;width:40px;height:40px;margin-top:-20px;font-size:60px;font-weight:100;line-height:30px;color:#fff;text-align:center;background:#222;border:3px solid #fff;-webkit-border-radius:23px;-moz-border-radius:23px;border-radius:23px;opacity:.5;filter:alpha(opacity=50)}.carousel-control.right{right:15px;left:auto}.carousel-control:hover{color:#fff;text-decoration:none;opacity:.9;filter:alpha(opacity=90)}.carousel-caption{position:absolute;right:0;bottom:0;left:0;padding:15px;background:#333;background:rgba(0,0,0,0.75)}.carousel-caption h4,.carousel-caption p{line-height:20px;color:#fff}.carousel-caption h4{margin:0 0 5px}.carousel-caption p{margin-bottom:0}.hero-unit{padding:60px;margin-bottom:30px;background-color:#eee;-webkit-border-radius:6px;-moz-border-radius:6px;border-radius:6px}.hero-unit h1{margin-bottom:0;font-size:60px;line-height:1;letter-spacing:-1px;color:inherit}.hero-unit p{font-size:18px;font-weight:200;line-height:30px;color:inherit}.pull-right{float:right}.pull-left{float:left}.hide{display:none}.show{display:block}.invisible{visibility:hidden}.affix{position:fixed}
'! !

!OHFileRequestHandler methodsFor: 'request handling' stamp: 'tbn 10/29/2012 21:12'!
handleRequest: aRequest
	(#('files//' 'files') includes: aRequest uri path)   ifTrue: [^ZnResponse unauthorized: 'No permisson'].
	(aRequest uri path = 'files/bootstrap.min.css') ifTrue: [^self cssResponseFor: #cssbootstrapminCssContent ].
	(aRequest uri path = 'files/bootstrap.min.js') ifTrue: [^self javaScriptResponseFor: #jsbootstrapminJsContent ].
	(aRequest uri path = 'files/glyphicons-halflings.png') ifTrue: [^self imagePNGResponseFor: #imgglyphiconshalflingsPngContent ].	
	(aRequest uri path = 'files/glyphicons-halflings-white.png') ifTrue: [^self imagePNGResponseFor: #imgglyphiconshalflingswhitePngContent ].						
	^ZnResponse notFound: aRequest uri! !

!OHFileRequestHandler methodsFor: 'private' stamp: 'tbn 10/29/2012 21:07'!
imagePNGResponseFor: aContentSelector

	^self respondWith: (self perform: aContentSelector) usingMIMEType: 'image/png'
	! !

!OHFileRequestHandler methodsFor: 'uploads' stamp: 'tbn 10/29/2012 20:41'!
imgglyphiconshalflingsPngContent
	^ #(137 80 78 71 13 10 26 10 0 0 0 13 73 72 68 82 0 0 1 213 0 0 0 159 8 4 0 0 0 5 4 139 194 0 0 0 25 116 69 88 116 83 111 102 116 119 97 114 101 0 65 100 111 98 101 32 73 109 97 103 101 82 101 97 100 121 113 201 101 60 0 0 49 161 73 68 65 84 120 218 237 125 109 108 92 69 186 166 87 178 180 94 201 186 182 68 36 124 110 28 119 39 254 160 59 118 127 209 142 199 56 141 109 48 249 152 107 60 102 217 56 217 128 179 14 19 60 203 104 51 36 136 12 32 18 8 12 98 44 109 110 228 160 204 13 163 32 210 147 17 23 184 215 18 190 171 48 241 222 31 76 32 89 96 54 115 39 29 62 6 20 172 81 2 1 188 191 174 29 183 238 159 253 83 251 190 167 186 250 156 110 159 83 245 86 167 59 49 75 189 71 137 219 246 115 234 212 169 243 62 85 111 189 199 245 84 85 149 49 99 198 150 157 89 117 214 188 197 236 99 222 249 97 38 247 163 194 35 67 44 112 216 154 196 18 20 184 62 107 218 186 12 23 159 182 250 150 85 131 76 87 10 15 45 115 198 110 199 51 86 157 113 188 235 126 78 154 254 163 239 111 214 24 252 99 232 199 248 73 187 126 76 197 0 27 21 163 123 255 224 45 9 198 250 241 72 56 37 95 232 239 157 77 178 194 163 119 246 66 191 226 178 54 69 87 178 213 44 196 162 112 134 188 25 130 172 157 197 89 2 254 15 50 43 173 40 89 179 235 176 2 240 64 160 239 177 38 225 243 65 187 47 154 182 2 164 6 142 181 51 107 88 227 129 104 224 27 223 141 216 45 25 97 141 239 170 31 179 215 65 192 7 212 232 60 62 80 248 149 140 39 92 193 163 155 74 203 59 40 248 125 134 35 0 155 81 122 132 150 255 148 128 135 58 52 195 253 37 109 63 110 102 162 110 116 75 42 24 192 175 178 230 108 203 57 74 201 216 218 43 161 68 222 238 73 167 253 89 117 49 89 145 168 172 90 94 156 160 40 30 93 89 89 69 173 190 102 64 236 157 192 30 226 208 158 174 108 88 225 238 122 93 135 85 215 116 165 29 16 9 168 143 117 185 13 190 38 225 1 53 45 80 154 164 237 87 128 125 131 254 64 116 240 145 124 221 35 76 245 152 89 127 146 61 251 180 115 240 159 200 220 130 31 172 198 249 44 119 35 7 43 190 82 241 148 43 20 63 145 198 139 97 214 120 209 255 9 88 233 48 248 14 34 16 27 101 97 41 157 116 253 71 23 15 221 42 212 161 119 86 16 174 119 22 235 86 94 170 194 0 114 102 37 120 66 4 40 8 113 214 188 188 52 62 154 22 31 252 87 213 71 182 35 221 4 241 142 108 87 17 85 60 208 129 204 248 209 19 187 88 74 86 209 182 183 147 108 247 139 172 193 190 82 253 196 238 36 107 253 68 86 114 211 73 175 174 163 233 164 55 58 240 88 60 143 115 62 37 88 224 49 2 157 190 78 178 142 69 122 15 26 249 186 119 150 138 167 59 121 210 238 57 239 122 192 57 248 79 212 37 23 126 150 227 151 126 165 225 117 169 202 201 151 4 42 250 61 177 170 170 196 231 73 27 209 120 145 99 225 121 125 174 246 31 28 89 40 254 163 235 111 214 24 18 149 117 10 194 177 78 36 171 94 24 172 106 159 254 11 238 174 187 255 2 101 92 245 137 105 88 237 241 157 156 172 93 217 227 59 89 45 165 114 135 246 0 215 227 172 17 209 178 138 38 190 129 62 186 33 127 165 122 108 8 89 201 97 86 72 86 78 212 176 207 57 61 135 139 93 138 31 61 135 253 31 141 152 176 199 109 82 175 204 77 222 253 30 142 27 127 100 187 26 175 79 85 28 67 11 169 74 27 85 105 84 21 125 114 241 87 26 190 168 87 39 18 21 159 218 185 117 170 184 41 202 162 132 233 22 247 31 203 70 34 89 85 254 35 240 252 80 227 215 190 159 132 231 234 38 220 145 237 208 133 207 232 204 82 229 79 192 170 139 216 119 121 122 219 233 109 3 25 36 171 170 187 79 178 209 223 20 254 115 63 32 32 43 94 144 70 84 219 193 234 221 223 73 144 69 225 113 247 37 185 243 38 153 155 172 130 168 126 231 12 62 238 77 213 193 199 125 93 177 225 212 150 226 16 187 119 22 238 187 65 134 239 153 27 63 10 14 91 203 250 247 78 116 101 101 120 110 238 40 229 230 142 170 149 159 171 66 186 100 26 157 207 77 84 217 20 170 112 202 165 154 110 113 255 113 238 83 233 63 154 248 216 98 87 150 251 188 232 144 88 109 87 54 241 141 206 120 42 123 2 86 95 227 187 248 251 169 33 86 195 106 206 167 240 115 227 187 86 76 94 106 239 145 194 127 133 13 88 107 207 81 106 169 85 244 255 174 208 54 156 5 215 235 115 30 107 148 245 204 169 110 126 253 91 252 113 242 199 184 254 45 255 166 96 13 216 79 21 31 3 25 25 145 160 201 58 71 166 28 244 200 20 235 148 221 55 226 135 223 108 181 131 34 107 184 153 253 199 127 144 227 237 115 82 249 25 101 138 50 170 174 118 29 242 81 213 61 206 81 198 188 74 207 85 173 88 96 161 29 103 158 1 26 81 121 126 19 9 196 143 238 75 131 183 200 176 220 127 176 69 176 93 212 254 35 240 252 80 227 187 231 58 151 116 166 157 217 100 182 92 84 189 47 117 199 31 241 247 155 218 248 157 227 231 59 254 216 179 249 58 168 74 203 99 45 37 39 166 160 101 231 141 255 12 28 113 129 147 213 10 4 63 2 106 188 34 47 121 104 134 133 172 52 142 172 56 162 90 105 22 26 154 241 191 194 249 212 210 49 242 124 74 85 255 167 239 117 240 15 62 162 190 95 196 255 205 78 235 204 221 59 104 120 119 191 78 25 85 11 211 74 178 81 85 55 3 92 233 185 106 243 169 132 29 204 174 98 84 162 58 163 175 152 179 202 2 66 225 63 54 241 8 254 163 235 111 189 127 74 176 194 49 206 138 37 136 243 73 10 85 89 45 31 73 131 239 217 105 52 123 132 61 159 114 199 164 55 136 170 64 41 72 136 75 231 74 43 134 102 18 152 52 207 88 25 254 56 67 215 100 195 63 39 106 216 14 131 49 244 197 252 32 146 149 22 78 209 242 215 60 155 11 51 218 57 252 159 146 213 69 60 140 119 223 172 134 128 86 141 135 247 122 151 69 125 224 253 94 95 101 230 170 180 12 112 165 231 170 31 116 235 182 190 51 250 138 57 171 44 227 170 235 63 186 248 177 103 146 108 205 89 247 79 214 192 184 60 246 140 206 120 170 120 2 213 124 134 186 146 97 22 216 142 249 170 85 101 151 133 170 240 70 245 178 211 235 135 9 243 49 22 218 59 129 147 123 12 69 70 211 48 15 96 129 5 255 198 227 68 197 82 145 166 252 43 146 85 214 20 14 89 105 68 229 217 223 209 52 235 30 63 138 89 96 29 124 66 129 135 190 115 50 200 220 121 105 112 155 73 255 113 227 187 62 87 213 111 253 13 167 4 86 156 185 225 84 249 252 71 219 223 26 122 103 35 248 10 37 150 139 17 207 68 48 35 220 160 51 158 170 152 19 91 116 166 105 3 153 216 162 186 27 40 11 85 215 44 196 93 206 49 50 53 144 217 124 238 248 78 197 204 173 1 102 119 216 55 119 179 32 230 154 237 198 11 248 191 117 43 14 190 194 138 23 217 194 93 168 68 181 98 93 223 194 75 166 32 156 217 120 98 87 234 11 213 155 55 29 124 227 149 208 146 250 135 88 227 149 155 149 1 174 252 123 85 221 214 199 24 137 99 249 153 24 71 149 207 127 244 241 88 135 8 107 194 172 254 124 19 139 40 255 0 104 41 73 85 204 97 41 22 255 108 112 32 51 144 249 108 16 250 238 212 117 80 85 252 93 68 146 240 151 41 169 47 16 55 126 52 87 137 22 184 116 7 53 25 229 188 24 74 125 177 251 86 191 7 233 249 10 88 245 48 171 167 134 122 230 32 203 86 77 169 195 198 59 62 190 71 212 153 213 94 232 127 160 175 124 248 184 103 70 58 206 228 163 106 97 90 233 187 246 94 21 41 55 52 67 35 106 238 25 119 114 44 208 181 83 245 108 245 252 71 31 143 117 216 59 49 144 233 204 118 207 109 62 7 127 60 209 41 191 15 125 170 242 171 60 189 235 240 86 90 11 117 101 219 160 68 231 159 43 106 213 121 135 150 235 175 26 171 74 54 86 123 106 11 253 177 146 75 173 129 62 180 134 90 3 247 213 225 81 213 150 15 239 253 183 38 254 109 90 58 158 150 1 190 49 239 85 161 77 66 229 126 162 229 242 31 10 30 198 97 24 237 192 131 58 228 47 225 156 151 58 75 255 87 158 87 79 29 210 160 38 133 173 159 170 186 89 6 180 170 174 50 102 236 6 249 143 241 55 99 198 140 25 51 102 204 152 49 99 198 140 25 51 102 204 152 49 99 198 140 25 51 102 204 152 49 99 198 140 25 51 102 204 152 177 229 103 165 200 42 26 51 102 236 70 19 53 221 76 16 98 180 145 165 8 78 142 193 50 35 84 102 61 67 233 16 96 33 25 150 127 16 14 252 90 71 175 85 101 234 163 135 135 101 130 197 50 86 195 21 169 207 60 156 49 109 107 83 164 201 229 3 30 197 52 105 207 151 42 46 154 123 78 252 56 88 153 97 4 106 126 6 142 233 239 218 128 226 110 65 154 120 44 255 151 215 37 102 69 58 195 124 233 89 152 68 86 247 106 11 10 158 235 172 194 162 218 108 103 54 194 40 58 171 107 126 140 165 247 77 246 77 226 215 53 63 166 52 9 93 87 79 183 62 186 248 232 175 139 87 165 200 23 163 151 90 31 148 21 105 71 252 124 152 81 203 71 252 74 22 101 180 231 75 91 89 99 213 181 185 112 109 106 69 92 102 47 190 199 142 56 38 188 79 81 255 51 205 32 25 139 226 156 246 253 46 51 25 116 185 234 116 50 39 189 45 86 224 56 223 249 225 133 112 131 88 181 83 176 114 199 89 35 74 33 171 251 241 81 240 184 234 127 32 131 34 164 44 117 98 215 64 70 173 179 26 250 20 75 223 58 190 117 220 94 237 249 105 121 169 170 91 31 93 60 46 67 119 175 139 0 157 131 175 43 87 31 92 141 41 191 239 98 188 170 157 10 107 175 114 45 161 23 4 229 131 238 46 77 162 6 116 164 23 218 128 212 77 168 145 113 198 202 132 21 245 143 192 178 254 211 219 176 30 167 183 141 166 35 36 157 94 88 36 158 209 34 156 141 167 137 189 187 241 86 96 149 84 138 52 153 27 25 109 225 210 126 247 119 37 80 181 112 49 183 154 124 133 43 38 85 120 212 89 5 137 138 56 171 197 42 194 114 178 56 58 163 236 230 172 0 23 244 224 107 55 81 208 131 210 128 84 170 186 235 3 226 147 202 250 184 240 147 214 36 1 31 136 219 2 208 142 245 206 198 153 191 10 129 83 62 126 167 83 31 252 174 245 181 132 106 204 115 225 173 58 53 222 113 46 119 176 38 95 90 46 4 244 88 61 149 170 137 252 58 222 136 98 119 6 235 96 148 193 26 210 32 95 224 8 107 100 130 123 39 162 202 48 219 58 216 100 199 14 220 115 212 254 35 240 171 24 113 171 141 28 190 105 33 50 50 52 211 246 149 252 110 113 137 92 146 57 132 45 145 170 75 85 23 84 228 115 83 85 189 236 27 117 86 15 111 21 149 64 59 188 85 174 179 122 219 62 94 250 161 61 188 151 78 178 219 246 149 143 170 238 250 112 188 188 62 2 111 245 133 80 193 191 79 133 199 218 23 10 144 160 64 73 251 19 234 250 64 224 27 163 215 39 71 147 144 106 53 169 27 111 175 42 85 174 62 21 238 228 94 171 42 145 101 155 119 139 18 228 62 205 171 202 167 135 215 225 171 160 18 81 176 134 148 53 12 205 132 175 202 231 134 60 36 231 35 158 53 182 74 210 217 187 241 168 106 210 246 54 101 238 41 240 219 95 13 253 238 249 251 100 93 177 211 50 130 176 150 66 58 192 135 170 94 242 40 42 178 58 56 74 202 193 209 89 21 213 83 233 172 134 174 242 210 239 75 221 151 147 232 12 93 85 52 95 198 114 106 164 8 123 220 245 225 53 146 215 135 227 97 199 145 47 237 121 243 151 86 157 2 255 63 147 236 71 191 116 255 228 71 191 4 17 172 15 212 245 137 98 64 120 80 85 159 228 55 2 79 51 167 124 170 233 141 170 9 15 255 73 176 242 81 53 206 30 221 81 252 179 71 119 196 9 42 25 40 59 179 119 162 25 102 183 48 42 215 80 240 85 85 143 60 16 89 164 198 148 136 255 241 182 118 134 178 188 254 98 161 206 116 194 246 53 123 50 33 235 44 125 169 138 189 236 210 166 150 143 148 58 41 7 183 206 106 50 79 107 153 206 170 21 19 146 39 16 12 214 138 48 73 46 113 92 40 196 37 111 106 81 31 203 22 166 226 196 150 213 135 227 97 60 234 182 235 212 141 139 148 101 120 220 65 103 116 139 251 39 163 91 100 59 215 184 219 7 30 249 171 170 250 96 114 200 99 100 187 236 27 158 166 150 106 8 160 138 80 185 70 85 221 36 148 23 85 101 74 189 73 54 217 84 252 179 201 38 90 125 170 170 238 122 20 191 222 245 40 149 122 247 12 118 102 117 168 122 207 32 191 155 123 6 125 219 191 223 157 209 229 221 158 108 120 147 206 85 245 26 90 23 239 232 172 138 199 46 215 89 229 178 159 98 204 206 231 21 127 37 187 134 142 16 151 168 15 110 119 192 183 64 144 215 199 169 191 184 83 57 222 214 124 197 186 115 37 218 62 203 22 95 245 111 35 167 252 158 57 216 92 164 69 85 126 255 5 47 221 218 129 247 116 18 40 114 157 91 189 81 181 20 170 90 117 3 153 3 251 79 111 59 176 159 203 232 29 219 33 77 114 85 187 93 219 206 48 84 211 234 99 5 112 68 197 145 213 63 0 46 172 245 218 99 27 206 234 80 117 237 177 205 231 172 24 70 128 178 128 153 251 178 59 15 156 188 30 170 138 76 95 185 169 170 171 179 138 249 83 222 211 98 125 184 82 47 140 74 95 203 231 14 43 25 223 212 104 165 50 36 23 245 97 181 163 105 144 11 173 85 213 199 169 191 184 83 57 62 191 141 208 132 125 55 19 170 54 114 202 7 169 181 122 117 249 222 237 249 224 126 229 155 189 52 173 253 111 196 168 10 49 74 156 173 128 20 209 10 181 140 94 177 204 152 227 192 126 163 24 30 163 105 30 0 67 222 184 129 53 192 255 53 20 60 80 239 218 190 157 114 239 47 196 71 190 30 255 89 235 107 224 171 181 148 151 53 162 109 75 10 128 139 19 50 229 167 170 158 206 170 53 44 194 223 222 63 241 49 39 31 2 15 211 106 195 147 81 148 250 192 112 23 84 235 190 186 240 246 198 10 42 188 243 126 209 73 63 72 213 215 157 242 171 41 58 180 250 186 181 92 169 249 249 251 232 248 74 143 170 58 51 231 209 180 23 85 71 21 111 41 88 240 196 46 204 195 139 188 177 234 42 2 127 106 139 92 247 190 24 63 125 223 227 137 142 197 71 126 65 123 89 35 198 87 17 18 47 51 170 234 233 172 182 191 33 202 188 227 143 248 61 223 239 67 246 103 4 197 117 9 42 212 254 245 117 95 245 240 222 174 43 171 81 101 235 131 53 194 119 175 58 248 202 207 85 233 134 234 203 75 169 138 63 85 156 87 139 27 49 106 92 199 198 83 53 47 29 60 171 1 122 55 80 94 214 240 247 170 60 19 44 83 164 20 191 21 106 136 85 85 56 252 220 16 170 234 232 172 118 44 138 50 135 95 198 239 135 95 22 223 251 105 218 235 187 138 174 238 171 30 94 159 170 165 214 7 19 82 3 25 53 30 94 118 164 246 78 108 62 71 215 185 93 250 103 133 254 245 119 246 188 115 14 249 110 11 122 84 117 79 61 138 63 47 15 147 211 219 253 122 198 178 99 62 218 254 6 206 159 24 98 182 35 55 214 187 99 103 146 230 107 191 254 222 155 84 157 85 151 2 106 144 247 169 42 45 84 61 21 93 221 250 232 227 117 117 125 175 163 62 221 168 218 78 208 173 13 217 248 14 29 157 91 13 93 226 148 7 58 37 47 95 155 12 174 235 83 247 122 93 54 68 46 212 109 174 135 131 172 196 236 68 55 85 198 140 25 51 102 204 152 49 99 198 140 25 51 102 204 152 49 99 198 140 25 51 102 204 152 49 99 198 140 25 51 102 204 152 49 99 198 140 25 51 102 204 152 49 99 5 230 250 163 236 180 62 222 74 19 52 104 235 80 80 133 174 43 171 167 65 155 59 39 157 71 95 174 88 75 161 218 109 76 171 133 152 53 73 46 125 44 119 70 70 117 167 222 109 36 83 150 45 165 69 141 45 59 195 149 10 67 51 73 45 21 96 7 207 66 235 223 82 157 213 120 49 190 136 210 147 84 177 74 221 149 59 104 206 138 156 56 163 11 68 234 89 248 170 74 141 130 27 23 111 59 180 231 192 254 222 217 16 89 194 154 53 140 31 77 178 205 231 228 75 183 172 201 176 77 127 157 181 59 154 170 190 37 80 186 148 142 0 100 57 75 238 104 148 248 128 110 231 180 68 24 91 122 175 197 103 86 104 232 44 174 127 18 165 39 67 3 25 186 10 112 33 94 77 214 40 179 87 75 50 170 88 165 62 85 81 130 196 37 226 246 176 94 131 16 155 112 56 9 203 189 214 94 35 144 206 150 216 132 21 20 43 46 64 151 212 241 103 234 67 234 122 37 201 148 26 4 45 80 114 11 10 150 130 184 75 191 88 255 136 10 188 133 130 166 110 211 193 22 183 62 189 187 215 61 139 213 148 222 209 168 240 197 101 83 22 118 82 151 215 21 163 146 76 151 122 170 242 189 214 53 37 57 85 81 83 32 162 161 2 92 140 87 145 213 171 217 202 75 213 246 39 220 104 153 112 41 23 195 180 10 74 183 148 114 152 104 161 223 13 158 238 157 77 48 202 70 12 162 206 40 102 29 95 164 82 53 241 7 47 201 47 47 167 2 71 239 228 43 24 243 170 139 245 254 163 177 14 182 120 9 28 49 34 232 191 254 179 168 101 83 240 250 11 53 133 144 10 173 214 58 84 245 246 102 127 190 240 61 43 138 55 20 201 81 21 201 167 167 2 92 140 151 147 181 178 84 69 162 161 160 167 115 252 224 188 172 239 114 198 223 222 89 174 115 56 250 27 149 28 38 134 107 237 236 249 251 182 255 173 170 35 112 83 213 138 53 157 4 77 224 179 84 170 98 171 170 68 220 138 91 78 103 161 53 81 210 92 115 199 26 237 0 53 80 66 64 91 241 0 56 201 168 145 86 49 170 20 170 162 164 175 172 38 246 166 52 87 115 121 30 91 154 199 190 10 159 119 210 85 128 189 241 50 178 86 150 170 182 238 236 55 5 193 194 55 148 128 106 239 196 212 208 212 208 222 137 100 94 126 89 102 183 237 67 169 171 95 130 192 104 59 97 46 204 199 234 38 134 77 174 10 105 157 32 30 167 22 20 194 85 150 170 186 26 22 186 1 170 87 112 122 115 3 96 62 247 47 214 34 164 212 39 79 242 73 157 246 225 218 219 178 231 139 28 27 121 5 137 138 155 128 4 22 172 58 27 207 66 122 100 245 195 251 147 181 242 84 141 23 244 159 113 194 163 239 157 61 208 185 138 173 98 7 58 133 130 176 34 252 189 186 249 109 171 47 190 1 209 45 47 80 220 29 247 87 193 68 81 243 199 180 205 144 226 255 53 201 238 254 31 55 159 170 186 26 22 250 170 23 250 1 109 229 2 96 244 23 72 253 165 29 37 65 157 218 243 86 181 210 33 201 72 188 212 155 215 191 165 18 23 181 247 64 8 34 81 163 182 0 122 227 197 28 222 139 124 235 223 146 84 214 7 191 254 45 239 179 42 79 85 253 94 186 251 210 166 54 252 186 169 173 251 18 33 200 238 139 67 119 132 2 107 209 124 104 162 38 5 72 100 53 142 76 69 89 224 121 18 145 142 39 217 198 163 55 159 170 37 189 42 211 60 67 39 64 173 108 0 140 132 27 153 98 33 119 0 76 187 87 87 26 40 4 37 248 210 219 67 16 223 230 143 52 20 175 131 23 131 129 230 251 163 185 51 92 187 250 20 147 15 132 179 164 251 208 120 225 173 244 250 183 188 207 42 141 170 189 179 167 183 81 70 188 210 168 26 133 60 241 233 109 167 183 133 31 142 18 186 131 208 223 131 28 103 63 223 137 204 30 195 251 168 164 184 31 18 94 177 15 41 68 138 125 134 123 223 85 142 170 214 152 29 124 141 81 8 173 155 207 213 61 67 39 64 173 124 0 140 25 117 119 0 76 187 215 130 81 176 69 175 61 145 63 254 120 43 214 120 165 13 34 190 219 254 151 103 253 221 228 83 17 213 11 239 79 212 210 168 106 235 228 215 136 13 46 212 193 102 113 106 91 253 232 155 89 224 163 192 71 205 164 253 67 195 236 225 231 132 147 109 62 7 123 232 252 61 41 173 20 176 198 90 175 37 217 157 191 167 80 9 187 140 7 250 42 71 213 230 220 93 235 7 192 149 200 0 47 151 0 184 56 3 76 23 1 212 205 0 119 129 186 36 63 56 127 252 241 77 185 41 92 196 175 171 17 228 163 16 181 24 47 35 170 55 85 135 102 100 55 39 54 180 16 27 92 16 104 49 239 10 118 2 73 146 24 102 148 69 73 114 152 152 199 61 144 127 189 49 248 119 246 220 92 242 87 75 214 30 158 86 90 5 196 72 16 19 75 252 156 103 254 90 137 131 205 161 157 36 6 109 164 228 120 183 139 201 210 32 37 5 156 203 13 127 221 25 96 106 125 212 84 117 84 28 129 129 246 81 74 90 175 232 42 72 62 42 81 221 120 107 76 70 84 191 16 192 31 239 222 121 134 147 85 213 20 197 127 2 161 45 134 41 145 195 180 14 98 190 174 105 65 168 217 243 124 113 96 193 191 70 173 5 27 39 193 159 31 212 43 9 152 225 231 52 94 81 182 121 11 180 120 139 206 72 41 146 30 238 35 196 116 94 173 149 63 64 93 94 25 96 65 213 82 234 83 138 170 113 25 168 106 103 158 66 58 197 114 60 104 204 134 202 25 82 21 110 17 133 2 213 202 122 212 22 148 223 80 206 166 203 41 17 167 242 91 21 43 149 110 11 234 210 77 217 88 1 254 72 33 135 166 180 185 127 48 230 141 231 73 15 247 129 137 148 114 6 156 203 13 175 239 115 75 207 161 213 167 20 85 227 82 50 240 203 84 9 88 253 103 0 198 180 218 179 69 253 19 99 198 140 25 51 102 204 152 49 99 198 140 25 51 102 204 152 49 99 198 140 25 51 102 204 152 49 99 198 140 25 51 102 204 152 49 99 198 110 142 193 106 185 192 178 168 199 180 121 22 198 140 73 136 218 120 81 252 113 186 20 55 102 77 131 238 203 52 69 22 204 70 159 177 46 195 250 151 51 52 60 46 231 6 105 148 225 146 59 155 225 101 208 146 105 154 178 178 49 99 37 57 249 186 230 238 75 9 233 202 17 238 134 205 160 50 20 129 127 205 74 141 67 148 236 110 198 213 119 217 4 252 15 248 12 69 194 164 249 99 144 70 249 138 130 180 134 161 19 96 142 224 53 118 54 171 37 203 191 93 248 51 184 170 84 171 252 121 236 196 96 141 126 157 154 168 97 162 178 178 91 91 22 219 74 31 171 62 75 15 15 247 219 183 108 60 50 239 45 52 191 89 138 231 75 226 104 103 81 176 174 246 76 211 196 120 156 86 167 119 222 80 182 236 126 209 201 3 31 77 13 245 206 166 190 144 143 145 184 48 108 32 51 154 198 133 214 97 197 138 73 84 136 25 200 128 104 119 74 172 19 109 188 168 172 232 193 168 173 153 20 120 73 77 164 213 185 165 184 124 157 171 85 55 120 203 134 83 189 179 126 50 157 2 223 149 29 63 138 107 7 87 49 107 15 165 252 189 19 67 51 93 217 227 59 89 173 149 110 83 222 1 151 186 210 145 65 23 237 31 101 186 88 202 89 122 248 56 44 39 130 120 137 60 13 18 107 55 75 21 120 145 157 131 222 194 93 214 249 36 179 165 120 190 36 142 118 22 5 235 180 103 152 84 35 119 251 147 59 111 240 31 201 253 242 194 64 11 8 200 122 161 95 86 208 218 247 109 225 110 124 162 29 72 214 181 239 203 104 29 229 216 90 103 45 94 84 65 110 171 175 45 135 12 41 131 224 150 175 64 30 52 157 91 42 212 57 120 75 227 197 198 139 231 214 193 178 178 106 5 62 197 26 33 44 7 1 172 86 116 203 58 101 249 176 212 15 151 194 113 18 110 56 37 111 104 20 178 202 233 83 132 40 50 232 92 81 135 203 94 233 97 105 103 233 225 241 26 237 184 70 151 184 51 128 179 118 179 84 85 68 25 86 184 108 146 81 200 234 133 167 172 87 165 99 221 237 25 37 146 85 224 229 170 101 142 113 169 52 159 210 157 194 186 47 237 190 85 190 16 13 165 36 134 95 230 159 81 21 33 194 228 180 62 188 181 248 17 201 213 116 215 124 233 32 215 44 200 155 2 71 60 22 116 223 67 247 165 193 91 212 120 84 88 109 102 124 236 3 183 60 169 196 79 218 161 175 77 84 217 2 124 40 119 58 204 220 227 95 88 218 21 8 164 211 254 106 55 119 176 180 179 116 241 188 229 19 32 187 10 65 88 223 205 166 170 112 217 36 137 26 94 120 90 171 82 177 238 246 164 145 213 193 235 106 172 120 148 238 20 230 214 96 240 51 20 61 17 226 94 177 15 241 28 127 108 108 177 43 203 151 101 187 31 81 226 27 217 56 28 103 56 86 11 135 145 43 254 57 77 203 239 1 235 47 163 170 192 7 158 143 0 150 111 232 49 52 115 110 157 98 20 155 12 161 30 235 116 88 217 220 141 23 219 115 138 253 201 252 215 118 69 192 108 43 64 92 140 146 101 184 28 44 229 44 183 99 209 174 226 60 167 40 134 194 105 245 72 86 89 170 114 151 165 81 195 11 79 21 55 163 97 221 237 73 169 145 62 81 37 100 213 35 106 85 213 134 179 124 59 12 72 175 216 91 98 200 194 193 238 185 206 172 199 35 202 202 198 225 161 25 28 171 243 2 44 87 233 115 55 78 84 25 49 4 126 221 212 233 109 16 38 199 187 178 123 39 32 92 173 150 227 159 190 183 11 146 98 237 66 75 74 18 190 111 56 229 37 183 33 15 152 133 128 36 149 170 81 151 155 168 207 106 58 169 135 47 166 82 88 41 36 83 121 170 22 222 179 127 12 228 141 167 235 16 82 176 133 68 85 103 95 68 251 131 232 187 166 198 74 207 92 209 253 234 18 181 170 106 223 78 174 168 214 150 83 85 59 126 183 63 182 247 79 137 188 104 152 115 115 253 23 100 225 245 198 163 125 147 14 54 206 40 84 13 60 22 205 213 95 158 52 201 239 220 18 98 53 248 245 212 22 214 32 163 94 78 11 170 246 248 78 140 37 56 81 101 106 70 188 55 116 111 231 164 238 77 121 219 211 169 234 96 41 103 157 91 167 135 47 166 210 208 204 199 247 220 124 170 186 239 193 63 6 242 198 211 169 74 193 230 229 117 220 71 167 186 253 227 76 239 229 157 149 142 23 222 47 127 61 163 67 84 220 160 104 100 202 105 102 72 186 212 248 99 199 158 129 249 230 217 226 71 52 246 140 44 188 238 248 243 225 245 142 178 96 146 68 213 158 195 123 39 120 253 163 202 71 95 112 47 53 248 226 137 64 109 32 43 215 36 106 86 212 72 168 188 138 51 213 97 15 34 133 144 42 197 169 28 44 229 44 161 251 72 191 74 210 181 175 15 200 184 133 84 94 81 121 170 162 111 38 73 195 137 23 158 74 85 26 86 119 87 31 167 253 195 76 231 101 77 184 248 126 3 143 241 215 51 116 162 162 189 147 16 143 28 178 187 65 169 227 54 244 206 218 193 114 204 221 119 201 164 202 54 156 141 178 213 191 237 191 32 208 242 157 92 48 72 192 76 37 76 170 26 88 53 234 146 99 168 161 198 231 147 64 160 72 72 195 131 4 90 139 186 124 78 86 220 203 43 55 87 77 171 195 30 123 252 173 166 168 30 23 99 105 103 233 226 133 224 42 188 206 234 164 200 184 85 154 170 220 55 105 195 137 23 158 26 171 208 177 122 138 136 250 100 245 32 42 204 12 63 21 175 103 116 228 199 88 245 145 237 56 238 245 204 157 79 169 176 88 205 8 238 176 58 239 244 93 50 252 201 141 93 217 112 94 176 184 43 43 242 199 62 193 248 19 184 65 148 232 219 86 218 155 69 237 123 226 230 225 11 147 2 180 68 66 46 200 38 168 30 47 197 210 206 210 195 227 53 54 159 131 169 65 227 114 120 89 35 220 149 22 247 121 225 41 244 163 99 75 81 20 116 200 170 243 178 166 224 126 173 0 206 240 182 255 173 234 245 140 199 197 33 32 236 153 59 182 67 125 30 202 131 238 157 24 200 116 102 123 230 54 159 131 36 78 167 252 28 86 115 106 11 254 185 1 119 117 112 152 90 41 122 197 129 253 124 250 45 148 119 15 236 103 43 110 30 222 77 86 106 198 47 31 100 43 85 143 189 176 148 179 4 202 126 205 175 196 219 234 197 29 178 105 141 151 243 58 95 105 120 154 163 11 119 181 234 104 113 159 131 114 62 169 233 167 131 45 205 120 171 235 188 172 41 186 223 221 183 218 121 208 198 82 4 61 33 32 236 150 211 200 29 6 195 172 58 5 248 14 138 74 47 108 204 20 202 73 107 135 212 14 195 86 64 185 110 229 221 21 55 23 239 52 55 53 227 231 56 171 90 245 216 11 75 209 74 230 40 254 156 85 120 154 122 241 141 49 119 157 41 94 234 160 92 159 212 163 158 6 246 122 200 170 243 178 166 168 99 130 6 168 169 50 102 204 216 141 232 118 170 43 135 54 102 204 152 49 99 198 140 25 51 102 204 152 49 99 198 140 25 51 102 204 152 49 99 198 140 25 51 102 204 152 49 99 198 140 25 51 102 204 152 177 50 155 174 78 239 247 13 111 159 67 150 157 92 158 245 175 184 15 5 160 70 49 157 214 180 216 13 168 85 90 247 74 86 204 154 92 174 52 205 233 244 198 25 77 167 247 251 134 23 103 113 25 49 122 123 38 179 157 89 157 250 84 10 127 163 44 240 17 72 88 126 68 173 11 117 193 92 193 157 103 244 247 125 120 254 62 189 43 89 177 192 2 232 100 78 222 204 174 134 239 111 145 19 108 13 184 90 180 88 43 70 165 211 91 26 158 47 106 195 255 43 83 126 50 47 106 86 238 242 185 56 243 74 27 187 114 94 173 219 239 232 30 179 212 137 93 3 25 74 125 74 197 239 157 160 233 42 219 143 60 163 237 50 26 212 176 38 163 74 221 163 235 165 106 20 5 79 181 246 77 64 226 209 175 4 35 48 224 19 224 165 79 223 91 137 250 83 137 202 247 183 176 135 134 88 211 66 94 6 13 117 122 249 101 133 30 144 92 167 215 193 187 157 93 133 239 157 253 100 19 174 223 252 100 19 46 176 165 151 47 132 160 212 120 88 69 10 162 102 39 118 209 235 79 187 95 180 166 147 29 139 72 138 36 123 232 37 16 59 149 107 24 231 116 143 55 222 129 223 109 188 131 197 145 124 242 250 8 157 100 123 97 161 6 222 138 181 94 163 212 31 133 199 155 22 162 218 142 69 167 134 53 28 202 139 166 209 66 114 93 87 183 250 172 61 168 95 185 154 209 195 83 65 188 19 187 134 102 40 248 48 8 32 32 30 133 217 111 30 85 215 53 199 23 113 127 11 44 31 235 31 95 92 215 108 255 2 117 122 157 203 170 117 122 29 188 251 144 227 187 178 184 246 14 215 111 226 154 61 28 89 105 229 247 206 126 124 15 167 136 10 15 18 48 43 172 61 86 140 213 242 181 246 148 242 133 0 168 74 151 216 170 11 179 221 47 178 6 155 222 141 15 189 212 122 77 214 208 92 247 24 122 67 20 229 76 195 255 177 195 91 85 245 17 58 23 124 107 5 42 94 56 34 182 144 92 87 217 154 92 13 46 168 239 88 84 106 88 129 53 11 206 83 107 189 70 25 139 117 92 29 148 49 231 131 32 173 158 151 113 39 142 246 109 191 18 196 163 47 241 7 81 191 157 148 85 216 149 163 42 171 65 201 189 68 78 90 215 174 63 95 168 26 91 20 35 140 13 203 141 52 254 58 189 14 94 28 106 124 194 21 22 53 157 76 16 202 71 249 173 129 12 18 124 124 0 169 173 194 195 184 194 66 87 123 54 91 117 81 70 169 191 184 3 181 46 49 138 180 36 113 70 200 14 237 57 180 199 2 135 73 72 103 41 92 247 152 213 14 205 224 158 53 176 234 31 62 67 195 127 35 199 195 117 246 88 1 220 90 161 233 36 17 159 35 42 60 200 6 25 30 3 223 144 171 115 82 201 118 185 49 84 106 4 62 74 184 186 109 24 17 62 42 167 171 227 198 35 137 162 40 174 233 10 201 233 91 70 166 104 196 115 215 169 245 53 245 28 213 42 106 81 202 188 150 38 154 134 232 38 215 253 38 80 234 136 227 187 231 138 155 76 174 211 91 26 222 81 148 225 170 49 42 252 212 16 171 135 32 175 154 59 164 26 159 180 21 143 88 125 211 73 149 206 176 192 91 5 81 132 63 222 113 16 168 81 189 90 13 72 232 30 243 251 228 247 221 153 149 213 7 241 214 158 86 182 138 69 115 66 146 4 188 67 212 90 57 190 233 74 84 75 182 203 11 171 162 6 151 219 116 117 129 157 138 25 112 161 171 203 183 186 234 11 47 169 79 239 236 177 29 180 44 46 107 161 16 85 100 137 115 131 79 72 77 103 29 17 52 61 45 41 239 43 216 191 232 253 147 104 50 193 127 185 78 175 131 119 247 47 114 124 87 214 81 110 61 183 14 71 73 85 249 1 59 147 152 39 170 18 143 7 132 106 44 172 212 25 118 240 238 102 241 199 179 254 207 6 237 153 112 191 101 143 172 168 250 36 19 245 224 186 199 86 12 71 84 28 89 241 115 66 90 31 196 79 135 49 112 231 106 58 4 252 152 155 168 114 252 177 29 142 34 110 169 84 85 83 67 103 156 156 26 114 11 199 118 101 167 134 164 65 236 219 152 177 24 153 194 152 70 232 18 67 43 213 150 35 139 91 74 150 184 242 84 101 253 39 118 57 45 212 51 7 9 68 238 109 168 211 187 212 117 253 117 122 29 188 251 144 227 19 182 152 63 206 221 48 187 149 32 148 111 203 255 247 9 162 210 234 227 14 104 213 120 17 240 171 117 137 89 245 208 12 38 147 16 183 238 167 29 139 187 95 148 53 52 215 61 102 181 208 192 48 55 135 255 107 215 156 85 213 7 240 48 135 183 93 16 68 58 212 248 230 130 228 135 28 207 106 177 100 119 208 47 23 30 43 158 218 80 168 161 71 85 86 243 228 83 142 231 60 249 148 92 50 168 29 117 166 187 97 116 180 99 26 213 94 8 122 89 220 82 178 196 133 109 67 212 43 212 210 55 180 2 188 254 188 35 139 227 6 44 124 250 129 58 189 197 105 22 153 78 175 131 119 247 186 42 124 20 94 115 224 220 109 229 124 148 88 62 238 150 146 208 170 143 94 253 221 49 129 92 151 24 35 129 193 211 205 185 148 9 38 152 164 143 37 167 123 44 50 192 184 85 136 170 62 136 15 221 142 46 8 99 48 1 143 53 129 122 216 35 170 10 111 235 103 133 246 78 224 163 215 79 43 169 169 81 202 236 147 173 16 146 239 32 130 174 16 149 3 162 6 243 17 197 44 206 204 203 151 197 45 37 75 92 249 180 210 238 91 83 95 96 253 121 138 171 43 155 250 98 247 173 185 95 57 138 235 52 157 222 210 240 34 163 85 169 242 43 135 231 206 142 97 112 146 125 178 73 173 184 232 232 30 91 243 77 44 66 170 143 46 222 78 116 17 241 156 224 199 119 170 5 72 151 4 219 4 106 148 230 188 172 133 7 252 172 69 137 12 186 239 156 250 18 133 158 76 210 205 18 223 128 12 48 68 88 40 169 107 143 218 181 167 182 184 148 11 133 78 111 23 85 167 247 123 134 23 103 113 117 122 10 82 232 30 119 107 213 167 82 120 39 16 214 117 26 90 224 91 154 243 30 217 222 51 39 159 165 122 221 121 121 178 184 215 147 37 174 60 85 133 142 104 78 91 185 166 232 174 245 116 122 191 127 120 49 227 32 99 151 99 253 171 245 93 70 11 221 175 213 66 168 34 93 1 97 91 74 22 183 152 172 250 68 213 189 91 99 198 140 25 51 102 204 152 49 99 198 140 25 51 102 204 152 49 99 198 140 25 51 102 204 152 49 99 198 140 25 51 102 204 152 49 99 198 140 25 51 86 6 131 101 115 123 76 43 24 51 86 72 11 13 93 89 80 186 65 9 143 62 251 115 159 189 166 255 160 198 149 250 224 252 51 106 89 70 92 217 218 115 184 226 247 61 109 49 170 28 38 212 250 140 86 217 25 149 194 65 30 201 188 63 107 92 43 93 198 54 121 14 15 239 239 190 147 190 29 187 49 138 195 234 103 116 221 79 73 87 23 55 246 97 239 108 124 49 8 171 236 173 201 32 232 169 245 206 198 62 36 93 101 12 157 55 200 218 216 157 191 87 175 73 8 188 20 101 63 222 166 209 1 76 35 149 224 255 62 29 124 199 255 189 243 10 237 143 210 173 177 8 180 14 93 218 210 10 112 177 77 53 77 173 2 85 141 100 73 250 178 160 54 49 237 253 212 160 251 101 30 199 188 127 89 189 71 240 240 254 238 187 104 237 79 160 110 135 212 51 231 213 173 82 58 94 16 21 215 107 95 39 89 117 117 113 35 236 225 231 112 245 35 10 16 226 74 191 135 159 139 168 29 50 214 120 165 153 241 235 108 62 215 255 79 106 170 174 5 217 204 245 15 216 99 89 157 178 233 166 131 172 157 33 149 218 161 43 240 115 90 47 252 237 236 222 215 11 68 145 125 207 225 50 158 160 6 65 28 131 89 13 109 153 148 174 0 136 112 18 174 99 15 35 198 60 39 120 187 207 83 75 120 150 159 96 229 166 42 87 91 44 101 124 145 143 54 226 183 66 255 72 41 227 182 164 107 106 149 200 217 112 153 187 68 190 85 40 50 113 122 120 135 168 57 233 213 210 201 42 116 113 97 153 47 44 234 17 10 12 18 29 90 91 191 175 9 48 207 62 253 236 211 168 167 214 156 23 21 243 127 140 129 133 120 78 41 102 239 196 131 251 195 64 113 213 168 135 205 209 254 70 85 213 157 191 151 119 28 24 40 183 23 184 97 59 203 139 28 19 240 15 62 210 124 84 134 23 99 124 2 212 119 7 50 160 198 247 18 181 101 105 84 93 42 230 33 95 92 149 87 5 4 25 15 71 123 10 143 13 167 232 93 129 172 94 208 219 5 157 5 221 133 223 201 90 53 204 212 237 184 116 124 145 143 54 206 111 89 72 200 206 200 235 223 127 97 233 189 14 191 172 219 254 254 79 64 191 61 237 171 132 184 196 11 109 121 94 97 107 228 191 19 186 184 241 69 252 46 190 168 210 197 117 244 139 238 122 224 174 7 28 93 35 217 165 185 160 104 87 118 252 40 235 238 58 212 44 149 29 227 54 30 201 245 65 147 235 223 137 74 231 194 141 239 70 97 156 22 226 222 92 11 8 226 130 119 169 248 87 215 244 166 101 120 62 118 161 60 231 235 63 124 253 135 182 212 38 105 95 22 190 113 134 122 235 12 207 240 148 201 93 11 101 178 82 95 196 55 8 169 17 124 38 32 99 26 42 143 107 21 214 128 52 102 212 241 200 44 74 32 171 85 151 248 220 25 95 196 104 147 248 92 49 22 65 164 132 238 238 232 26 249 149 191 249 181 165 247 186 117 92 183 253 45 137 76 92 207 156 94 231 234 126 18 212 80 185 104 114 195 201 42 116 113 97 48 175 131 102 84 234 226 58 15 223 77 85 249 197 59 22 113 212 62 181 101 116 139 117 185 77 217 207 89 195 214 65 17 62 134 24 142 128 225 171 254 41 46 20 44 249 160 59 201 166 239 67 2 218 98 29 119 219 106 69 7 41 248 212 87 176 226 190 197 31 207 13 133 198 70 211 171 64 254 115 52 141 162 101 20 162 54 94 228 181 81 57 111 73 125 52 200 120 60 251 147 213 46 213 66 63 162 150 66 213 194 223 171 235 35 136 154 36 145 21 229 72 120 236 6 46 120 57 44 149 204 97 33 174 82 8 84 232 112 103 20 100 53 186 255 137 165 247 250 120 66 183 253 101 138 142 143 252 2 178 46 76 55 3 64 165 42 239 158 10 21 65 115 100 117 116 116 3 143 5 30 83 235 226 86 85 97 224 139 7 82 85 124 150 143 73 9 120 24 71 182 7 223 131 36 84 174 252 195 235 253 241 173 159 172 155 194 27 235 157 21 35 95 156 249 73 70 247 77 194 140 246 95 88 245 64 102 245 111 247 217 194 81 176 73 68 205 250 127 73 178 190 73 63 124 247 37 142 191 247 165 36 219 114 28 127 234 143 23 9 165 158 185 25 123 156 159 137 244 204 69 212 219 78 196 184 220 27 119 222 149 243 178 113 24 29 113 233 63 213 3 237 233 226 68 157 216 189 125 173 125 7 111 149 47 96 211 163 170 67 84 177 105 9 157 172 241 60 81 253 82 123 92 121 89 199 233 199 7 138 239 20 70 193 154 242 81 21 74 107 104 251 202 251 156 237 175 94 63 85 115 58 217 69 135 253 124 29 93 220 214 252 86 3 242 0 21 41 90 124 72 221 106 115 87 246 225 231 2 11 145 124 233 72 39 127 124 212 238 111 145 130 251 242 61 100 124 131 223 188 106 32 131 35 226 249 84 231 255 14 218 37 159 79 225 200 9 87 8 250 225 33 160 78 35 30 199 119 204 49 91 105 127 188 72 40 189 240 83 86 189 249 220 230 115 172 250 133 159 218 91 61 212 201 136 138 129 169 24 227 55 159 179 231 149 49 255 7 200 179 190 133 255 84 93 65 32 71 212 230 143 155 236 178 253 51 192 149 165 170 67 84 24 215 187 249 108 82 189 221 149 67 86 57 81 253 28 92 86 35 220 155 160 240 78 7 222 211 143 106 252 203 135 49 181 47 238 115 142 108 0 162 82 149 207 201 11 37 94 115 49 147 174 142 110 85 213 106 198 15 164 168 248 44 189 120 125 255 133 102 151 180 127 87 246 124 74 117 75 216 24 119 254 158 173 112 148 237 253 208 231 83 189 179 109 44 240 60 156 130 55 22 15 60 214 6 143 223 255 10 136 135 4 200 187 175 255 16 157 133 213 91 7 195 82 60 38 148 128 162 112 253 7 247 63 184 31 239 6 201 39 219 239 44 176 208 153 5 137 239 142 92 205 59 14 236 239 204 6 22 202 53 170 98 72 36 228 51 199 35 184 17 81 147 52 3 92 236 184 226 25 248 95 129 239 167 7 25 215 62 200 47 167 121 119 227 79 186 13 167 114 68 13 57 169 31 239 4 151 23 89 85 68 93 234 224 152 9 206 137 195 250 164 162 64 115 202 229 232 93 217 193 191 43 39 85 97 76 125 219 251 12 104 131 154 114 204 85 177 21 221 223 231 39 55 186 58 186 186 115 85 124 107 27 41 72 250 128 64 167 244 225 136 241 104 223 78 190 113 29 158 35 127 232 155 207 181 193 56 140 239 121 173 203 173 224 88 178 199 207 197 177 35 246 182 19 119 253 217 10 180 49 33 149 237 157 137 198 23 82 39 55 226 231 102 200 117 227 215 147 27 187 178 48 138 249 190 191 221 112 22 164 33 87 136 186 195 150 87 43 78 109 217 112 182 92 163 170 160 154 45 135 105 111 68 36 207 0 163 227 242 103 250 217 160 203 133 37 157 37 239 188 195 144 248 109 202 237 86 128 93 148 204 177 156 153 114 225 119 42 178 202 90 222 125 191 249 121 155 43 19 76 187 10 78 190 228 111 231 117 169 106 5 218 125 206 120 116 135 244 149 147 162 131 41 108 83 159 239 116 117 113 245 168 218 120 177 251 210 233 109 160 78 7 121 75 204 85 170 5 160 79 110 68 98 131 104 102 125 235 107 188 62 206 54 26 222 15 157 117 192 102 84 239 37 254 144 248 195 192 123 135 246 20 166 32 60 241 144 174 184 7 146 250 219 14 109 106 3 188 164 70 205 31 99 194 109 85 190 27 195 175 171 236 8 161 249 99 223 242 59 176 119 21 138 237 56 158 130 64 100 71 185 70 85 65 181 252 38 143 169 130 32 201 231 26 234 209 203 61 110 240 113 213 53 93 105 80 188 136 8 249 125 167 122 14 234 58 185 107 226 188 182 145 221 45 188 196 202 147 187 9 206 154 108 42 39 85 155 143 122 227 97 120 171 87 133 181 212 14 70 214 100 90 186 184 122 84 237 190 4 78 82 147 115 43 146 136 35 171 249 248 30 32 119 3 206 192 122 103 105 58 183 176 77 66 7 132 192 113 248 191 158 116 141 250 77 208 13 252 108 35 144 168 94 214 39 71 153 223 163 140 42 94 218 116 219 123 141 156 216 213 61 167 114 69 253 185 234 82 147 186 110 157 14 81 249 36 97 100 74 108 196 48 50 37 159 174 84 218 138 94 138 132 212 221 1 60 211 126 103 167 63 214 79 243 102 42 85 215 94 243 198 63 252 156 58 172 189 78 162 138 158 148 174 43 155 111 182 91 224 80 190 85 210 115 146 124 231 81 147 187 82 39 93 231 86 243 26 45 76 41 72 13 157 75 191 228 144 158 13 109 89 203 213 110 181 92 177 191 52 125 89 169 235 86 211 68 189 11 206 104 201 205 248 82 240 169 186 234 59 103 162 5 213 45 169 251 39 16 133 51 97 215 161 230 77 168 12 68 173 104 163 125 7 31 180 49 99 198 140 25 51 102 204 152 49 99 198 140 25 51 102 204 152 49 99 198 140 25 51 102 204 152 49 99 198 140 25 51 102 204 152 49 99 198 140 253 255 107 184 42 200 154 52 237 96 76 230 36 129 98 217 9 170 242 156 214 85 234 236 178 235 52 92 23 4 100 116 156 215 214 39 158 255 174 62 133 16 72 200 132 124 213 46 150 220 43 89 43 47 135 71 157 231 121 154 206 243 50 197 79 67 87 118 25 254 31 211 242 185 51 118 27 29 44 171 39 107 105 97 229 207 202 216 200 12 173 244 165 87 179 191 137 140 20 11 79 54 223 175 69 244 61 72 118 5 10 36 76 176 108 185 120 73 190 129 3 232 186 141 23 27 47 134 152 125 5 138 14 94 93 232 218 248 209 4 211 120 140 153 92 51 28 212 232 12 230 201 174 53 175 231 32 176 6 164 6 255 81 209 84 29 38 71 231 57 65 212 121 94 142 248 182 175 250 255 105 228 149 125 79 220 243 91 53 222 177 198 119 113 165 52 44 115 12 74 74 215 214 73 46 109 121 69 212 94 235 19 37 136 205 22 150 39 86 8 241 66 126 189 100 129 215 175 137 206 14 125 227 42 22 254 106 247 173 42 135 9 126 153 200 117 3 193 143 84 229 174 107 134 245 161 25 92 102 134 75 208 172 204 42 182 174 89 93 155 192 243 157 217 95 118 39 73 18 217 214 203 168 230 186 225 20 235 127 246 233 145 169 54 210 88 6 154 8 151 111 255 231 39 159 106 38 117 6 205 236 201 167 110 255 103 24 5 250 232 84 5 93 157 111 237 5 242 132 218 140 254 198 57 148 14 171 169 243 92 42 190 119 86 72 211 150 191 124 16 204 9 197 62 140 254 58 242 53 69 16 70 248 39 74 4 13 191 137 203 28 253 201 157 96 238 182 196 3 169 33 235 242 65 166 175 152 216 195 234 174 32 201 10 196 217 231 101 126 192 199 95 59 170 204 240 17 53 231 215 177 207 138 169 26 251 140 224 184 233 149 139 109 95 38 254 79 247 191 198 25 171 86 105 218 197 221 235 60 21 125 34 171 233 157 141 186 240 176 104 87 57 214 88 177 54 246 208 75 24 31 80 198 163 13 71 133 34 235 198 173 163 63 185 243 47 193 247 148 229 79 175 94 216 247 4 235 104 127 67 166 72 225 216 208 76 251 27 172 99 223 19 171 23 172 105 194 8 204 80 24 165 170 106 223 227 255 41 125 251 251 208 81 157 81 213 166 141 137 35 116 77 30 167 8 157 103 190 176 57 255 12 198 212 120 71 119 151 130 239 202 30 217 126 100 59 95 229 74 43 223 17 8 82 225 187 178 184 60 252 245 31 30 235 59 182 3 101 7 162 140 18 219 12 222 194 53 47 81 1 115 165 47 53 186 178 78 91 242 3 201 33 19 180 97 43 132 78 137 80 207 98 43 252 209 186 146 233 73 198 125 180 251 210 224 45 131 183 116 95 226 113 147 24 85 61 150 77 75 220 202 158 217 6 89 199 220 15 254 53 110 111 158 225 42 202 199 218 238 118 151 222 118 183 98 142 202 138 123 93 184 226 164 124 148 12 126 9 90 5 141 24 31 168 123 45 232 255 143 136 250 190 18 184 235 129 135 94 136 253 155 255 70 86 118 105 207 181 51 144 153 89 97 141 217 2 210 252 152 244 171 61 30 54 110 140 173 248 100 83 59 156 45 159 205 180 94 59 176 31 117 234 170 170 94 13 254 124 240 191 61 250 243 95 200 119 43 176 250 34 139 142 248 202 224 105 127 221 38 52 161 243 108 147 35 180 119 130 147 105 237 251 114 124 87 22 150 244 135 156 51 85 248 36 219 253 34 74 7 236 126 145 138 231 79 64 93 126 7 116 24 27 206 226 82 74 86 179 169 77 72 191 119 16 58 204 166 147 188 236 213 64 63 255 5 254 62 235 79 165 203 233 63 232 118 100 114 186 178 31 116 83 167 42 36 237 38 8 126 49 62 137 218 19 192 168 29 171 228 214 221 90 125 94 5 249 5 110 205 76 40 244 198 93 194 102 42 170 38 158 42 232 81 158 146 97 223 73 20 202 199 240 208 234 157 132 124 148 140 51 212 42 176 151 139 247 79 141 162 234 63 141 170 172 250 231 145 193 255 114 255 63 182 42 241 182 179 52 136 71 121 122 91 228 107 47 116 228 107 151 130 81 3 150 207 207 150 181 207 246 87 67 191 67 18 217 75 186 107 47 221 250 120 167 188 53 215 124 249 228 83 206 42 96 22 146 207 207 185 206 179 152 81 177 6 220 194 4 226 166 69 25 190 119 22 148 155 26 156 121 146 10 111 11 145 216 75 171 89 3 31 113 84 248 98 170 250 227 19 223 36 217 15 206 243 207 45 47 80 116 170 115 29 90 78 238 155 75 206 28 219 81 190 185 42 62 167 137 221 162 236 137 221 229 85 153 64 187 208 143 34 74 81 59 162 196 207 194 185 38 188 10 138 76 120 23 210 59 43 84 227 11 47 43 191 244 218 79 221 232 181 159 202 195 22 62 232 187 15 12 6 40 84 178 155 254 63 196 183 68 94 78 42 169 39 194 112 246 239 183 246 141 254 36 73 164 182 245 87 214 144 245 23 212 87 26 126 211 11 61 252 230 74 124 208 127 1 212 95 137 243 85 84 101 193 196 55 214 176 80 17 96 255 14 59 67 89 106 107 224 61 28 223 115 223 85 91 171 229 109 223 153 45 188 250 198 59 176 125 59 179 50 124 247 165 141 119 20 182 128 28 111 171 30 49 30 131 112 145 48 21 30 130 198 126 62 134 240 48 219 31 223 245 109 18 183 245 10 64 74 239 114 199 159 243 99 217 183 52 162 14 205 156 216 5 226 63 113 127 197 14 247 92 213 25 85 85 233 73 86 63 50 133 229 143 76 169 4 130 28 47 198 43 208 168 234 132 190 60 12 22 189 220 135 94 84 245 219 219 13 165 63 116 169 106 29 92 18 208 74 114 163 184 3 220 210 128 220 127 167 152 66 42 193 152 179 254 142 61 107 255 109 252 168 12 191 254 88 239 44 110 125 97 191 222 1 169 172 213 146 185 73 97 249 161 100 236 112 215 183 246 227 108 241 108 31 123 92 239 250 54 118 56 148 164 82 181 170 234 133 159 186 183 173 178 210 178 153 18 228 185 127 102 165 49 185 5 221 70 124 213 143 194 59 228 101 243 61 92 68 194 223 26 11 44 68 165 58 207 136 143 162 114 241 152 120 81 144 84 226 151 142 146 42 124 123 110 182 137 83 10 57 126 224 61 252 125 211 149 190 201 71 126 17 37 106 251 58 68 133 169 106 173 60 211 225 158 171 58 163 170 106 79 37 140 254 240 10 239 36 84 56 33 106 255 236 211 219 118 109 219 229 124 39 79 164 137 208 151 135 193 194 185 226 158 177 122 92 118 115 73 118 96 255 200 148 19 168 202 168 106 141 181 45 161 94 155 36 45 128 206 94 172 160 232 71 12 143 81 175 161 123 219 109 159 165 190 96 141 210 84 251 154 35 219 99 139 214 158 173 227 184 157 159 124 110 226 46 223 170 78 142 36 222 247 30 79 11 199 214 196 251 201 17 171 154 74 85 86 191 225 236 202 188 155 116 44 30 223 233 143 221 253 226 106 198 103 182 45 247 133 254 251 109 239 173 129 240 78 86 182 163 243 12 132 157 22 122 204 254 58 207 28 159 192 151 40 211 206 153 42 124 49 85 213 120 144 61 143 89 177 214 107 42 252 131 251 249 116 171 13 206 24 77 179 254 207 6 247 78 200 229 78 221 68 85 207 104 75 153 171 242 32 216 158 88 40 229 136 132 82 118 241 33 127 177 35 66 95 30 6 151 28 171 99 191 120 239 143 128 82 157 167 183 141 31 197 185 137 140 170 111 182 141 31 69 53 68 103 26 62 144 25 63 250 102 155 164 169 3 88 81 135 168 81 233 203 148 124 64 139 34 211 213 161 77 145 151 163 236 200 118 101 67 215 62 244 210 109 215 30 79 36 72 25 227 222 35 93 89 148 181 12 174 73 61 220 193 142 41 95 192 28 235 235 96 169 135 131 107 248 8 169 166 42 10 146 58 97 216 127 62 33 19 88 179 231 203 33 155 170 87 214 94 221 244 26 134 119 210 146 27 156 182 108 39 232 60 59 248 118 119 103 73 192 211 116 164 5 30 95 219 5 63 74 104 148 159 96 131 143 35 69 58 102 100 120 61 162 150 54 87 117 60 131 134 210 210 25 246 204 0 219 211 139 226 100 50 166 17 100 105 25 190 215 22 159 203 130 140 99 35 104 28 194 172 99 52 237 223 251 0 6 212 16 63 27 60 180 231 208 30 72 186 164 224 187 70 89 111 180 251 86 112 191 78 241 158 14 59 132 221 183 74 92 17 251 192 32 246 182 137 207 255 26 62 132 96 11 40 138 136 233 116 184 51 123 219 62 226 166 138 193 227 59 59 22 113 134 186 70 177 137 135 120 221 52 144 89 99 171 7 227 8 137 181 83 191 36 119 191 46 160 189 133 133 151 100 221 208 97 42 107 163 171 243 124 163 240 81 22 213 44 191 237 43 120 241 146 185 253 115 25 94 143 168 75 223 171 210 230 170 252 25 80 94 220 233 238 110 128 79 214 174 3 76 53 109 173 73 219 119 108 63 45 46 202 178 211 219 210 247 74 56 31 11 22 167 70 212 1 195 234 133 213 11 20 253 66 46 45 58 50 133 1 192 200 148 221 33 208 206 234 204 5 47 65 202 35 98 213 219 95 109 37 204 73 196 40 156 15 148 226 36 124 188 80 90 91 175 247 165 160 49 189 71 172 123 94 231 25 35 26 181 174 242 242 196 111 62 215 51 215 245 109 232 119 15 63 39 199 99 120 172 163 183 91 252 94 149 58 87 149 107 47 151 30 96 39 61 255 176 208 126 214 165 198 234 250 6 87 210 40 21 245 103 81 143 182 170 98 102 143 118 55 85 142 122 201 232 77 254 51 181 145 169 198 43 216 141 145 75 231 58 207 24 209 52 124 71 241 29 16 67 16 116 170 249 4 65 203 43 75 244 255 202 168 250 22 123 64 169 202 208 198 150 11 177 91 48 248 53 237 240 253 177 255 7 69 155 124 1 121 110 52 77 0 0 0 0 73 69 78 68 174 66 96 130) asByteArray! !

!OHFileRequestHandler methodsFor: 'uploads' stamp: 'tbn 10/29/2012 21:10'!
imgglyphiconshalflingswhitePngContent
	^ #(137 80 78 71 13 10 26 10 0 0 0 13 73 72 68 82 0 0 1 213 0 0 0 159 8 3 0 0 0 152 211 179 123 0 0 2 217 80 76 84 69 255 255 255 0 0 0 0 0 0 249 249 249 255 255 255 0 0 0 255 255 255 253 253 253 109 109 109 0 0 0 255 255 255 255 255 255 255 255 255 0 0 0 0 0 0 255 255 255 240 240 240 254 254 254 246 246 246 0 0 0 252 252 252 0 0 0 0 0 0 255 255 255 255 255 255 218 218 218 0 0 0 194 194 194 244 244 244 255 255 255 255 255 255 244 244 244 247 247 247 255 255 255 0 0 0 0 0 0 179 179 179 253 253 253 0 0 0 226 226 226 176 176 176 255 255 255 255 255 255 251 251 251 231 231 231 254 254 254 255 255 255 0 0 0 237 237 237 0 0 0 207 207 207 0 0 0 253 253 253 246 246 246 237 237 237 251 251 251 231 231 231 250 250 250 225 225 225 146 146 146 254 254 254 254 254 254 193 193 193 152 152 152 116 116 116 225 225 225 208 208 208 0 0 0 243 243 243 187 187 187 161 161 161 128 128 128 253 253 253 212 212 212 98 98 98 255 255 255 213 213 213 248 248 248 220 220 220 250 250 250 251 251 251 233 233 233 251 251 251 253 253 253 253 253 253 209 209 209 242 242 242 252 252 252 248 248 248 235 235 235 252 252 252 182 182 182 198 198 198 229 229 229 238 238 238 245 245 245 253 253 253 101 101 101 103 103 103 240 240 240 182 182 182 224 224 224 247 247 247 250 250 250 233 233 233 229 229 229 250 250 250 248 248 248 203 203 203 255 255 255 132 132 132 241 241 241 120 120 120 247 247 247 221 221 221 249 249 249 200 200 200 210 210 210 236 236 236 250 250 250 222 222 222 226 226 226 230 230 230 243 243 243 155 155 155 168 168 168 165 165 165 220 220 220 238 238 238 255 255 255 241 241 241 201 201 201 240 240 240 255 255 255 255 255 255 222 222 222 198 198 198 188 188 188 235 235 235 214 214 214 208 208 208 226 226 226 249 249 249 244 244 244 226 226 226 236 236 236 245 245 245 180 180 180 255 255 255 253 253 253 251 251 251 252 252 252 250 250 250 230 230 230 0 0 0 228 228 228 252 252 252 247 247 247 176 176 176 153 153 153 253 253 253 236 236 236 252 252 252 193 193 193 233 233 233 255 255 255 218 218 218 240 240 240 240 240 240 245 245 245 241 241 241 254 254 254 248 248 248 254 254 254 142 142 142 226 226 226 251 251 251 249 249 249 220 220 220 255 255 255 242 242 242 250 250 250 159 159 159 237 237 237 247 247 247 246 246 246 232 232 232 243 243 243 250 250 250 245 245 245 245 245 245 166 166 166 203 203 203 250 250 250 248 248 248 211 211 211 235 235 235 250 250 250 235 235 235 170 170 170 243 243 243 237 237 237 162 162 162 207 207 207 218 218 218 214 214 214 162 162 162 235 235 235 226 226 226 249 249 249 85 85 85 205 205 205 255 255 255 214 214 214 227 227 227 225 225 225 234 234 234 252 252 252 255 255 255 246 246 246 251 251 251 243 243 243 244 244 244 204 204 204 255 255 255 255 255 255 249 249 249 245 245 245 255 255 255 242 242 242 253 253 253 0 0 0 217 217 217 252 252 252 251 251 251 252 252 252 233 233 233 191 191 191 251 251 251 234 234 234 233 233 233 254 254 254 255 255 255 248 114 79 230 0 0 0 242 116 82 78 83 0 26 0 212 207 2 15 241 35 16 239 159 95 10 5 47 169 240 198 21 226 24 3 191 31 111 19 83 183 223 63 134 197 127 6 23 67 225 13 107 68 143 175 194 141 192 79 18 83 15 95 8 160 165 154 178 140 211 17 54 208 224 62 52 33 126 97 11 167 64 49 30 209 95 39 111 18 196 110 162 210 139 145 144 128 77 134 161 147 51 177 66 81 106 153 182 112 38 37 33 21 108 181 195 34 88 113 114 59 128 29 151 32 65 91 130 60 96 137 97 109 125 52 133 51 47 48 73 136 4 168 80 67 77 33 54 40 42 103 75 38 89 81 166 71 68 80 44 14 229 129 96 146 123 1 86 80 164 45 25 234 120 193 41 104 221 55 135 101 49 93 244 136 223 27 87 191 179 36 151 135 49 24 131 98 196 122 83 220 149 99 23 79 217 205 93 143 192 138 21 150 85 22 59 90 105 60 78 35 215 12 41 9 56 54 112 86 224 242 148 58 104 141 35 249 48 90 132 24 81 212 14 74 78 134 190 69 20 68 84 140 222 126 245 135 94 0 0 30 45 73 68 65 84 120 94 236 157 135 127 35 199 153 166 191 98 39 2 13 52 2 65 16 36 65 104 0 6 147 28 13 41 14 195 112 134 51 154 60 26 77 144 70 57 89 57 88 193 178 44 219 114 206 105 157 214 246 218 190 221 219 124 155 115 188 219 116 57 231 156 115 206 249 222 191 224 88 221 32 107 186 190 106 118 243 64 173 108 95 191 146 73 255 158 42 126 104 244 131 14 160 62 20 233 187 39 121 220 34 128 226 208 208 16 145 141 221 216 134 137 75 11 54 52 214 89 156 42 46 118 232 64 178 184 31 238 142 1 99 46 125 59 135 239 159 116 78 37 2 168 68 73 1 24 170 152 202 208 9 8 33 16 90 29 182 208 143 53 76 241 72 163 50 218 54 32 140 31 131 201 175 142 214 34 138 11 212 45 98 177 69 44 21 44 41 144 202 143 0 192 17 13 66 5 140 183 24 166 62 109 25 185 170 195 227 250 110 28 248 246 54 112 109 159 82 246 79 10 119 109 16 64 176 221 204 86 221 35 63 201 39 67 133 200 145 90 35 169 142 113 158 135 24 236 192 27 23 98 210 211 124 36 189 58 220 41 137 194 47 69 190 37 247 226 110 5 82 185 113 151 67 224 104 24 8 110 181 201 37 245 105 211 204 147 173 186 182 182 223 125 108 131 109 10 63 105 255 100 226 100 195 34 128 44 216 25 173 22 199 0 96 172 72 241 8 21 34 114 46 122 161 188 139 142 193 126 253 236 252 40 98 240 81 220 85 38 234 189 29 151 41 150 53 245 234 88 35 149 167 160 242 20 233 153 69 77 170 230 220 82 60 205 42 112 91 24 128 91 37 46 169 79 201 204 163 152 165 2 107 55 147 27 0 108 73 111 176 253 3 168 253 147 182 223 74 176 70 8 160 17 11 165 108 86 15 33 204 161 196 131 117 72 130 96 198 3 188 153 128 151 155 20 19 231 3 130 38 162 44 199 122 22 180 201 82 107 36 21 164 242 17 168 124 36 246 108 138 187 188 88 98 252 162 226 233 199 106 223 170 200 100 85 8 177 251 63 206 163 36 72 181 238 184 25 169 87 177 190 127 36 85 251 39 133 31 198 197 72 220 69 28 51 42 213 173 186 128 181 181 85 7 92 125 234 173 253 127 134 40 210 10 24 164 18 122 18 104 86 107 125 103 199 117 171 82 107 36 21 164 242 37 168 124 137 84 168 124 218 234 99 107 166 28 231 141 179 34 16 227 158 228 177 68 231 148 253 29 171 131 95 87 43 139 174 148 202 46 81 242 210 197 41 213 64 18 171 253 147 198 189 128 72 8 162 192 155 205 98 181 115 4 184 212 108 158 1 142 84 180 169 183 68 255 244 173 82 0 4 196 3 50 88 109 163 35 97 5 13 221 234 186 51 108 89 195 206 122 204 106 185 142 157 212 227 146 154 35 27 33 222 24 9 52 254 4 74 180 196 56 209 40 0 140 242 99 181 31 1 118 153 137 190 14 116 93 173 20 97 183 152 84 153 19 199 1 224 248 9 210 247 143 0 68 5 13 206 133 224 188 225 81 63 94 45 139 213 15 95 7 94 36 58 1 92 255 236 222 86 9 160 36 171 149 78 124 236 61 40 118 136 90 39 113 143 54 185 90 240 215 134 135 215 252 66 53 86 236 204 238 33 121 134 180 188 51 228 223 75 156 255 227 177 191 98 224 4 0 6 118 52 140 241 30 120 240 235 234 163 17 226 82 93 27 97 108 151 237 31 33 212 254 73 219 111 135 80 137 64 197 116 165 228 86 3 121 148 186 238 17 224 76 239 255 217 170 15 109 108 181 218 191 73 168 85 98 124 91 42 176 182 6 108 107 101 39 42 190 87 100 238 5 26 192 221 100 224 179 240 24 239 68 183 211 157 125 92 87 155 131 95 87 223 157 180 249 182 164 114 208 78 218 63 153 248 219 118 222 171 29 193 219 178 88 37 167 142 48 117 135 246 111 117 105 42 132 252 74 86 24 183 128 198 166 135 98 37 134 125 244 227 23 136 105 53 73 165 89 108 78 159 69 45 27 119 23 208 207 130 251 102 95 87 51 109 254 5 73 229 224 133 196 253 147 133 151 45 140 109 131 202 24 172 178 81 41 147 83 11 181 214 107 180 127 171 84 67 8 55 234 237 25 109 164 60 34 196 244 220 140 135 98 139 84 124 236 198 39 166 213 36 181 210 152 159 163 243 243 214 82 38 62 165 234 79 13 112 15 156 245 186 154 190 249 133 234 54 221 30 172 22 210 246 15 231 250 189 116 177 168 238 165 83 173 142 78 92 169 215 175 76 140 238 109 213 248 92 200 2 206 18 209 202 196 114 64 166 4 51 158 117 141 84 10 98 55 250 211 116 46 53 46 113 169 244 200 51 178 114 48 252 61 153 56 84 144 194 7 127 191 170 105 173 74 169 92 235 200 54 117 70 10 148 178 127 82 184 51 50 94 247 26 237 241 17 39 197 170 138 243 192 237 14 177 120 136 226 73 171 9 239 210 70 132 56 79 123 37 56 173 158 107 74 154 211 77 83 129 200 180 19 100 226 66 69 100 230 209 232 160 239 87 157 130 67 89 195 247 79 58 47 79 140 78 47 151 73 139 16 234 95 61 189 128 120 70 69 148 209 33 26 32 205 61 165 230 105 58 111 193 126 27 146 161 183 32 121 254 63 182 154 39 183 154 39 183 154 91 205 147 91 205 147 91 205 147 91 205 147 91 205 173 150 232 187 46 185 85 31 62 177 36 247 80 150 198 166 138 99 37 134 93 160 219 5 92 99 169 180 58 233 124 9 253 44 101 175 83 156 90 44 145 111 154 191 88 114 237 228 206 203 88 186 33 235 82 230 148 22 199 198 22 15 242 64 225 90 248 118 130 32 7 135 48 212 231 62 0 63 193 42 231 174 13 212 60 240 254 213 31 0 30 124 16 248 129 20 171 188 78 54 254 48 250 185 59 123 29 175 6 20 97 158 15 100 179 234 50 24 5 212 233 118 43 68 228 243 94 116 224 224 250 209 91 113 0 33 4 8 242 219 158 86 125 200 248 102 171 156 219 168 207 143 142 206 215 89 255 234 101 224 165 151 128 203 41 86 121 157 108 124 22 34 12 102 247 85 199 3 178 113 136 157 64 235 136 199 188 152 52 89 45 2 152 26 179 89 253 205 45 33 182 54 97 147 158 138 66 58 111 37 241 22 74 164 219 3 73 177 180 151 85 31 81 124 163 85 198 75 168 79 4 160 96 162 174 61 92 11 253 180 18 173 242 58 8 235 48 190 176 192 120 11 22 133 177 80 97 243 137 204 117 136 30 2 64 156 187 33 231 187 75 134 226 3 14 16 80 207 100 213 120 104 119 49 62 215 36 106 206 141 179 147 118 23 144 246 90 100 224 232 16 153 120 241 171 213 83 154 85 65 8 197 38 91 85 82 1 223 100 149 253 55 240 195 184 157 194 122 183 107 253 171 47 3 152 156 4 240 114 162 85 94 7 172 142 228 29 160 163 243 151 119 58 73 46 224 21 86 199 174 24 235 244 255 99 62 113 238 132 156 237 46 33 19 183 122 83 219 114 38 171 179 213 50 133 41 87 103 249 9 190 133 82 9 45 206 105 227 81 9 56 191 231 216 251 80 97 92 208 158 215 85 37 149 105 221 161 166 254 85 16 239 95 61 5 224 195 31 6 112 202 248 9 28 155 76 117 160 234 40 238 158 2 78 185 26 63 134 159 160 48 63 129 195 134 58 93 189 206 172 228 134 212 20 207 116 172 66 37 147 85 124 153 250 249 178 161 78 115 28 24 111 114 78 255 185 102 182 250 9 4 248 44 187 80 16 9 1 33 18 173 22 4 118 34 10 89 172 54 188 104 76 239 95 173 0 64 16 0 64 133 98 233 183 115 17 175 99 3 182 172 163 113 103 26 152 118 52 14 124 157 194 124 29 48 108 207 159 208 235 212 36 15 83 140 245 57 141 142 238 242 98 202 177 154 209 106 35 142 159 163 126 158 131 193 210 207 3 63 111 178 247 125 30 145 145 131 240 125 55 115 65 80 109 58 73 86 185 61 110 149 247 175 10 33 244 254 213 123 177 155 123 205 221 104 188 206 69 224 162 170 163 56 1 164 115 0 232 16 117 0 128 205 111 76 174 24 235 200 84 240 36 241 132 245 7 59 86 221 250 185 173 115 27 245 246 99 113 236 68 19 1 7 166 51 240 248 184 241 12 252 7 219 17 224 188 130 15 51 46 68 6 171 66 136 20 171 233 253 171 179 0 26 66 52 0 204 38 236 21 86 39 216 220 12 84 29 197 9 96 245 1 224 189 68 239 5 0 54 255 153 158 154 207 183 243 113 253 121 249 106 251 7 56 86 157 137 213 230 42 235 214 3 237 88 37 253 179 4 155 64 115 171 92 222 106 114 78 181 7 36 224 124 246 61 15 53 2 254 206 134 32 39 236 109 85 194 20 171 105 253 171 75 253 143 105 29 2 128 37 67 153 201 73 240 58 115 115 97 29 198 133 96 28 42 96 243 29 181 61 25 250 108 189 247 41 62 200 117 213 152 77 101 117 83 27 154 155 183 168 73 242 95 206 79 247 136 76 252 163 95 169 125 144 111 38 169 237 28 192 106 122 255 234 221 0 112 157 232 186 254 123 2 168 164 214 225 220 108 117 144 58 4 79 241 193 174 171 198 204 41 171 115 164 37 24 81 64 227 205 36 222 60 93 102 155 9 18 128 160 120 79 37 133 247 80 67 98 104 114 50 163 213 244 254 213 26 0 188 159 232 253 0 80 75 183 202 235 112 158 102 53 189 78 195 171 51 94 29 29 111 171 249 169 250 188 93 234 101 178 74 202 234 193 164 105 208 66 152 156 52 54 52 19 134 128 94 116 2 239 127 141 135 117 217 178 254 85 214 140 58 71 52 39 191 143 242 50 50 89 234 112 206 235 136 204 117 166 71 39 24 47 80 121 217 52 63 161 254 232 46 29 213 230 83 66 132 80 95 15 62 145 18 209 235 25 27 154 73 12 9 49 116 51 206 147 247 66 228 201 173 230 201 173 230 201 173 230 201 173 230 86 243 228 86 243 228 86 243 228 86 243 228 86 115 171 230 6 195 93 238 179 33 215 54 55 7 40 170 199 103 11 175 164 165 139 138 121 131 176 64 134 148 12 29 52 62 81 218 242 32 223 213 86 171 70 173 125 94 88 215 135 236 218 188 136 146 213 106 141 181 30 166 101 22 247 50 54 9 76 158 179 208 37 158 242 89 180 71 226 104 1 11 251 179 154 108 26 137 67 173 125 173 41 211 226 60 10 136 33 218 69 160 244 240 199 69 189 80 231 90 21 87 90 153 189 140 86 43 17 254 64 194 134 16 207 82 13 53 6 123 64 111 117 24 151 201 144 127 134 7 52 178 130 21 178 38 133 0 132 152 180 72 133 209 1 172 54 247 101 181 121 32 86 19 139 136 221 128 8 24 3 152 86 197 165 214 193 172 190 18 225 99 113 90 132 222 146 169 114 236 211 22 74 198 231 121 66 234 230 121 7 158 211 17 136 70 122 209 15 245 70 20 78 162 36 162 16 143 72 29 98 200 200 213 16 179 42 17 43 157 106 213 143 113 242 209 141 206 192 32 218 171 29 152 107 221 191 85 224 88 132 175 3 108 186 101 1 183 2 236 196 246 190 31 196 49 147 213 202 26 218 100 8 224 48 100 94 245 45 145 66 37 137 131 157 125 15 234 12 156 248 184 123 89 245 161 23 153 37 114 199 42 210 106 53 65 107 53 166 117 16 171 179 34 204 44 183 58 126 233 210 184 225 89 190 220 8 126 10 104 153 247 251 3 196 83 65 157 126 191 173 54 21 30 236 12 188 144 102 117 193 108 213 135 102 181 138 123 200 181 81 116 65 84 72 208 90 136 107 29 192 170 138 198 173 47 0 95 176 184 213 83 159 238 188 110 225 251 185 10 177 117 22 39 93 98 249 93 124 109 96 171 66 133 241 196 129 193 207 192 161 30 74 44 79 36 237 193 100 117 93 183 90 16 115 174 13 192 70 76 223 58 169 196 249 250 250 155 97 245 248 139 192 139 199 153 213 14 194 204 26 84 52 207 111 224 126 98 121 24 63 119 112 199 106 230 187 165 214 65 156 129 133 216 40 128 120 249 93 132 194 134 16 166 250 133 170 102 213 237 182 126 4 97 110 214 167 47 158 169 184 191 94 200 100 213 218 178 246 99 21 31 216 218 250 0 152 213 135 44 33 196 22 208 49 169 248 105 28 38 150 27 120 105 95 86 75 64 105 112 171 205 131 57 3 175 208 222 86 105 37 97 59 11 213 24 175 76 1 63 137 48 74 31 147 42 185 146 154 197 170 53 220 28 182 184 85 209 15 183 138 147 39 193 172 186 120 94 238 178 54 30 226 86 91 165 26 94 32 22 224 123 246 101 85 153 200 210 124 151 58 48 248 61 48 135 187 200 100 219 171 111 135 168 16 231 42 74 31 147 26 113 37 149 91 173 198 245 89 195 78 184 152 46 115 81 132 76 139 117 100 154 91 50 215 240 5 57 254 73 253 243 58 87 193 110 151 212 200 255 208 217 2 22 18 142 202 109 30 153 88 24 108 165 218 131 190 7 54 215 33 24 108 143 78 108 135 217 86 217 213 167 75 85 188 164 164 106 86 227 92 74 37 169 85 223 138 157 223 66 176 142 76 99 75 102 23 225 98 215 21 246 62 22 97 26 147 61 210 98 155 126 31 185 82 93 97 71 37 91 157 250 247 215 106 115 64 171 60 105 143 91 208 165 42 94 46 100 59 85 73 169 82 43 235 79 15 68 152 50 101 202 220 182 229 32 250 161 81 195 227 78 51 169 52 34 49 163 133 221 31 210 248 134 232 103 163 48 224 250 195 7 117 6 22 148 92 135 20 228 73 125 220 193 227 208 119 70 86 216 255 25 52 121 47 68 158 220 106 158 220 106 158 220 106 110 53 79 110 53 79 110 53 79 110 53 79 110 53 183 234 182 104 224 44 210 183 85 114 171 174 93 172 24 22 186 93 76 94 191 151 167 131 37 74 142 187 68 131 198 247 105 31 201 173 186 207 30 71 209 212 157 13 223 180 174 47 0 219 37 61 39 113 138 195 165 41 200 217 242 231 58 140 143 81 203 60 191 88 161 46 171 229 39 244 163 135 91 149 64 249 80 18 159 234 208 1 196 118 195 47 201 188 5 176 161 136 242 184 62 47 20 57 240 77 216 183 221 152 85 215 62 121 201 178 88 199 64 125 179 13 148 12 235 235 70 162 180 116 1 220 103 94 130 219 26 118 79 92 176 158 211 184 119 118 130 112 149 207 31 175 122 51 129 15 155 75 53 105 5 164 33 36 80 62 148 196 129 197 22 25 2 128 144 185 39 6 210 17 148 86 198 155 172 148 162 76 158 28 50 114 24 180 250 64 164 85 77 195 201 75 195 250 90 175 245 137 185 229 54 14 27 214 215 5 192 116 119 140 235 167 159 194 166 16 98 228 132 109 223 49 226 104 124 244 124 201 7 22 93 125 126 185 48 26 248 192 5 77 106 65 0 162 192 180 2 210 16 18 40 31 74 226 0 138 221 193 173 74 17 80 54 56 7 204 67 38 121 114 200 204 215 137 101 29 125 173 106 26 142 95 99 203 74 189 63 234 73 48 172 175 107 234 219 62 21 194 154 171 87 153 139 30 225 248 9 198 251 139 153 175 233 124 161 66 190 222 157 225 46 34 84 69 88 100 143 32 13 129 12 212 56 148 196 33 99 119 6 181 42 69 40 27 6 206 74 41 202 229 201 33 206 19 91 87 34 173 106 26 95 21 212 195 225 208 162 101 88 95 215 208 5 88 66 59 164 247 27 175 111 176 134 79 48 126 63 172 58 80 189 67 227 11 40 46 178 237 182 177 27 91 183 17 142 145 145 242 33 87 113 163 37 223 29 212 42 108 101 195 192 89 41 69 153 60 94 136 75 229 90 185 84 149 54 48 214 29 3 46 240 245 129 35 171 181 248 65 92 253 164 193 53 1 59 82 109 198 127 116 107 100 194 27 47 56 26 127 167 7 41 53 126 130 191 160 172 94 48 218 32 35 229 67 107 26 103 150 166 6 182 26 101 205 204 121 41 141 178 151 177 205 182 191 145 212 186 210 0 176 54 196 165 170 60 128 40 63 198 215 7 38 201 245 245 117 127 238 65 132 225 86 159 146 245 109 48 94 104 18 157 46 151 116 30 204 120 82 42 244 215 97 244 169 39 246 58 5 44 165 72 167 124 232 14 197 141 150 170 207 12 108 53 122 132 59 18 56 43 101 166 35 98 39 35 124 251 125 50 198 15 31 119 40 124 75 99 150 74 189 13 200 108 54 13 235 3 3 128 182 190 174 119 249 139 94 130 213 143 140 111 215 7 24 151 105 250 156 7 51 27 5 2 72 211 26 13 234 82 9 24 150 142 204 148 15 57 138 27 44 89 147 5 103 80 171 214 176 58 78 12 156 91 53 83 21 195 246 251 137 82 135 157 33 162 167 228 91 26 41 149 231 93 22 128 250 156 105 125 96 0 250 250 186 109 172 29 146 184 78 177 52 208 165 185 178 227 118 209 96 124 59 102 30 172 40 174 180 70 239 108 116 169 4 132 162 76 212 56 148 196 195 183 90 35 189 65 239 150 164 79 37 213 192 89 41 78 185 85 174 53 89 234 16 209 101 156 188 100 150 74 206 69 15 141 51 100 90 31 216 176 146 254 199 60 200 120 183 199 241 157 216 201 157 3 241 228 182 101 32 20 149 64 249 80 18 7 218 167 207 15 254 206 70 250 84 82 13 156 149 50 83 161 194 183 223 252 206 166 47 117 136 90 176 126 240 154 67 230 4 51 141 199 212 88 202 122 188 205 211 85 15 168 158 14 226 120 245 92 3 50 141 115 171 3 241 228 182 101 32 20 149 68 249 144 68 46 231 141 201 229 102 66 79 38 101 110 221 39 105 200 229 82 37 143 6 153 63 70 121 184 86 115 83 126 36 117 136 174 109 141 156 119 40 41 193 180 114 148 186 30 111 179 48 42 68 129 237 152 213 105 33 51 189 58 24 79 110 91 22 66 181 33 115 202 135 66 228 112 62 221 163 3 72 84 217 49 242 232 11 59 246 56 77 215 106 110 202 143 164 14 145 211 164 239 188 228 113 18 112 222 11 49 104 242 94 136 60 185 213 60 185 213 60 185 213 220 106 158 220 106 158 220 106 158 220 106 158 220 106 110 213 220 223 251 150 113 213 40 113 112 245 7 79 107 170 146 212 125 184 223 248 73 63 84 89 56 72 171 174 109 104 143 121 75 184 26 2 204 157 117 53 143 205 207 194 7 206 73 156 116 247 101 213 110 81 66 222 151 96 181 82 196 194 96 175 26 183 69 192 80 203 13 173 218 166 246 152 189 185 7 120 251 153 15 171 158 189 62 185 62 128 226 18 145 161 15 121 116 190 14 123 63 124 156 215 39 106 41 148 201 198 2 128 181 125 89 85 219 207 228 25 85 249 219 220 123 231 64 86 229 135 47 128 74 49 236 70 43 1 128 16 172 191 55 228 128 137 91 79 87 171 79 91 230 249 13 24 248 185 145 137 121 141 179 199 85 89 171 141 3 31 170 149 136 245 33 63 66 244 200 68 29 37 157 7 68 129 153 87 106 188 62 45 21 65 105 54 120 163 122 41 187 213 206 85 0 11 9 82 189 249 170 177 146 55 19 12 100 245 217 26 138 64 17 181 103 135 136 14 3 0 17 235 239 149 92 134 115 111 216 41 20 156 97 207 52 223 122 102 28 140 91 171 87 43 129 149 177 62 185 184 171 12 156 255 80 141 244 62 228 10 124 31 149 219 113 76 227 209 71 23 56 143 118 226 184 226 234 200 163 132 152 108 180 106 144 169 181 50 90 237 22 17 198 116 220 223 43 229 21 140 86 165 212 65 172 54 103 60 132 47 142 230 16 81 13 16 130 72 8 173 231 83 114 25 206 163 147 209 26 231 214 100 125 216 249 89 143 113 224 212 103 93 128 115 89 93 231 59 127 4 93 70 235 67 14 170 64 53 8 188 89 141 211 213 150 141 53 206 67 169 51 229 56 111 217 41 107 154 49 27 39 251 252 100 54 171 62 84 11 42 203 202 134 146 167 85 122 40 165 109 41 251 226 174 67 68 13 96 135 214 72 101 47 190 46 241 58 231 151 122 19 78 165 200 57 112 103 111 13 38 78 4 157 67 166 215 131 140 222 135 188 30 62 182 87 211 248 213 176 95 146 241 72 106 160 241 41 164 88 101 54 70 132 0 160 55 112 146 109 190 45 232 96 39 214 99 134 187 220 21 46 213 15 171 139 194 65 90 61 20 141 179 254 94 201 101 56 247 194 70 215 59 60 157 203 251 196 74 49 123 29 243 227 138 43 56 39 128 201 170 39 132 214 135 92 65 181 42 191 30 210 248 143 91 178 11 139 241 82 36 85 227 143 89 41 86 185 13 243 65 121 201 131 140 119 41 142 31 69 99 35 60 213 84 135 131 148 187 92 118 87 60 144 85 49 239 73 216 152 23 67 68 111 139 198 89 127 111 200 1 19 183 93 223 119 109 206 97 119 138 230 58 66 24 185 32 18 58 39 167 90 43 1 127 178 118 23 233 125 200 193 124 161 48 31 28 209 235 28 113 134 171 195 14 49 142 80 170 206 131 225 42 128 164 117 3 149 141 84 171 205 55 32 243 70 51 142 177 57 189 210 235 65 125 36 129 221 229 102 187 43 238 111 141 200 252 7 231 91 197 232 189 73 177 53 20 246 247 202 176 254 222 189 120 17 40 38 205 31 148 19 221 241 105 0 181 187 202 188 15 89 222 3 143 241 58 99 191 80 112 42 6 142 187 2 98 156 156 194 184 7 74 136 178 145 106 149 86 55 0 108 172 106 116 115 78 2 107 166 156 118 151 203 239 138 7 187 91 186 102 121 51 192 140 103 93 27 234 247 247 130 245 247 190 117 156 156 194 21 224 233 178 177 15 185 200 230 103 231 74 248 140 69 134 48 27 41 86 105 197 130 181 162 195 185 232 193 131 148 187 92 118 87 60 176 85 103 248 116 0 4 167 101 239 126 66 127 239 91 194 213 16 192 224 65 214 15 134 137 135 217 72 181 74 23 27 151 200 28 39 229 46 151 221 21 15 110 149 156 38 9 49 212 148 189 251 9 253 189 111 37 103 205 177 7 95 159 137 78 25 16 230 13 10 166 155 148 53 234 46 87 215 26 236 245 51 121 47 68 158 239 100 171 121 114 171 185 213 60 185 213 60 185 213 60 185 213 60 185 213 60 185 213 220 106 158 220 170 123 149 190 173 147 247 3 119 97 119 136 58 54 186 100 74 167 59 6 38 213 254 8 237 51 139 112 13 116 108 140 140 177 97 115 8 245 213 28 159 178 228 213 87 95 85 223 222 196 84 128 3 95 39 57 123 63 240 97 171 134 133 5 212 172 195 196 236 149 108 0 47 48 171 247 225 19 100 72 103 113 108 108 177 99 230 255 250 207 56 196 82 130 121 249 232 22 128 148 158 1 30 109 61 203 162 154 95 140 205 186 229 150 91 212 183 55 49 175 120 34 6 220 34 219 20 198 83 214 73 102 86 147 251 114 241 252 140 5 120 51 207 51 121 149 41 0 104 127 141 13 212 240 199 104 204 213 160 187 136 48 139 174 145 63 209 114 217 243 169 1 53 151 120 154 251 176 138 254 95 252 12 45 218 198 249 200 106 213 245 221 228 3 198 247 25 245 13 245 139 172 209 135 111 79 58 231 235 36 155 173 150 0 88 66 88 0 74 172 234 209 163 144 49 188 136 26 227 143 195 35 214 136 117 55 189 96 243 22 122 117 50 224 252 123 239 147 92 59 228 235 117 220 151 177 57 64 168 48 219 197 86 36 21 23 50 88 157 155 155 83 223 248 226 203 230 3 38 250 166 211 66 21 97 204 253 91 239 79 218 126 145 209 106 180 78 50 223 160 200 170 47 173 30 142 154 252 106 122 95 174 0 128 219 110 3 0 65 177 172 1 222 217 233 127 167 191 232 136 126 19 192 194 11 218 117 248 8 218 104 0 64 21 71 76 252 79 253 101 201 181 11 207 199 63 14 84 136 197 5 224 102 60 86 133 152 247 172 215 101 251 136 64 181 144 193 42 0 245 45 125 241 101 247 6 164 64 31 192 13 237 48 90 116 11 252 47 126 191 134 157 188 148 237 88 109 48 219 42 230 142 213 200 42 252 161 72 39 92 151 175 1 171 172 178 243 172 117 250 235 83 236 69 183 212 109 2 172 76 23 214 187 241 209 54 128 31 179 208 229 252 143 59 43 22 123 29 108 2 155 202 53 219 189 25 175 171 193 233 63 29 117 25 42 169 153 173 154 23 95 230 171 9 78 105 45 58 133 73 64 44 59 134 93 255 211 216 201 87 178 89 253 96 9 42 197 20 171 250 223 128 110 0 192 83 79 241 245 126 143 110 231 182 219 228 87 253 80 178 46 30 129 204 23 99 252 242 143 18 172 176 90 139 84 30 196 117 167 190 246 0 80 111 94 199 131 55 243 227 219 252 119 240 23 137 66 174 82 66 227 87 129 95 109 160 100 106 198 3 138 149 24 133 216 253 135 180 252 66 17 222 219 255 54 209 58 237 207 42 151 218 72 210 202 22 23 237 1 230 93 255 179 232 167 209 204 100 181 81 62 5 149 123 82 173 174 171 201 235 201 253 186 116 219 110 40 150 207 122 207 23 33 83 215 55 111 10 215 239 4 128 215 73 101 174 142 238 153 119 0 245 51 93 212 231 98 220 151 252 19 228 199 56 185 53 124 198 105 183 157 207 160 230 234 82 219 0 218 74 107 202 177 90 145 82 79 22 43 234 30 56 163 85 38 181 58 93 149 90 137 105 101 82 137 146 172 6 30 162 60 73 153 172 126 176 3 21 124 209 100 149 175 159 44 131 106 129 245 235 166 159 129 123 135 16 198 59 195 55 239 133 85 0 232 221 140 207 88 184 127 66 136 137 167 96 157 209 248 145 143 91 232 117 53 126 31 218 61 122 252 113 234 181 181 197 176 139 222 185 101 0 203 231 188 98 150 99 53 250 204 201 111 214 244 219 123 15 59 209 238 246 234 128 223 169 248 64 59 166 238 2 228 110 42 84 129 11 196 181 50 169 4 36 220 168 142 138 48 222 39 179 89 45 63 10 149 106 147 91 229 90 163 235 106 181 192 250 129 211 173 186 118 255 230 231 105 135 45 232 142 7 42 114 68 123 234 109 76 45 44 76 161 61 236 196 121 21 192 159 109 161 26 227 29 120 31 139 182 250 99 30 58 177 250 167 87 101 245 202 234 233 118 210 177 202 251 111 195 143 20 197 132 140 10 192 186 34 100 70 201 216 214 254 56 91 231 84 125 211 181 70 27 207 45 249 73 203 222 86 240 137 108 86 91 80 193 151 179 188 179 41 68 86 11 67 172 31 56 221 170 125 124 107 90 204 207 11 214 12 253 177 6 198 123 15 177 149 201 201 89 158 124 242 29 239 120 114 114 217 209 120 97 242 247 240 71 95 212 214 206 62 137 40 252 243 74 203 77 138 222 151 55 151 179 28 171 210 90 64 20 140 178 53 221 97 94 228 186 92 71 152 122 153 175 115 170 190 233 207 129 85 130 210 42 165 114 77 207 101 179 122 31 84 172 94 202 58 201 172 23 130 245 205 166 88 61 62 220 36 10 2 98 105 62 179 85 38 88 172 14 81 111 121 98 98 185 71 196 248 107 248 7 205 56 175 32 150 10 197 210 152 23 243 141 253 255 110 41 46 213 141 164 242 156 217 240 0 111 227 12 13 20 17 165 192 94 7 77 129 109 14 225 100 179 90 131 202 243 105 235 36 115 171 170 111 150 111 222 234 42 123 187 52 236 236 209 101 76 98 164 76 217 179 34 2 141 4 34 22 109 120 58 160 96 58 109 201 107 158 2 91 27 216 24 103 101 84 136 209 21 135 222 172 8 41 157 193 132 39 48 42 84 152 155 66 225 128 123 33 28 250 238 73 222 11 145 39 183 154 39 183 154 39 183 154 39 183 154 91 205 147 91 205 147 91 205 147 91 205 147 91 93 152 90 136 131 220 106 11 81 138 46 101 141 11 24 39 47 184 174 121 247 118 81 164 55 49 248 40 90 38 28 134 243 210 88 145 245 63 31 40 95 156 154 90 148 156 199 29 3 186 148 41 123 116 196 218 128 109 152 30 90 237 255 192 87 209 207 143 144 41 173 171 45 67 147 1 138 21 211 242 180 182 13 106 113 225 110 237 44 204 139 159 34 225 73 118 139 166 189 85 76 216 33 104 162 153 217 234 155 191 238 241 169 175 221 115 231 107 146 243 28 65 99 114 78 130 244 254 228 189 154 209 132 128 129 133 86 69 52 246 48 250 121 152 88 220 210 24 126 229 26 52 122 202 184 86 227 179 176 37 183 241 44 233 185 223 251 41 102 21 248 195 192 5 113 116 195 112 152 117 166 126 227 13 16 11 222 248 141 169 142 209 42 253 147 169 5 94 230 214 48 58 229 253 207 233 220 178 246 51 255 51 133 195 15 207 74 206 226 2 79 244 40 166 27 183 246 163 155 90 66 63 75 153 94 5 32 192 118 93 27 24 146 117 110 160 159 27 108 231 250 255 244 87 254 192 31 130 3 182 105 48 180 112 54 173 136 91 236 176 169 224 67 95 53 88 253 35 16 5 250 91 191 246 119 88 51 225 98 241 206 229 187 171 196 82 189 123 249 206 226 162 78 75 240 65 127 238 207 255 5 140 233 101 32 83 171 232 211 101 170 124 221 227 8 27 185 119 241 162 199 120 226 186 202 222 115 244 241 111 62 214 80 92 229 132 148 212 149 54 210 59 110 86 219 17 109 175 102 235 73 36 224 248 137 19 199 251 86 205 147 74 45 0 219 74 37 214 140 188 142 48 175 243 85 119 251 89 208 142 201 83 245 243 15 243 215 22 110 145 117 255 210 109 255 232 151 174 198 249 171 120 122 181 20 21 210 203 151 86 159 198 171 218 73 181 118 110 29 244 87 255 218 95 255 27 113 76 157 90 216 199 242 233 34 17 95 151 88 174 122 135 195 26 247 198 11 0 56 199 93 65 112 151 137 131 136 205 63 134 182 67 205 23 139 0 142 145 158 53 200 52 136 183 51 241 142 27 122 119 40 220 123 55 101 178 42 200 178 96 219 176 172 33 65 212 81 147 58 241 75 85 20 110 245 149 8 191 194 255 8 122 20 235 93 250 49 121 134 86 132 248 155 71 97 176 250 67 255 234 127 109 48 238 80 89 10 217 154 85 120 54 84 84 38 7 183 104 86 239 57 86 24 167 31 10 254 238 223 211 172 158 122 195 145 160 32 49 91 247 88 174 122 135 90 156 203 213 238 132 16 208 57 170 101 162 114 155 113 243 74 184 179 184 78 68 223 47 249 172 185 103 183 254 88 166 235 42 57 111 151 240 237 78 54 171 68 195 195 22 96 13 15 203 123 224 247 170 73 239 37 21 203 77 180 122 57 194 151 227 84 30 251 81 142 159 224 150 136 254 254 55 30 102 246 92 34 106 254 195 95 51 217 254 214 231 126 6 120 66 225 39 128 159 249 220 183 136 136 89 157 155 93 42 75 208 140 227 238 147 171 37 34 250 212 231 53 171 30 34 240 200 113 120 113 126 252 17 146 129 198 149 61 157 183 5 145 168 106 188 1 180 186 83 225 62 106 24 164 86 231 183 38 2 126 93 21 50 160 120 122 27 192 70 143 184 213 237 159 49 88 149 167 95 121 18 222 249 68 6 192 206 60 35 78 146 213 238 14 239 82 66 247 212 125 6 75 244 207 255 197 47 157 141 243 127 105 29 137 138 121 134 249 191 245 203 13 33 86 20 94 17 162 241 203 191 101 178 74 159 137 26 135 125 47 70 107 239 241 65 223 250 55 159 251 183 32 226 235 21 83 169 200 215 43 46 150 40 101 29 99 141 151 136 74 58 127 18 152 122 240 131 170 243 87 147 90 8 154 138 176 235 170 150 119 1 239 210 217 81 153 31 254 225 240 27 197 18 158 126 97 219 210 234 132 216 205 132 246 112 231 54 44 101 53 237 175 44 172 8 43 162 150 148 193 44 253 251 255 240 31 173 243 241 27 247 255 116 177 118 245 37 79 94 79 248 252 79 125 227 215 159 32 45 79 252 250 55 62 101 178 218 107 67 166 54 19 163 119 97 29 244 95 254 235 127 67 157 12 13 162 139 124 189 226 8 155 57 145 145 215 42 149 154 206 31 135 28 216 20 87 198 241 184 65 170 2 41 215 85 182 74 103 234 25 56 60 253 90 128 180 154 120 94 63 132 255 190 50 178 117 182 173 89 253 237 179 245 232 42 94 63 251 219 218 135 75 67 173 22 90 164 91 130 255 169 255 249 48 46 146 150 224 67 181 175 64 2 109 190 231 211 231 127 17 223 36 45 223 196 47 126 158 124 143 89 165 229 91 101 254 119 16 131 101 81 0 253 159 217 215 182 38 20 99 235 18 15 202 79 158 52 115 124 137 156 99 146 167 74 229 251 159 119 115 239 251 30 88 205 18 56 26 47 241 154 188 206 54 207 47 11 218 188 25 59 231 39 70 175 76 78 94 25 157 56 31 127 29 93 219 26 129 101 97 100 235 90 12 11 49 39 174 220 0 176 25 144 158 31 247 94 134 4 218 252 153 26 251 188 135 76 179 30 30 145 115 66 100 252 37 18 8 211 43 77 162 183 96 221 227 83 75 246 141 56 215 164 178 247 171 236 186 42 131 170 2 41 103 108 144 16 35 142 51 34 196 16 146 103 209 138 152 83 11 25 199 227 20 139 142 169 113 116 99 120 120 131 154 124 72 62 150 172 198 248 61 240 24 140 58 179 197 4 231 19 253 206 109 202 106 213 229 172 223 255 236 213 85 223 242 193 243 118 163 113 236 121 141 143 115 169 220 146 158 76 103 108 254 27 67 54 43 91 70 205 83 87 28 103 133 246 147 57 245 152 131 119 86 51 188 49 181 65 9 235 12 143 78 148 223 68 190 60 205 251 171 203 194 36 53 101 255 23 40 115 132 250 141 161 160 255 91 14 28 208 0 0 0 32 8 219 168 98 2 250 151 179 135 158 97 70 46 21 148 168 93 177 75 161 238 199 0 0 0 0 73 69 78 68 174 66 96 130) asByteArray! !

!OHFileRequestHandler methodsFor: 'initialize-release' stamp: 'tbn 10/29/2012 20:48'!
initialize
	super initialize.
	! !

!OHFileRequestHandler methodsFor: 'private' stamp: 'tbn 10/29/2012 21:06'!
javaScriptResponseFor: aContentSelector

	^self respondWith: (self perform: aContentSelector) usingMIMEType: 'text/javascript'
	! !

!OHFileRequestHandler methodsFor: 'uploads' stamp: 'tbn 10/29/2012 20:41'!
jsbootstrapminJsContent
	^ '/*!!
* Bootstrap.js by @fat & @mdo
* Copyright 2012 Twitter, Inc.
* http://www.apache.org/licenses/LICENSE-2.0.txt
*/
!!function(e){e(function(){"use strict";e.support.transition=function(){var e=function(){var e=document.createElement("bootstrap"),t={WebkitTransition:"webkitTransitionEnd",MozTransition:"transitionend",OTransition:"oTransitionEnd otransitionend",transition:"transitionend"},n;for(n in t)if(e.style[n]!!==undefined)return t[n]}();return e&&{end:e}}()})}(window.jQuery),!!function(e){"use strict";var t=''[data-dismiss="alert"]'',n=function(n){e(n).on("click",t,this.close)};n.prototype.close=function(t){function s(){i.trigger("closed").remove()}var n=e(this),r=n.attr("data-target"),i;r||(r=n.attr("href"),r=r&&r.replace(/.*(?=#[^\s]*$)/,"")),i=e(r),t&&t.preventDefault(),i.length||(i=n.hasClass("alert")?n:n.parent()),i.trigger(t=e.Event("close"));if(t.isDefaultPrevented())return;i.removeClass("in"),e.support.transition&&i.hasClass("fade")?i.on(e.support.transition.end,s):s()},e.fn.alert=function(t){return this.each(function(){var r=e(this),i=r.data("alert");i||r.data("alert",i=new n(this)),typeof t=="string"&&i[t].call(r)})},e.fn.alert.Constructor=n,e(function(){e("body").on("click.alert.data-api",t,n.prototype.close)})}(window.jQuery),!!function(e){"use strict";var t=function(t,n){this.$element=e(t),this.options=e.extend({},e.fn.button.defaults,n)};t.prototype.setState=function(e){var t="disabled",n=this.$element,r=n.data(),i=n.is("input")?"val":"html";e+="Text",r.resetText||n.data("resetText",n[i]()),n[i](r[e]||this.options[e]),setTimeout(function(){e=="loadingText"?n.addClass(t).attr(t,t):n.removeClass(t).removeAttr(t)},0)},t.prototype.toggle=function(){var e=this.$element.closest(''[data-toggle="buttons-radio"]'');e&&e.find(".active").removeClass("active"),this.$element.toggleClass("active")},e.fn.button=function(n){return this.each(function(){var r=e(this),i=r.data("button"),s=typeof n=="object"&&n;i||r.data("button",i=new t(this,s)),n=="toggle"?i.toggle():n&&i.setState(n)})},e.fn.button.defaults={loadingText:"loading..."},e.fn.button.Constructor=t,e(function(){e("body").on("click.button.data-api","[data-toggle^=button]",function(t){var n=e(t.target);n.hasClass("btn")||(n=n.closest(".btn")),n.button("toggle")})})}(window.jQuery),!!function(e){"use strict";var t=function(t,n){this.$element=e(t),this.options=n,this.options.slide&&this.slide(this.options.slide),this.options.pause=="hover"&&this.$element.on("mouseenter",e.proxy(this.pause,this)).on("mouseleave",e.proxy(this.cycle,this))};t.prototype={cycle:function(t){return t||(this.paused=!!1),this.options.interval&&!!this.paused&&(this.interval=setInterval(e.proxy(this.next,this),this.options.interval)),this},to:function(t){var n=this.$element.find(".item.active"),r=n.parent().children(),i=r.index(n),s=this;if(t>r.length-1||t<0)return;return this.sliding?this.$element.one("slid",function(){s.to(t)}):i==t?this.pause().cycle():this.slide(t>i?"next":"prev",e(r[t]))},pause:function(t){return t||(this.paused=!!0),this.$element.find(".next, .prev").length&&e.support.transition.end&&(this.$element.trigger(e.support.transition.end),this.cycle()),clearInterval(this.interval),this.interval=null,this},next:function(){if(this.sliding)return;return this.slide("next")},prev:function(){if(this.sliding)return;return this.slide("prev")},slide:function(t,n){var r=this.$element.find(".item.active"),i=n||r[t](),s=this.interval,o=t=="next"?"left":"right",u=t=="next"?"first":"last",a=this,f=e.Event("slide",{relatedTarget:i[0]});this.sliding=!!0,s&&this.pause(),i=i.length?i:this.$element.find(".item")[u]();if(i.hasClass("active"))return;if(e.support.transition&&this.$element.hasClass("slide")){this.$element.trigger(f);if(f.isDefaultPrevented())return;i.addClass(t),i[0].offsetWidth,r.addClass(o),i.addClass(o),this.$element.one(e.support.transition.end,function(){i.removeClass([t,o].join(" ")).addClass("active"),r.removeClass(["active",o].join(" ")),a.sliding=!!1,setTimeout(function(){a.$element.trigger("slid")},0)})}else{this.$element.trigger(f);if(f.isDefaultPrevented())return;r.removeClass("active"),i.addClass("active"),this.sliding=!!1,this.$element.trigger("slid")}return s&&this.cycle(),this}},e.fn.carousel=function(n){return this.each(function(){var r=e(this),i=r.data("carousel"),s=e.extend({},e.fn.carousel.defaults,typeof n=="object"&&n),o=typeof n=="string"?n:s.slide;i||r.data("carousel",i=new t(this,s)),typeof n=="number"?i.to(n):o?i[o]():s.interval&&i.cycle()})},e.fn.carousel.defaults={interval:5e3,pause:"hover"},e.fn.carousel.Constructor=t,e(function(){e("body").on("click.carousel.data-api","[data-slide]",function(t){var n=e(this),r,i=e(n.attr("data-target")||(r=n.attr("href"))&&r.replace(/.*(?=#[^\s]+$)/,"")),s=!!i.data("modal")&&e.extend({},i.data(),n.data());i.carousel(s),t.preventDefault()})})}(window.jQuery),!!function(e){"use strict";var t=function(t,n){this.$element=e(t),this.options=e.extend({},e.fn.collapse.defaults,n),this.options.parent&&(this.$parent=e(this.options.parent)),this.options.toggle&&this.toggle()};t.prototype={constructor:t,dimension:function(){var e=this.$element.hasClass("width");return e?"width":"height"},show:function(){var t,n,r,i;if(this.transitioning)return;t=this.dimension(),n=e.camelCase(["scroll",t].join("-")),r=this.$parent&&this.$parent.find("> .accordion-group > .in");if(r&&r.length){i=r.data("collapse");if(i&&i.transitioning)return;r.collapse("hide"),i||r.data("collapse",null)}this.$element[t](0),this.transition("addClass",e.Event("show"),"shown"),e.support.transition&&this.$element[t](this.$element[0][n])},hide:function(){var t;if(this.transitioning)return;t=this.dimension(),this.reset(this.$element[t]()),this.transition("removeClass",e.Event("hide"),"hidden"),this.$element[t](0)},reset:function(e){var t=this.dimension();return this.$element.removeClass("collapse")[t](e||"auto")[0].offsetWidth,this.$element[e!!==null?"addClass":"removeClass"]("collapse"),this},transition:function(t,n,r){var i=this,s=function(){n.type=="show"&&i.reset(),i.transitioning=0,i.$element.trigger(r)};this.$element.trigger(n);if(n.isDefaultPrevented())return;this.transitioning=1,this.$element[t]("in"),e.support.transition&&this.$element.hasClass("collapse")?this.$element.one(e.support.transition.end,s):s()},toggle:function(){this[this.$element.hasClass("in")?"hide":"show"]()}},e.fn.collapse=function(n){return this.each(function(){var r=e(this),i=r.data("collapse"),s=typeof n=="object"&&n;i||r.data("collapse",i=new t(this,s)),typeof n=="string"&&i[n]()})},e.fn.collapse.defaults={toggle:!!0},e.fn.collapse.Constructor=t,e(function(){e("body").on("click.collapse.data-api","[data-toggle=collapse]",function(t){var n=e(this),r,i=n.attr("data-target")||t.preventDefault()||(r=n.attr("href"))&&r.replace(/.*(?=#[^\s]+$)/,""),s=e(i).data("collapse")?"toggle":n.data();n[e(i).hasClass("in")?"addClass":"removeClass"]("collapsed"),e(i).collapse(s)})})}(window.jQuery),!!function(e){"use strict";function r(){i(e(t)).removeClass("open")}function i(t){var n=t.attr("data-target"),r;return n||(n=t.attr("href"),n=n&&/#/.test(n)&&n.replace(/.*(?=#[^\s]*$)/,"")),r=e(n),r.length||(r=t.parent()),r}var t="[data-toggle=dropdown]",n=function(t){var n=e(t).on("click.dropdown.data-api",this.toggle);e("html").on("click.dropdown.data-api",function(){n.parent().removeClass("open")})};n.prototype={constructor:n,toggle:function(t){var n=e(this),s,o;if(n.is(".disabled, :disabled"))return;return s=i(n),o=s.hasClass("open"),r(),o||(s.toggleClass("open"),n.focus()),!!1},keydown:function(t){var n,r,s,o,u,a;if(!!/(38|40|27)/.test(t.keyCode))return;n=e(this),t.preventDefault(),t.stopPropagation();if(n.is(".disabled, :disabled"))return;o=i(n),u=o.hasClass("open");if(!!u||u&&t.keyCode==27)return n.click();r=e("[role=menu] li:not(.divider) a",o);if(!!r.length)return;a=r.index(r.filter(":focus")),t.keyCode==38&&a>0&&a--,t.keyCode==40&&a<r.length-1&&a++,~a||(a=0),r.eq(a).focus()}},e.fn.dropdown=function(t){return this.each(function(){var r=e(this),i=r.data("dropdown");i||r.data("dropdown",i=new n(this)),typeof t=="string"&&i[t].call(r)})},e.fn.dropdown.Constructor=n,e(function(){e("html").on("click.dropdown.data-api touchstart.dropdown.data-api",r),e("body").on("click.dropdown touchstart.dropdown.data-api",".dropdown form",function(e){e.stopPropagation()}).on("click.dropdown.data-api touchstart.dropdown.data-api",t,n.prototype.toggle).on("keydown.dropdown.data-api touchstart.dropdown.data-api",t+", [role=menu]",n.prototype.keydown)})}(window.jQuery),!!function(e){"use strict";var t=function(t,n){this.options=n,this.$element=e(t).delegate(''[data-dismiss="modal"]'',"click.dismiss.modal",e.proxy(this.hide,this)),this.options.remote&&this.$element.find(".modal-body").load(this.options.remote)};t.prototype={constructor:t,toggle:function(){return this[this.isShown?"hide":"show"]()},show:function(){var t=this,n=e.Event("show");this.$element.trigger(n);if(this.isShown||n.isDefaultPrevented())return;e("body").addClass("modal-open"),this.isShown=!!0,this.escape(),this.backdrop(function(){var n=e.support.transition&&t.$element.hasClass("fade");t.$element.parent().length||t.$element.appendTo(document.body),t.$element.show(),n&&t.$element[0].offsetWidth,t.$element.addClass("in").attr("aria-hidden",!!1).focus(),t.enforceFocus(),n?t.$element.one(e.support.transition.end,function(){t.$element.trigger("shown")}):t.$element.trigger("shown")})},hide:function(t){t&&t.preventDefault();var n=this;t=e.Event("hide"),this.$element.trigger(t);if(!!this.isShown||t.isDefaultPrevented())return;this.isShown=!!1,e("body").removeClass("modal-open"),this.escape(),e(document).off("focusin.modal"),this.$element.removeClass("in").attr("aria-hidden",!!0),e.support.transition&&this.$element.hasClass("fade")?this.hideWithTransition():this.hideModal()},enforceFocus:function(){var t=this;e(document).on("focusin.modal",function(e){t.$element[0]!!==e.target&&!!t.$element.has(e.target).length&&t.$element.focus()})},escape:function(){var e=this;this.isShown&&this.options.keyboard?this.$element.on("keyup.dismiss.modal",function(t){t.which==27&&e.hide()}):this.isShown||this.$element.off("keyup.dismiss.modal")},hideWithTransition:function(){var t=this,n=setTimeout(function(){t.$element.off(e.support.transition.end),t.hideModal()},500);this.$element.one(e.support.transition.end,function(){clearTimeout(n),t.hideModal()})},hideModal:function(e){this.$element.hide().trigger("hidden"),this.backdrop()},removeBackdrop:function(){this.$backdrop.remove(),this.$backdrop=null},backdrop:function(t){var n=this,r=this.$element.hasClass("fade")?"fade":"";if(this.isShown&&this.options.backdrop){var i=e.support.transition&&r;this.$backdrop=e(''<div class="modal-backdrop ''+r+''" />'').appendTo(document.body),this.options.backdrop!!="static"&&this.$backdrop.click(e.proxy(this.hide,this)),i&&this.$backdrop[0].offsetWidth,this.$backdrop.addClass("in"),i?this.$backdrop.one(e.support.transition.end,t):t()}else!!this.isShown&&this.$backdrop?(this.$backdrop.removeClass("in"),e.support.transition&&this.$element.hasClass("fade")?this.$backdrop.one(e.support.transition.end,e.proxy(this.removeBackdrop,this)):this.removeBackdrop()):t&&t()}},e.fn.modal=function(n){return this.each(function(){var r=e(this),i=r.data("modal"),s=e.extend({},e.fn.modal.defaults,r.data(),typeof n=="object"&&n);i||r.data("modal",i=new t(this,s)),typeof n=="string"?i[n]():s.show&&i.show()})},e.fn.modal.defaults={backdrop:!!0,keyboard:!!0,show:!!0},e.fn.modal.Constructor=t,e(function(){e("body").on("click.modal.data-api",''[data-toggle="modal"]'',function(t){var n=e(this),r=n.attr("href"),i=e(n.attr("data-target")||r&&r.replace(/.*(?=#[^\s]+$)/,"")),s=i.data("modal")?"toggle":e.extend({remote:!!/#/.test(r)&&r},i.data(),n.data());t.preventDefault(),i.modal(s).one("hide",function(){n.focus()})})})}(window.jQuery),!!function(e){"use strict";var t=function(e,t){this.init("tooltip",e,t)};t.prototype={constructor:t,init:function(t,n,r){var i,s;this.type=t,this.$element=e(n),this.options=this.getOptions(r),this.enabled=!!0,this.options.trigger=="click"?this.$element.on("click."+this.type,this.options.selector,e.proxy(this.toggle,this)):this.options.trigger!!="manual"&&(i=this.options.trigger=="hover"?"mouseenter":"focus",s=this.options.trigger=="hover"?"mouseleave":"blur",this.$element.on(i+"."+this.type,this.options.selector,e.proxy(this.enter,this)),this.$element.on(s+"."+this.type,this.options.selector,e.proxy(this.leave,this))),this.options.selector?this._options=e.extend({},this.options,{trigger:"manual",selector:""}):this.fixTitle()},getOptions:function(t){return t=e.extend({},e.fn[this.type].defaults,t,this.$element.data()),t.delay&&typeof t.delay=="number"&&(t.delay={show:t.delay,hide:t.delay}),t},enter:function(t){var n=e(t.currentTarget)[this.type](this._options).data(this.type);if(!!n.options.delay||!!n.options.delay.show)return n.show();clearTimeout(this.timeout),n.hoverState="in",this.timeout=setTimeout(function(){n.hoverState=="in"&&n.show()},n.options.delay.show)},leave:function(t){var n=e(t.currentTarget)[this.type](this._options).data(this.type);this.timeout&&clearTimeout(this.timeout);if(!!n.options.delay||!!n.options.delay.hide)return n.hide();n.hoverState="out",this.timeout=setTimeout(function(){n.hoverState=="out"&&n.hide()},n.options.delay.hide)},show:function(){var e,t,n,r,i,s,o;if(this.hasContent()&&this.enabled){e=this.tip(),this.setContent(),this.options.animation&&e.addClass("fade"),s=typeof this.options.placement=="function"?this.options.placement.call(this,e[0],this.$element[0]):this.options.placement,t=/in/.test(s),e.remove().css({top:0,left:0,display:"block"}).appendTo(t?this.$element:document.body),n=this.getPosition(t),r=e[0].offsetWidth,i=e[0].offsetHeight;switch(t?s.split(" ")[1]:s){case"bottom":o={top:n.top+n.height,left:n.left+n.width/2-r/2};break;case"top":o={top:n.top-i,left:n.left+n.width/2-r/2};break;case"left":o={top:n.top+n.height/2-i/2,left:n.left-r};break;case"right":o={top:n.top+n.height/2-i/2,left:n.left+n.width}}e.css(o).addClass(s).addClass("in")}},setContent:function(){var e=this.tip(),t=this.getTitle();e.find(".tooltip-inner")[this.options.html?"html":"text"](t),e.removeClass("fade in top bottom left right")},hide:function(){function r(){var t=setTimeout(function(){n.off(e.support.transition.end).remove()},500);n.one(e.support.transition.end,function(){clearTimeout(t),n.remove()})}var t=this,n=this.tip();return n.removeClass("in"),e.support.transition&&this.$tip.hasClass("fade")?r():n.remove(),this},fixTitle:function(){var e=this.$element;(e.attr("title")||typeof e.attr("data-original-title")!!="string")&&e.attr("data-original-title",e.attr("title")||"").removeAttr("title")},hasContent:function(){return this.getTitle()},getPosition:function(t){return e.extend({},t?{top:0,left:0}:this.$element.offset(),{width:this.$element[0].offsetWidth,height:this.$element[0].offsetHeight})},getTitle:function(){var e,t=this.$element,n=this.options;return e=t.attr("data-original-title")||(typeof n.title=="function"?n.title.call(t[0]):n.title),e},tip:function(){return this.$tip=this.$tip||e(this.options.template)},validate:function(){this.$element[0].parentNode||(this.hide(),this.$element=null,this.options=null)},enable:function(){this.enabled=!!0},disable:function(){this.enabled=!!1},toggleEnabled:function(){this.enabled=!!this.enabled},toggle:function(){this[this.tip().hasClass("in")?"hide":"show"]()},destroy:function(){this.hide().$element.off("."+this.type).removeData(this.type)}},e.fn.tooltip=function(n){return this.each(function(){var r=e(this),i=r.data("tooltip"),s=typeof n=="object"&&n;i||r.data("tooltip",i=new t(this,s)),typeof n=="string"&&i[n]()})},e.fn.tooltip.Constructor=t,e.fn.tooltip.defaults={animation:!!0,placement:"top",selector:!!1,template:''<div class="tooltip"><div class="tooltip-arrow"></div><div class="tooltip-inner"></div></div>'',trigger:"hover",title:"",delay:0,html:!!0}}(window.jQuery),!!function(e){"use strict";var t=function(e,t){this.init("popover",e,t)};t.prototype=e.extend({},e.fn.tooltip.Constructor.prototype,{constructor:t,setContent:function(){var e=this.tip(),t=this.getTitle(),n=this.getContent();e.find(".popover-title")[this.options.html?"html":"text"](t),e.find(".popover-content > *")[this.options.html?"html":"text"](n),e.removeClass("fade top bottom left right in")},hasContent:function(){return this.getTitle()||this.getContent()},getContent:function(){var e,t=this.$element,n=this.options;return e=t.attr("data-content")||(typeof n.content=="function"?n.content.call(t[0]):n.content),e},tip:function(){return this.$tip||(this.$tip=e(this.options.template)),this.$tip},destroy:function(){this.hide().$element.off("."+this.type).removeData(this.type)}}),e.fn.popover=function(n){return this.each(function(){var r=e(this),i=r.data("popover"),s=typeof n=="object"&&n;i||r.data("popover",i=new t(this,s)),typeof n=="string"&&i[n]()})},e.fn.popover.Constructor=t,e.fn.popover.defaults=e.extend({},e.fn.tooltip.defaults,{placement:"right",trigger:"click",content:"",template:''<div class="popover"><div class="arrow"></div><div class="popover-inner"><h3 class="popover-title"></h3><div class="popover-content"><p></p></div></div></div>''})}(window.jQuery),!!function(e){"use strict";function t(t,n){var r=e.proxy(this.process,this),i=e(t).is("body")?e(window):e(t),s;this.options=e.extend({},e.fn.scrollspy.defaults,n),this.$scrollElement=i.on("scroll.scroll-spy.data-api",r),this.selector=(this.options.target||(s=e(t).attr("href"))&&s.replace(/.*(?=#[^\s]+$)/,"")||"")+" .nav li > a",this.$body=e("body"),this.refresh(),this.process()}t.prototype={constructor:t,refresh:function(){var t=this,n;this.offsets=e([]),this.targets=e([]),n=this.$body.find(this.selector).map(function(){var t=e(this),n=t.data("target")||t.attr("href"),r=/^#\w/.test(n)&&e(n);return r&&r.length&&[[r.position().top,n]]||null}).sort(function(e,t){return e[0]-t[0]}).each(function(){t.offsets.push(this[0]),t.targets.push(this[1])})},process:function(){var e=this.$scrollElement.scrollTop()+this.options.offset,t=this.$scrollElement[0].scrollHeight||this.$body[0].scrollHeight,n=t-this.$scrollElement.height(),r=this.offsets,i=this.targets,s=this.activeTarget,o;if(e>=n)return s!!=(o=i.last()[0])&&this.activate(o);for(o=r.length;o--;)s!!=i[o]&&e>=r[o]&&(!!r[o+1]||e<=r[o+1])&&this.activate(i[o])},activate:function(t){var n,r;this.activeTarget=t,e(this.selector).parent(".active").removeClass("active"),r=this.selector+''[data-target="''+t+''"],''+this.selector+''[href="''+t+''"]'',n=e(r).parent("li").addClass("active"),n.parent(".dropdown-menu").length&&(n=n.closest("li.dropdown").addClass("active")),n.trigger("activate")}},e.fn.scrollspy=function(n){return this.each(function(){var r=e(this),i=r.data("scrollspy"),s=typeof n=="object"&&n;i||r.data("scrollspy",i=new t(this,s)),typeof n=="string"&&i[n]()})},e.fn.scrollspy.Constructor=t,e.fn.scrollspy.defaults={offset:10},e(window).on("load",function(){e(''[data-spy="scroll"]'').each(function(){var t=e(this);t.scrollspy(t.data())})})}(window.jQuery),!!function(e){"use strict";var t=function(t){this.element=e(t)};t.prototype={constructor:t,show:function(){var t=this.element,n=t.closest("ul:not(.dropdown-menu)"),r=t.attr("data-target"),i,s,o;r||(r=t.attr("href"),r=r&&r.replace(/.*(?=#[^\s]*$)/,""));if(t.parent("li").hasClass("active"))return;i=n.find(".active a").last()[0],o=e.Event("show",{relatedTarget:i}),t.trigger(o);if(o.isDefaultPrevented())return;s=e(r),this.activate(t.parent("li"),n),this.activate(s,s.parent(),function(){t.trigger({type:"shown",relatedTarget:i})})},activate:function(t,n,r){function o(){i.removeClass("active").find("> .dropdown-menu > .active").removeClass("active"),t.addClass("active"),s?(t[0].offsetWidth,t.addClass("in")):t.removeClass("fade"),t.parent(".dropdown-menu")&&t.closest("li.dropdown").addClass("active"),r&&r()}var i=n.find("> .active"),s=r&&e.support.transition&&i.hasClass("fade");s?i.one(e.support.transition.end,o):o(),i.removeClass("in")}},e.fn.tab=function(n){return this.each(function(){var r=e(this),i=r.data("tab");i||r.data("tab",i=new t(this)),typeof n=="string"&&i[n]()})},e.fn.tab.Constructor=t,e(function(){e("body").on("click.tab.data-api",''[data-toggle="tab"], [data-toggle="pill"]'',function(t){t.preventDefault(),e(this).tab("show")})})}(window.jQuery),!!function(e){"use strict";var t=function(t,n){this.$element=e(t),this.options=e.extend({},e.fn.typeahead.defaults,n),this.matcher=this.options.matcher||this.matcher,this.sorter=this.options.sorter||this.sorter,this.highlighter=this.options.highlighter||this.highlighter,this.updater=this.options.updater||this.updater,this.$menu=e(this.options.menu).appendTo("body"),this.source=this.options.source,this.shown=!!1,this.listen()};t.prototype={constructor:t,select:function(){var e=this.$menu.find(".active").attr("data-value");return this.$element.val(this.updater(e)).change(),this.hide()},updater:function(e){return e},show:function(){var t=e.extend({},this.$element.offset(),{height:this.$element[0].offsetHeight});return this.$menu.css({top:t.top+t.height,left:t.left}),this.$menu.show(),this.shown=!!0,this},hide:function(){return this.$menu.hide(),this.shown=!!1,this},lookup:function(t){var n;return this.query=this.$element.val(),!!this.query||this.query.length<this.options.minLength?this.shown?this.hide():this:(n=e.isFunction(this.source)?this.source(this.query,e.proxy(this.process,this)):this.source,n?this.process(n):this)},process:function(t){var n=this;return t=e.grep(t,function(e){return n.matcher(e)}),t=this.sorter(t),t.length?this.render(t.slice(0,this.options.items)).show():this.shown?this.hide():this},matcher:function(e){return~e.toLowerCase().indexOf(this.query.toLowerCase())},sorter:function(e){var t=[],n=[],r=[],i;while(i=e.shift())i.toLowerCase().indexOf(this.query.toLowerCase())?~i.indexOf(this.query)?n.push(i):r.push(i):t.push(i);return t.concat(n,r)},highlighter:function(e){var t=this.query.replace(/[\-\[\]{}()*+?.,\\\^$|#\s]/g,"\\$&");return e.replace(new RegExp("("+t+")","ig"),function(e,t){return"<strong>"+t+"</strong>"})},render:function(t){var n=this;return t=e(t).map(function(t,r){return t=e(n.options.item).attr("data-value",r),t.find("a").html(n.highlighter(r)),t[0]}),t.first().addClass("active"),this.$menu.html(t),this},next:function(t){var n=this.$menu.find(".active").removeClass("active"),r=n.next();r.length||(r=e(this.$menu.find("li")[0])),r.addClass("active")},prev:function(e){var t=this.$menu.find(".active").removeClass("active"),n=t.prev();n.length||(n=this.$menu.find("li").last()),n.addClass("active")},listen:function(){this.$element.on("blur",e.proxy(this.blur,this)).on("keypress",e.proxy(this.keypress,this)).on("keyup",e.proxy(this.keyup,this)),(e.browser.chrome||e.browser.webkit||e.browser.msie)&&this.$element.on("keydown",e.proxy(this.keydown,this)),this.$menu.on("click",e.proxy(this.click,this)).on("mouseenter","li",e.proxy(this.mouseenter,this))},move:function(e){if(!!this.shown)return;switch(e.keyCode){case 9:case 13:case 27:e.preventDefault();break;case 38:e.preventDefault(),this.prev();break;case 40:e.preventDefault(),this.next()}e.stopPropagation()},keydown:function(t){this.suppressKeyPressRepeat=!!~e.inArray(t.keyCode,[40,38,9,13,27]),this.move(t)},keypress:function(e){if(this.suppressKeyPressRepeat)return;this.move(e)},keyup:function(e){switch(e.keyCode){case 40:case 38:break;case 9:case 13:if(!!this.shown)return;this.select();break;case 27:if(!!this.shown)return;this.hide();break;default:this.lookup()}e.stopPropagation(),e.preventDefault()},blur:function(e){var t=this;setTimeout(function(){t.hide()},150)},click:function(e){e.stopPropagation(),e.preventDefault(),this.select()},mouseenter:function(t){this.$menu.find(".active").removeClass("active"),e(t.currentTarget).addClass("active")}},e.fn.typeahead=function(n){return this.each(function(){var r=e(this),i=r.data("typeahead"),s=typeof n=="object"&&n;i||r.data("typeahead",i=new t(this,s)),typeof n=="string"&&i[n]()})},e.fn.typeahead.defaults={source:[],items:8,menu:''<ul class="typeahead dropdown-menu"></ul>'',item:''<li><a href="#"></a></li>'',minLength:1},e.fn.typeahead.Constructor=t,e(function(){e("body").on("focus.typeahead.data-api",''[data-provide="typeahead"]'',function(t){var n=e(this);if(n.data("typeahead"))return;t.preventDefault(),n.typeahead(n.data())})})}(window.jQuery),!!function(e){"use strict";var t=function(t,n){this.options=e.extend({},e.fn.affix.defaults,n),this.$window=e(window).on("scroll.affix.data-api",e.proxy(this.checkPosition,this)),this.$element=e(t),this.checkPosition()};t.prototype.checkPosition=function(){if(!!this.$element.is(":visible"))return;var t=e(document).height(),n=this.$window.scrollTop(),r=this.$element.offset(),i=this.options.offset,s=i.bottom,o=i.top,u="affix affix-top affix-bottom",a;typeof i!!="object"&&(s=o=i),typeof o=="function"&&(o=i.top()),typeof s=="function"&&(s=i.bottom()),a=this.unpin!!=null&&n+this.unpin<=r.top?!!1:s!!=null&&r.top+this.$element.height()>=t-s?"bottom":o!!=null&&n<=o?"top":!!1;if(this.affixed===a)return;this.affixed=a,this.unpin=a=="bottom"?r.top-n:null,this.$element.removeClass(u).addClass("affix"+(a?"-"+a:""))},e.fn.affix=function(n){return this.each(function(){var r=e(this),i=r.data("affix"),s=typeof n=="object"&&n;i||r.data("affix",i=new t(this,s)),typeof n=="string"&&i[n]()})},e.fn.affix.Constructor=t,e.fn.affix.defaults={offset:0},e(window).on("load",function(){e(''[data-spy="affix"]'').each(function(){var t=e(this),n=t.data();n.offset=n.offset||{},n.offsetBottom&&(n.offset.bottom=n.offsetBottom),n.offsetTop&&(n.offset.top=n.offsetTop),t.affix(n)})})}(window.jQuery);'! !

!OHFileRequestHandler methodsFor: 'defaults' stamp: 'tbn 10/29/2012 20:38'!
prefix
	^'files'! !

!OHHelpRequestHandler methodsFor: 'request handling' stamp: 'tbn 10/23/2012 21:03'!
handleRequest: aRequest
	| entity |
	entity := ZnEntity text: 'Request handler method in ',self class name,' has to be implemented'.
	^ ZnResponse ok: entity
! !

!OHHelpRequestHandler methodsFor: 'private' stamp: 'tbn 10/29/2012 21:20'!
helpPageWithContent: aBlock

	^ String streamContents: [ :stream |
		stream << ZnConstants standardHtmlDocType.
		stream << '<html><head><title>Pharo Help</title><link rel="shortcut icon" href="/favicon.ico"/>'.
		stream << '<link rel="stylesheet" type="text/css" href="/files/bootstrap.min.css">'.	
		stream << '<style type="text/css"> '.
		stream << HelpResourceLibrary helpCss.
		stream << '</style>'.		
		stream << '</head>'.
		stream << '<body>'.
		aBlock value: stream.
		stream << '</body></html>' ]

	! !

!OHHelpRequestHandler methodsFor: 'private' stamp: 'tbn 10/23/2012 21:43'!
htmlResponse: html
	"Reply with a dynamic HTML page"

	^ ZnResponse ok: (ZnEntity html:  html)! !

!OHHelpRequestHandler methodsFor: 'defaults' stamp: 'tbn 10/23/2012 20:53'!
prefix
	^self subclassResponsibility ! !

!OHHelpRequestHandler methodsFor: 'private' stamp: 'tbn 10/29/2012 21:01'!
respondWith: content usingMIMEType: mimeType 
	| entity |
	entity := ZnEntity with: content type: mimeType. 
	^ ZnResponse ok: entity! !

OHHelpRequestHandler subclass: #OHWelcomeRequestHandler
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OnlineHelp-Core'!

!OHWelcomeRequestHandler methodsFor: 'request handling' stamp: 'tbn 10/29/2012 21:56'!
generateHelpPage
	 ^self helpPageWithContent: [:stream |
		
		stream << '
		<div class="navbar navbar-fixed-top">
			<div class="navbar-inner">
				<div class="container">
					<a class="brand" href="#" name="top">Pharo-Project</a>
					<div class="nav-collapse collapse">
					<ul class="nav">
						<li><a href="#"><i class="icon-home"></i> Home</a></li>
						<li><a href="/api"><i class="icon-th-list"></i> API</a></li>						
					</ul>
					</div>					
				</div>						
			</div>
			<div class="container"><br/>
			
			 
           		<div class="hero-unit">
            	<h1>Welcome</h1>
            <p>Welcome to Pharo-Project Online help. This online help should give you an introduction on how to use the Pharo Smalltalk system.</p>
            <p><a href="http://www.pharo-project.org" class="btn btn-primary btn-large">Learn more </a></p>
          </div>
          		 
			
			
			</div>
		</div>
		
		'
		
		
	]! !

!OHWelcomeRequestHandler methodsFor: 'request handling' stamp: 'tbn 10/29/2012 21:29'!
handleRequest: aRequest
	^self htmlResponse: self generateHelpPage ! !

!OHWelcomeRequestHandler methodsFor: 'defaults' stamp: 'tbn 10/29/2012 21:24'!
prefix
	^'welcome'! !
